(* Content-type: application/vnd.wolfram.mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 8.0' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       157,          7]
NotebookDataLength[    299278,       5707]
NotebookOptionsPosition[    293892,       5541]
NotebookOutlinePosition[    294536,       5564]
CellTagsIndexPosition[    294493,       5561]
WindowFrame->Normal*)

(* Beginning of Notebook Content *)
Notebook[{

Cell[CellGroupData[{
Cell["\<\
Computing Exact Closed-Form Distance Distributions in Regular Polygons\
\>", "Title",
 CellChangeTimes->{{3.5762216709375*^9, 3.576221702578125*^9}, {
  3.57622504103125*^9, 3.57622504625*^9}, {3.5764594949692497`*^9, 
  3.5764595119379997`*^9}}],

Cell[TextData[{
 StyleBox["CONTRIBUTION:",
  FontFamily->"Arial",
  FontWeight->"Bold",
  FontVariations->{"Underline"->True}],
 StyleBox[" ",
  FontFamily->"Arial",
  FontWeight->"Bold"],
 "This notebook implements the algorithm in [1] to compute: (i) the exact \
closed-form probability density function and (ii) the exact closed-form \
cumulative density function of the distance between a randomly located node \
and any arbitrary reference point inside a regular L-sided polygon.\n\nThese \
results can be used to obtain the closed-form probability density function of \
the Euclidean distance between any arbitrary reference point and its nth \
neighbor node when N nodes are uniformly and independently distributed (i.e. \
according to a uniform Binomial Point Process) inside a regular L-sided \
polygon.\n\n",
 StyleBox["CITING THIS WORK:",
  FontFamily->"Arial",
  FontWeight->"Bold",
  FontVariations->{"Underline"->True}],
 " If you use this notebook to generate distance distribution results, please \
cite our paper:\n\n[1] Z. Khalid and S. Durrani, \
\[OpenCurlyDoubleQuote]Distance Distributions in Regular Polygons,\
\[CloseCurlyDoubleQuote] to appear in IEEE Transactions on Vehicular \
Technology, 2013. \n\
http://ieeexplore.ieee.org/xpl/articleDetails.jsp?reload=true&tp=&arnumber=\
6415342\nhttp://arxiv.org/abs/1207.5857\n\n",
 StyleBox["USAGE INSTRUCTIONS:",
  FontFamily->"Arial",
  FontWeight->"Bold",
  FontVariations->{"Underline"->True}],
 StyleBox[" Please note the following:\n(i) Notebook assumes that the \
reference point is located inside the polygon.\n(ii) ",
  FontFamily->"Arial"],
 "Generally, enter reference point x and y coordinates in decimals (e.g., \
0.5) , rather than as fractions (e.g. 1/2).\n(iii) Sections 1-6 in the \
notebook generally execuate in a few seconds. Section 7 in the notebook is \
the time consuming part, depending upon the value of N.\n(iv) The distance \
distributions are piecewise function. The notebook outputs values in a text \
file, which can be imported in Matlab for plotting.\n(v) This notebook has \
been tested using ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " 8.0.\n \nFor comments, suggestions and bug reports, please email: \
salman.durrani@anu.edu.au.\n\n",
 StyleBox["COPYRIGHT:",
  FontFamily->"Arial",
  FontWeight->"Bold",
  FontVariations->{"Underline"->True}],
 "  \[Copyright] Salman Durrani, Zubair Khalid and Jing Guo.\nApplied Signal \
Processing (ASP) research group,\nResearch School of Engineering,\nThe \
Australian National University, Canberra, Australia, May 2013.\n"
}], "Text",
 CellChangeTimes->{{3.576221713203125*^9, 3.576221772390625*^9}, {
   3.576221922625*^9, 3.576222106140625*^9}, {3.57622214203125*^9, 
   3.57622215371875*^9}, {3.5762222333125*^9, 3.576222237765625*^9}, {
   3.576222274140625*^9, 3.57622228684375*^9}, {3.576222337265625*^9, 
   3.5762223855625*^9}, {3.576223884421875*^9, 3.57622390103125*^9}, {
   3.57622401659375*^9, 3.576224029125*^9}, {3.576224125046875*^9, 
   3.5762241560625*^9}, 3.5762242631875*^9, {3.576224509125*^9, 
   3.576224539859375*^9}, {3.576224945390625*^9, 3.57622494646875*^9}, {
   3.57622502446875*^9, 3.576225025390625*^9}, {3.57622579696875*^9, 
   3.576225846671875*^9}, {3.57622593440625*^9, 3.57622595765625*^9}, {
   3.57626260915625*^9, 3.576262615328125*^9}, {3.57635083128125*^9, 
   3.576350917984375*^9}, {3.57635094865625*^9, 3.5763511323125*^9}, {
   3.57635116403125*^9, 3.57635118471875*^9}, {3.576351527546875*^9, 
   3.5763515479375*^9}, {3.576353805828125*^9, 3.57635382303125*^9}, {
   3.57635386503125*^9, 3.576354029171875*^9}, {3.57635462703125*^9, 
   3.576354663328125*^9}, {3.57635474578125*^9, 3.57635485565625*^9}, {
   3.576354913390625*^9, 3.57635513175*^9}, {3.576355708328125*^9, 
   3.576355735046875*^9}, {3.57635590359375*^9, 3.5763559449375*^9}, {
   3.576355998921875*^9, 3.576356015921875*^9}, {3.576356062609375*^9, 
   3.576356116671875*^9}, {3.5764595501098747`*^9, 3.5764596240317497`*^9}, {
   3.5764596825786247`*^9, 3.5764597109067497`*^9}, {3.5764597964848747`*^9, 
   3.5764598186254997`*^9}, {3.5764598939379997`*^9, 
   3.5764598948754997`*^9}, {3.57670651665625*^9, 3.576706534109375*^9}}],

Cell[BoxData[{
 RowBox[{
  RowBox[{"ClearAll", "[", "\"\<Global`*\>\"", "]"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"starttime", " ", "=", " ", 
   RowBox[{"SessionTime", "[", "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"SetDirectory", "[", 
   RowBox[{"NotebookDirectory", "[", "]"}], "]"}], ";"}]}], "Input",
 CellChangeTimes->{{3.55779395803125*^9, 3.557793958515625*^9}, {
  3.557793992078125*^9, 3.5577940063125*^9}, {3.558743097109375*^9, 
  3.558743097453125*^9}, {3.55875139528125*^9, 3.558751395640625*^9}, {
  3.575833974984375*^9, 3.575833982375*^9}, {3.57583613675*^9, 
  3.5758361376875*^9}, {3.57602603775*^9, 3.576026040921875*^9}},
 FontSize->20],

Cell[CellGroupData[{

Cell["1. Define input parameters ", "Section",
 CellChangeTimes->{{3.5760260236875*^9, 3.576026050828125*^9}, 
   3.57602613696875*^9, {3.57609272621875*^9, 3.5760927274375*^9}, {
   3.576351228234375*^9, 3.57635122875*^9}, {3.5763512981875*^9, 
   3.576351304484375*^9}}],

Cell["\<\
Define the number of sides and the circum-radius of the regular convex \
polygon, which is centered at (0,0)\
\>", "Text",
 CellChangeTimes->{{3.557708311609375*^9, 3.55770833840625*^9}, {
  3.55779467246875*^9, 3.557794686109375*^9}, {3.5587406488125*^9, 
  3.558740650328125*^9}, {3.57583404484375*^9, 3.575834046875*^9}, {
  3.575834138578125*^9, 3.5758341395*^9}, {3.576025689546875*^9, 
  3.576025737640625*^9}, {3.576224570859375*^9, 3.576224589390625*^9}, {
  3.576351566515625*^9, 3.576351567*^9}, {3.576705524828125*^9, 
  3.57670553475*^9}},
 FontSize->20],

Cell[BoxData[{
 RowBox[{
  RowBox[{"L", "=", "4"}], ";"}], "\n", 
 RowBox[{
  RowBox[{"R", "=", "1"}], ";"}]}], "Input",
 CellChangeTimes->{{3.575834050078125*^9, 3.575834074015625*^9}, {
   3.575836406640625*^9, 3.57583640903125*^9}, 3.575839504484375*^9, {
   3.575840063859375*^9, 3.57584007203125*^9}, 3.575840152328125*^9, 
   3.575840983546875*^9, 3.575841024953125*^9, 3.575841251546875*^9, 
   3.5758413773778753`*^9, {3.5758415371278753`*^9, 3.5758415586591253`*^9}, 
   3.5758424477997503`*^9, {3.5758424803153753`*^9, 3.5758424825653753`*^9}, 
   3.5758425653310003`*^9, 3.5758437450028753`*^9, {3.5758438815341253`*^9, 
   3.5758439257997503`*^9}, {3.5758460896591253`*^9, 3.5758460930966253`*^9}, 
   3.5758469380810003`*^9, 3.5758470297372503`*^9, {3.5758470601278753`*^9, 
   3.5758470638935003`*^9}, {3.5758471558778753`*^9, 3.5758471760497503`*^9}, 
   3.5758472588466253`*^9, {3.5758579599091253`*^9, 3.5758579878778753`*^9}, {
   3.5758594400810003`*^9, 3.5758594454403753`*^9}, 3.5758595027997503`*^9, {
   3.5758600045653753`*^9, 3.5758600074403753`*^9}, {3.5758600585497503`*^9, 
   3.5758600824560003`*^9}, {3.5758601442528753`*^9, 
   3.5758601454716253`*^9}, {3.5758601931747503`*^9, 3.5758602552685003`*^9}, 
   3.575946443109375*^9, 3.57594649578125*^9, {3.575948334953125*^9, 
   3.57594833821875*^9}, {3.575948488921875*^9, 3.575948494515625*^9}, 
   3.575949023765625*^9, 3.575949415640625*^9, {3.575949706453125*^9, 
   3.575949709203125*^9}, {3.57595206265625*^9, 3.575952063015625*^9}, {
   3.57595224628125*^9, 3.57595225090625*^9}, {3.57595229315625*^9, 
   3.57595231*^9}, {3.57595400578125*^9, 3.575954012125*^9}, {
   3.57595709015625*^9, 3.575957092328125*^9}, {3.57595713540625*^9, 
   3.57595713809375*^9}, {3.57595733175*^9, 3.5759573613125*^9}, {
   3.575963161890625*^9, 3.5759631813125*^9}, 3.575965890921875*^9, {
   3.57596608921875*^9, 3.57596609315625*^9}, 3.575966183046875*^9, {
   3.575966391203125*^9, 3.575966399296875*^9}, {3.575966437703125*^9, 
   3.5759664416875*^9}, {3.575966936875*^9, 3.575966945546875*^9}, {
   3.5759670274375*^9, 3.5759670324375*^9}, {3.575967546875*^9, 
   3.575967549703125*^9}, 3.5759678521875*^9, {3.575968615140625*^9, 
   3.575968621015625*^9}, {3.5759693001875*^9, 3.575969307328125*^9}, 
   3.5759693493125*^9, {3.575969977203125*^9, 3.575969978*^9}, {
   3.575970018046875*^9, 3.5759700184375*^9}, {3.575970195453125*^9, 
   3.57597020071875*^9}, {3.57601326840625*^9, 3.576013274609375*^9}, {
   3.576014326890625*^9, 3.576014340203125*^9}, {3.57601570015625*^9, 
   3.576015706375*^9}, {3.5760159348125*^9, 3.57601594*^9}, {
   3.576016811234375*^9, 3.576016811921875*^9}, {3.57601687284375*^9, 
   3.576016878015625*^9}, {3.576016989421875*^9, 3.576016989640625*^9}, 
   3.576019353875*^9, {3.57601942634375*^9, 3.576019478078125*^9}, 
   3.576019566390625*^9, 3.57602039125*^9, 3.576021216734375*^9, 
   3.576021253734375*^9, 3.576021287890625*^9, {3.576021357171875*^9, 
   3.576021359265625*^9}, {3.576021547875*^9, 3.57602156725*^9}, {
   3.576021772375*^9, 3.576021774890625*^9}, {3.576021820546875*^9, 
   3.576021838265625*^9}, {3.576021906734375*^9, 3.576021908375*^9}, {
   3.57602563*^9, 3.576025657859375*^9}, {3.576025741171875*^9, 
   3.576025741640625*^9}, 3.576027649109375*^9, 3.576028666359375*^9, {
   3.57602968134375*^9, 3.576029683234375*^9}, 3.576029722984375*^9, 
   3.5760927035625*^9, 3.576136402734375*^9, 3.5761365664375*^9, 
   3.576136715828125*^9, {3.576136830171875*^9, 3.5761368534375*^9}, 
   3.576137037171875*^9, 3.576137229125*^9, 3.57613784128125*^9, {
   3.576138925984375*^9, 3.57613892678125*^9}, 3.5761389585625*^9, 
   3.57613910240625*^9, 3.57613932696875*^9, 3.576139382421875*^9, 
   3.576139418265625*^9, {3.576139545890625*^9, 3.576139567515625*^9}, 
   3.576139600515625*^9, 3.576139743921875*^9, 3.576177325875*^9, 
   3.57617753659375*^9, {3.576177631484375*^9, 3.576177656796875*^9}, 
   3.576202725462051*^9, {3.576202931869394*^9, 3.576202932181872*^9}, 
   3.57620392053125*^9, 3.576204006375*^9, {3.576204067171875*^9, 
   3.576204067421875*^9}, {3.576204108421875*^9, 3.57620412046875*^9}, 
   3.576204172671875*^9, {3.57621119121875*^9, 3.576211205578125*^9}, {
   3.576211503109375*^9, 3.576211513265625*^9}, {3.576212446421875*^9, 
   3.576212454578125*^9}, {3.576212553421875*^9, 3.576212573375*^9}, 
   3.57621351653125*^9, 3.57622103296875*^9, 3.576221410765625*^9, {
   3.5762250663125*^9, 3.576225066484375*^9}, 3.5762251535*^9, {
   3.576225216328125*^9, 3.57622521675*^9}, 3.576225394390625*^9, 
   3.576225439875*^9, 3.57622549146875*^9, 3.57622554153125*^9, {
   3.576225649609375*^9, 3.57622564975*^9}, {3.5762257023125*^9, 
   3.576225732921875*^9}, 3.576225789140625*^9, 3.576225862578125*^9, 
   3.576226445234375*^9, 3.576262940609375*^9, 3.576262999578125*^9, 
   3.576277790486184*^9, {3.5762781591453695`*^9, 3.5762781593797264`*^9}, 
   3.576278199704754*^9, 3.5762782314993525`*^9, {3.576278496433825*^9, 
   3.5762785044801335`*^9}, 3.57627859536436*^9, 3.576278643939065*^9, {
   3.576278686560795*^9, 3.576278689794921*^9}, {3.5762940172391253`*^9, 
   3.576294038034536*^9}, {3.5762943767138166`*^9, 3.576294395681231*^9}, {
   3.576294544030162*^9, 3.57629454610814*^9}, 3.576294891724432*^9, {
   3.576294969687693*^9, 3.576295186156828*^9}, {3.5762952214668417`*^9, 
   3.57629526452631*^9}, {3.5762953587540507`*^9, 3.5762954097504606`*^9}, {
   3.576295454481686*^9, 3.5762955202114334`*^9}, 3.5763108510607495`*^9, 
   3.5763113328383055`*^9, 3.5763114651528735`*^9, 3.576311565521614*^9, 
   3.5763117035235076`*^9, 3.576311861872565*^9, 3.5763119167847056`*^9, 
   3.576311949114555*^9, 3.5763120425578995`*^9, 3.5763121119248667`*^9, {
   3.57635123878125*^9, 3.576351240125*^9}, 3.5763514879375*^9, {
   3.57635158665625*^9, 3.57635158684375*^9}, {3.576357261828125*^9, 
   3.5763572888125*^9}, {3.576357346*^9, 3.576357355*^9}, {3.5763574744375*^9,
    3.57635747775*^9}, {3.576357560265625*^9, 3.576357564296875*^9}, {
   3.576357656546875*^9, 3.576357674984375*^9}, 3.5763649221201067`*^9, {
   3.576365011113841*^9, 3.576365011395071*^9}, {3.5763705589224052`*^9, 
   3.576370586905526*^9}, {3.5763707938181314`*^9, 3.576370797396096*^9}, {
   3.5763752153611217`*^9, 3.5763752182049446`*^9}, {3.576375266112421*^9, 
   3.5763752662217984`*^9}, 3.576380204204919*^9, 3.576380282764402*^9, 
   3.5763803317156467`*^9, 3.576380384447997*^9, 3.5763804373209667`*^9, {
   3.576380526708159*^9, 3.576380553082146*^9}, {3.5764597346254997`*^9, 
   3.5764597515942497`*^9}, {3.5764604806723747`*^9, 
   3.5764604810629997`*^9}, {3.5764606888754997`*^9, 3.5764606894379997`*^9}, 
   3.5764608303442497`*^9, 3.5764611053286247`*^9, 3.576706666515625*^9, 
   3.57670674975*^9, {3.576706790703125*^9, 3.57670682053125*^9}, {
   3.576786197203125*^9, 3.576786197453125*^9}, {3.57678707728125*^9, 
   3.576787079640625*^9}, {3.576787147796875*^9, 3.576787148140625*^9}, {
   3.576789302578125*^9, 3.57678930425*^9}, {3.576790682140625*^9, 
   3.57679068478125*^9}, {3.576790921953125*^9, 3.576790925140625*^9}, {
   3.576791102125*^9, 3.576791102484375*^9}, {3.57679168178125*^9, 
   3.57679168196875*^9}, 3.57689672903125*^9, {3.576897008890625*^9, 
   3.576897028859375*^9}, 3.576897229609375*^9, {3.57696095865625*^9, 
   3.57696095909375*^9}, 3.576960997484375*^9}],

Cell["\<\
Define the reference point, which must be located inside the regular convex \
polygon\
\>", "Text",
 CellChangeTimes->{{3.557708311609375*^9, 3.55770833840625*^9}, {
   3.55779467246875*^9, 3.557794686109375*^9}, {3.5587406488125*^9, 
   3.558740650328125*^9}, {3.57583404484375*^9, 3.575834046875*^9}, {
   3.575834138578125*^9, 3.5758341395*^9}, {3.576025689546875*^9, 
   3.5760257773125*^9}, {3.57620772953125*^9, 3.57620776365625*^9}, {
   3.576221429265625*^9, 3.576221432734375*^9}, {3.576221476859375*^9, 
   3.5762214789375*^9}, 3.5762246*^9, {3.57635105703125*^9, 
   3.57635105790625*^9}, 3.5763512708125*^9, 3.576351577421875*^9},
 FontSize->20],

Cell[BoxData[{
 RowBox[{
  RowBox[{"x", "=", 
   RowBox[{"1", "/", "2"}]}], ";"}], "\n", 
 RowBox[{
  RowBox[{"y", "=", 
   RowBox[{
    RowBox[{"-", "1"}], "/", "2"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"ref", "=", 
   RowBox[{"{", 
    RowBox[{"x", ",", "y"}], "}"}]}], ";"}]}], "Input",
 CellChangeTimes->{
  3.57602866975*^9, 3.5760296945*^9, {3.576029725890625*^9, 
   3.576029740171875*^9}, {3.576032026765625*^9, 3.576032056515625*^9}, {
   3.5760321470625*^9, 3.576032148140625*^9}, 3.576032198859375*^9, {
   3.576032232921875*^9, 3.576032237515625*^9}, 3.576032280890625*^9, {
   3.576092767828125*^9, 3.57609279396875*^9}, {3.57613644921875*^9, 
   3.576136449546875*^9}, {3.57613650946875*^9, 3.5761365096875*^9}, {
   3.576136685328125*^9, 3.5761366858125*^9}, {3.576136718734375*^9, 
   3.576136755765625*^9}, {3.576136795125*^9, 3.5761367995*^9}, 
   3.576136842875*^9, {3.576136929234375*^9, 3.576136929578125*^9}, 
   3.57613700715625*^9, {3.57613706040625*^9, 3.57613707740625*^9}, {
   3.576137254671875*^9, 3.576137254875*^9}, {3.57613780175*^9, 
   3.57613783075*^9}, {3.5761378848125*^9, 3.576137885640625*^9}, 
   3.576137931765625*^9, {3.576137980515625*^9, 3.576137983828125*^9}, {
   3.5761389825*^9, 3.576139012078125*^9}, {3.5761393334375*^9, 
   3.576139336984375*^9}, {3.576139392265625*^9, 3.57613943865625*^9}, 
   3.576177308828125*^9, {3.57617745525*^9, 3.576177461*^9}, {
   3.576177538671875*^9, 3.576177571921875*^9}, 3.576202905902472*^9, {
   3.576202958992484*^9, 3.5762029628984594`*^9}, {3.5762040013125*^9, 
   3.576204025609375*^9}, {3.576204094328125*^9, 3.57620412771875*^9}, {
   3.576204227296875*^9, 3.576204230640625*^9}, {3.576212221796875*^9, 
   3.57621222546875*^9}, {3.576213629171875*^9, 3.5762136295*^9}, {
   3.57621368246875*^9, 3.576213683984375*^9}, {3.576214099546875*^9, 
   3.5762141231875*^9}, 3.576221035546875*^9, {3.576225069546875*^9, 
   3.576225069890625*^9}, {3.576225196546875*^9, 3.576225196734375*^9}, {
   3.57622524728125*^9, 3.57622524825*^9}, 3.5762254475*^9, {
   3.576225582421875*^9, 3.576225583609375*^9}, {3.576225642703125*^9, 
   3.576225645515625*^9}, {3.576225867203125*^9, 3.576225877515625*^9}, {
   3.576226450453125*^9, 3.576226452703125*^9}, {3.576262888265625*^9, 
   3.576262917390625*^9}, {3.576262970140625*^9, 3.5762629706875*^9}, 
   3.576263004875*^9, {3.5762783052754087`*^9, 3.5762783057285013`*^9}, 
   3.5762784161894746`*^9, {3.5762784697794514`*^9, 3.5762784699513144`*^9}, {
   3.5762785010741234`*^9, 3.576278501277234*^9}, 3.576278596739263*^9, 
   3.57627864522022*^9, {3.5762786934665146`*^9, 3.5762786964037886`*^9}, {
   3.576294385041355*^9, 3.576294385931917*^9}, {3.5762945488579464`*^9, 
   3.57629454959227*^9}, {3.576294608650612*^9, 3.5762946087756033`*^9}, 
   3.5762947496406856`*^9, {3.5762949537825627`*^9, 3.576294953954426*^9}, 
   3.5762950500414104`*^9, {3.576295164564598*^9, 3.5762951667988157`*^9}, 
   3.5762954143438873`*^9, {3.5763066302090445`*^9, 3.576306632237048*^9}, {
   3.576312115965098*^9, 3.5763121168621492`*^9}, 3.576351584328125*^9, 
   3.576351754625*^9, {3.57635726746875*^9, 3.57635730971875*^9}, {
   3.576357350546875*^9, 3.576357350921875*^9}, 3.57635748146875*^9, {
   3.576357677046875*^9, 3.576357677359375*^9}, 3.576370590077259*^9, {
   3.57637080031784*^9, 3.5763708005990777`*^9}, 3.576375221408151*^9, {
   3.5764605173129997`*^9, 3.5764605175942497`*^9}, {3.5764605717348747`*^9, 
   3.5764605777348747`*^9}, {3.5764606941411247`*^9, 
   3.5764606972348747`*^9}, {3.5764607705942497`*^9, 
   3.5764607709379997`*^9}, {3.5764608750473747`*^9, 3.5764608800942497`*^9}, 
   3.5764609166567497`*^9, {3.5764611130473747`*^9, 3.5764611168442497`*^9}, {
   3.576790927765625*^9, 3.57679092946875*^9}, {3.576895893046875*^9, 
   3.576895901140625*^9}, {3.57689593146875*^9, 3.57689593634375*^9}, {
   3.57689607675*^9, 3.57689608165625*^9}, {3.576896125765625*^9, 
   3.57689613115625*^9}, {3.5768970238125*^9, 3.576897046546875*^9}, {
   3.576897232390625*^9, 3.576897236046875*^9}, {3.57696100209375*^9, 
   3.576961015375*^9}, {3.5769611256875*^9, 3.576961127984375*^9}}],

Cell["\<\
Define the tolerance to account for finite numerical precision in distance \
calculations\
\>", "Text",
 CellChangeTimes->{{3.557708311609375*^9, 3.55770833840625*^9}, {
   3.55779467246875*^9, 3.557794686109375*^9}, {3.5587406488125*^9, 
   3.558740650328125*^9}, {3.57583404484375*^9, 3.575834046875*^9}, {
   3.575834138578125*^9, 3.5758341395*^9}, {3.576025689546875*^9, 
   3.5760257773125*^9}, {3.57620772953125*^9, 3.57620776365625*^9}, {
   3.576221429265625*^9, 3.576221432734375*^9}, {3.576221476859375*^9, 
   3.5762214789375*^9}, 3.5762246*^9, {3.57635105703125*^9, 
   3.57635105790625*^9}, {3.57635125740625*^9, 3.57635126809375*^9}, {
   3.576355157234375*^9, 3.57635516425*^9}, {3.5764603366567497`*^9, 
   3.5764603372973747`*^9}, {3.5764603979692497`*^9, 
   3.5764604196098747`*^9}, {3.5769608889375*^9, 3.5769608893125*^9}},
 FontSize->20],

Cell[BoxData[
 RowBox[{
  RowBox[{"tol", "=", 
   RowBox[{"1", "*", 
    SuperscriptBox["10", 
     RowBox[{"-", "10"}]]}]}], ";"}]], "Input",
 CellChangeTimes->{{3.5764604217036247`*^9, 3.5764604263286247`*^9}, {
  3.576899923234375*^9, 3.576899923515625*^9}}]
}, Open  ]],

Cell[CellGroupData[{

Cell["2. Characterise the polygon geometry: Section II in [1]", "Section",
 CellChangeTimes->{{3.5760260236875*^9, 3.576026050828125*^9}, 
   3.57602613696875*^9, {3.57609272621875*^9, 3.5760927274375*^9}, {
   3.576351228234375*^9, 3.57635122875*^9}, {3.576351308984375*^9, 
   3.576351314671875*^9}, {3.576355695296875*^9, 3.57635570053125*^9}}],

Cell["\<\
Find the polygon in-radius, side length, area, interior angle and the central \
angle: Equations (1) and (2) in [1]\
\>", "Text",
 CellChangeTimes->{{3.5758418839091253`*^9, 3.5758418945497503`*^9}, {
  3.576025790296875*^9, 3.576025807703125*^9}, {3.57602592696875*^9, 
  3.576025940359375*^9}, {3.576354129203125*^9, 3.57635415428125*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"inradius", " ", "=", " ", 
   RowBox[{"R", " ", 
    RowBox[{"Cos", "[", 
     FractionBox["\[Pi]", "L"], "]"}]}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"sidelength", " ", "=", " ", 
   RowBox[{"2", " ", "R", " ", 
    RowBox[{"Sin", "[", 
     FractionBox["\[Pi]", "L"], "]"}]}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{"area", "=", " ", 
  RowBox[{
   FractionBox["1", "2"], "L", " ", 
   SuperscriptBox["R", "2"], " ", 
   RowBox[{"Sin", "[", 
    FractionBox[
     RowBox[{"2", " ", "\[Pi]"}], "L"], "]"}]}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"\[Theta]", "=", 
   FractionBox[
    RowBox[{"\[Pi]", " ", 
     RowBox[{"(", 
      RowBox[{"L", "-", "2"}], ")"}]}], "L"]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"\[CurlyTheta]", "=", 
   FractionBox[
    RowBox[{"2", " ", "\[Pi]", " "}], "L"]}], ";"}]}], "Input",
 CellChangeTimes->{{3.5758416875497503`*^9, 3.5758417890497503`*^9}, {
   3.5758418383778753`*^9, 3.5758418772528753`*^9}, {3.5758425088935003`*^9, 
   3.5758425112841253`*^9}, {3.5758435184247503`*^9, 
   3.5758435354872503`*^9}, {3.5758440808466253`*^9, 3.5758440864872503`*^9}, 
   3.5758600707216253`*^9, 3.5758602424247503`*^9, {3.5758612222216253`*^9, 
   3.5758612239247503`*^9}, 3.575967815375*^9, 3.57601460309375*^9, 
   3.57602207565625*^9, {3.576025908140625*^9, 3.57602591909375*^9}, {
   3.576025956421875*^9, 3.576025974515625*^9}, 3.57617759428125*^9, 
   3.576177667390625*^9, 3.576190257046875*^9, 3.57620777371875*^9}],

Cell[BoxData["2"], "Output",
 CellChangeTimes->{
  3.576022081015625*^9, 3.576022304015625*^9, 3.5760223708125*^9, {
   3.576025108546875*^9, 3.576025129046875*^9}, {3.576025618328125*^9, 
   3.57602565940625*^9}, {3.576025960671875*^9, 3.57602597575*^9}, {
   3.576026099203125*^9, 3.576026122328125*^9}, 3.576027492828125*^9, 
   3.576027653296875*^9, 3.576028672765625*^9, {3.576029684765625*^9, 
   3.576029696859375*^9}, 3.576029741609375*^9, 3.5760303191875*^9, 
   3.5760305234375*^9, 3.5760319509375*^9, {3.576032031734375*^9, 
   3.576032058203125*^9}, 3.5760321498125*^9, 3.576032200640625*^9, 
   3.576032238875*^9, 3.576032282203125*^9, 3.5760927051875*^9, {
   3.576092769109375*^9, 3.576092795328125*^9}, 3.576135975078125*^9, 
   3.5761362083125*^9, 3.5761363654375*^9, 3.57613640475*^9, 
   3.576136451203125*^9, 3.57613651125*^9, 3.576136567984375*^9, 
   3.576136687390625*^9, {3.57613672728125*^9, 3.57613675728125*^9}, 
   3.576136801*^9, {3.57613683271875*^9, 3.57613685484375*^9}, 
   3.57613693065625*^9, {3.576137008640625*^9, 3.57613706203125*^9}, 
   3.576137095390625*^9, {3.57613723071875*^9, 3.5761372563125*^9}, 
   3.576137491625*^9, {3.576137785484375*^9, 3.5761378428125*^9}, 
   3.576137887046875*^9, 3.576137933265625*^9, 3.576137985296875*^9, 
   3.576138373015625*^9, 3.576138885734375*^9, 3.576138929015625*^9, {
   3.57613897284375*^9, 3.57613901853125*^9}, 3.576139077*^9, 
   3.576139110125*^9, 3.576139338515625*^9, {3.576139385046875*^9, 
   3.576139393546875*^9}, {3.5761394246875*^9, 3.576139440640625*^9}, {
   3.57613951990625*^9, 3.576139570828125*^9}, 3.576139602078125*^9, 
   3.5761397459375*^9, {3.57617730215625*^9, 3.5761773270625*^9}, 
   3.57617742490625*^9, 3.576177462265625*^9, {3.576177562046875*^9, 
   3.576177596421875*^9}, {3.576177636359375*^9, 3.576177668734375*^9}, 
   3.576186312875*^9, 3.576186415828125*^9, 3.576186572640625*^9, 
   3.576186605875*^9, 3.576186692109375*^9, 3.576187141484375*^9, {
   3.576187416125*^9, 3.576187428375*^9}, 3.57618778846875*^9, 3.576187881*^9,
    3.576188228265625*^9, 3.576189232875*^9, {3.576189330578125*^9, 
   3.576189353*^9}, 3.576190005953125*^9, 3.57619015265625*^9, {
   3.5761907781875*^9, 3.57619080765625*^9}, 3.57619083809375*^9, {
   3.57619094634375*^9, 3.576190963484375*^9}, 3.57620267626239*^9, 
   3.5762027303523316`*^9, 3.57620282248647*^9, 3.576202911402085*^9, {
   3.576202941978057*^9, 3.5762029702260685`*^9}, 3.576203066016199*^9, {
   3.576203896171875*^9, 3.57620394915625*^9}, {3.57620400775*^9, 
   3.576204069078125*^9}, {3.57620409925*^9, 3.576204130796875*^9}, 
   3.576204174125*^9, 3.576204232328125*^9, 3.576207972671875*^9, 
   3.5762108625625*^9, {3.5762109896875*^9, 3.576211001890625*^9}, {
   3.576211192546875*^9, 3.576211206890625*^9}, 3.576211342890625*^9, {
   3.5762115070625*^9, 3.576211514921875*^9}, 3.5762116945625*^9, 
   3.576211738*^9, 3.5762121824375*^9, 3.576212226671875*^9, 
   3.576212352265625*^9, 3.57621240809375*^9, {3.57621244765625*^9, 
   3.57621251034375*^9}, {3.576212556640625*^9, 3.576212576203125*^9}, {
   3.576212697640625*^9, 3.5762127335*^9}, 3.5762131023125*^9, 
   3.576213303359375*^9, 3.57621351778125*^9, 3.57621355271875*^9, {
   3.57621361765625*^9, 3.5762136306875*^9}, {3.57621367328125*^9, 
   3.576213703203125*^9}, 3.57621380590625*^9, 3.576213893765625*^9, 
   3.576213952984375*^9, 3.57621400834375*^9, {3.576214100875*^9, 
   3.576214124921875*^9}, 3.576220920953125*^9, 3.576221004421875*^9, 
   3.57622103715625*^9, 3.576221117578125*^9, 3.576221413609375*^9, 
   3.576221604078125*^9, 3.5762250714375*^9, 3.576225115609375*^9, 
   3.576225155453125*^9, 3.576225200296875*^9, 3.576225251421875*^9, 
   3.576225396*^9, 3.57622549528125*^9, 3.5762255456875*^9, 
   3.576225585171875*^9, 3.576225653828125*^9, 3.5762257058125*^9, 
   3.576225736546875*^9, 3.576225880765625*^9, 3.576226456296875*^9, {
   3.576262871203125*^9, 3.5762629433125*^9}, 3.57626297403125*^9, 
   3.5762630079375*^9, 3.576277798735551*^9, 3.576278162160763*^9, {
   3.576278205579303*^9, 3.5762782350772257`*^9}, 3.576278308759538*^9, 
   3.5762784182362056`*^9, 3.5762784727792406`*^9, 3.5762785128545437`*^9, 
   3.576278602035765*^9, 3.5762786491886654`*^9, 3.576278699747282*^9, 
   3.57629439804044*^9, 3.5762945538888426`*^9, 3.5762946119785023`*^9, 
   3.576294754109121*^9, 3.5762948959272614`*^9, {3.5762949409240932`*^9, 
   3.5762951901721697`*^9}, {3.5762952239979134`*^9, 3.576295267151125*^9}, {
   3.576295362206933*^9, 3.576295384142888*^9}, 3.576295417453043*^9, {
   3.576295457809577*^9, 3.5762955239299216`*^9}, 3.576306637790658*^9, 
   3.5763106202815495`*^9, 3.5763108580561495`*^9, 3.5763113386816397`*^9, 
   3.576311469359114*^9, 3.576311609733143*^9, 3.576311705855641*^9, 
   3.576311864373708*^9, 3.5763119197298737`*^9, 3.5763119762901087`*^9, 
   3.576312045600073*^9, 3.576312121439411*^9, 3.576350002453125*^9, 
   3.576351490734375*^9, 3.57635159025*^9, 3.576351757515625*^9, 
   3.576355441359375*^9, 3.576355743046875*^9, {3.576357292453125*^9, 
   3.576357317515625*^9}, 3.576357358015625*^9, 3.576357484640625*^9, 
   3.57635756734375*^9, 3.576357660484375*^9, 3.576357706078125*^9, 
   3.5763631278816705`*^9, 3.5763648630305166`*^9, 3.576364924854289*^9, 
   3.5763650144261074`*^9, 3.576365071422095*^9, 3.576370532970443*^9, {
   3.5763705637503138`*^9, 3.576370592608396*^9}, 3.5763708034739485`*^9, 
   3.5763752281895747`*^9, 3.576375269643761*^9, 3.5763754025838003`*^9, 
   3.576380148972665*^9, 3.576380208829741*^9, 3.5763802853736763`*^9, 
   3.576380334559288*^9, 3.5763803869010277`*^9, 3.5763804691166205`*^9, {
   3.5763805293018093`*^9, 3.5763805563007727`*^9}, {3.5764597380004997`*^9, 
   3.5764597597348747`*^9}, 3.5764601443911247`*^9, 3.5764604468129997`*^9, 
   3.5764604941411247`*^9, 3.5764605359379997`*^9, 3.5764605918911247`*^9, 
   3.5764607034223747`*^9, 3.5764607737973747`*^9, 3.5764608338129997`*^9, 
   3.5764608835629997`*^9, 3.5764609209223747`*^9, 3.5764610754223747`*^9, {
   3.5764611268911247`*^9, 3.5764611523442497`*^9}, 3.57670640553125*^9, {
   3.576706654671875*^9, 3.576706677171875*^9}, 3.576706754875*^9, {
   3.57670680153125*^9, 3.576706825328125*^9}, 3.57678565428125*^9, 
   3.576786201953125*^9, 3.576787085046875*^9, 3.576787161265625*^9, 
   3.576788344671875*^9, {3.5767892801875*^9, 3.576789307453125*^9}, 
   3.576789485953125*^9, 3.576789562484375*^9, 3.5767896253125*^9, 
   3.576790691625*^9, 3.57679093403125*^9, 3.576791107578125*^9, 
   3.57679168709375*^9, 3.576895905578125*^9, 3.576895951875*^9, 
   3.57689608553125*^9, 3.576896136375*^9, 3.57689637725*^9, 
   3.5768967349375*^9, {3.576897014578125*^9, 3.576897050984375*^9}, 
   3.5768971910625*^9, 3.57689724084375*^9, 3.57689989646875*^9, 
   3.576960963125*^9, 3.57696106596875*^9, 3.57696113796875*^9}]
}, Open  ]],

Cell["\<\
Find the coordinates of the polygon vertices; Loop from 0 to establish the \
first vertext at (R,0)\
\>", "Text",
 CellChangeTimes->{{3.575839347828125*^9, 3.575839355953125*^9}, {
  3.5758563512841253`*^9, 3.5758563674247503`*^9}, {3.576224695125*^9, 
  3.57622470753125*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"polygonvertices", "=", 
   RowBox[{"{", "}"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{"For", "[", 
  RowBox[{
   RowBox[{"l", "=", "0"}], ",", 
   RowBox[{"l", "<", "L"}], ",", 
   RowBox[{"l", "++"}], ",", 
   RowBox[{
    RowBox[{"AppendTo", "[", 
     RowBox[{"polygonvertices", ",", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"R", " ", 
         RowBox[{"Cos", "[", 
          RowBox[{"l", " ", "\[CurlyTheta]"}], "]"}]}], ",", 
        RowBox[{"R", " ", 
         RowBox[{"Sin", "[", 
          RowBox[{"l", " ", "\[CurlyTheta]"}], "]"}]}]}], "}"}]}], "]"}], 
    ";"}]}], "]"}], "\[IndentingNewLine]", "polygonvertices"}], "Input",
 CellChangeTimes->{{3.575838787609375*^9, 3.575838788125*^9}, {
   3.5758388525625*^9, 3.5758388530625*^9}, {3.57583936471875*^9, 
   3.57583938865625*^9}, 3.575839433015625*^9, {3.575839482453125*^9, 
   3.575839492*^9}, {3.5758398399375*^9, 3.57583984665625*^9}, {
   3.575839927921875*^9, 3.575839948859375*^9}, 3.57584008434375*^9, {
   3.57584074175*^9, 3.57584074228125*^9}, {3.57584099978125*^9, 
   3.575841001609375*^9}, {3.575841162640625*^9, 3.575841180203125*^9}, {
   3.5758415044872503`*^9, 3.5758415067685003`*^9}, {3.5758417765966253`*^9, 
   3.5758417812216253`*^9}, {3.5758418160810003`*^9, 
   3.5758418178310003`*^9}, {3.5758426555810003`*^9, 
   3.5758426778153753`*^9}, {3.5758429411747503`*^9, 3.5758429526903753`*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"1", ",", "0"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0", ",", "1"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "1"}], ",", "0"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0", ",", 
     RowBox[{"-", "1"}]}], "}"}]}], "}"}]], "Output",
 CellChangeTimes->{{3.57584100278125*^9, 3.575841030515625*^9}, 
   3.57584118259375*^9, 3.57584125625*^9, 3.5758413856122503`*^9, {
   3.5758415419716253`*^9, 3.5758415606435003`*^9}, {3.5758417841122503`*^9, 
   3.5758418213622503`*^9}, 3.5758424497216253`*^9, {3.5758424843466253`*^9, 
   3.5758425135966253`*^9}, 3.5758425669560003`*^9, 3.5758426453622503`*^9, 
   3.5758426984091253`*^9, 3.5758433159560003`*^9, 3.5758433552997503`*^9, 
   3.5758437472685003`*^9, {3.5758438835497503`*^9, 3.5758439277997503`*^9}, 
   3.5758440883935003`*^9, 3.5758443261747503`*^9, 3.5758443955185003`*^9, 
   3.5758444348622503`*^9, 3.5758457766278753`*^9, 3.5758460380966253`*^9, 
   3.5758460946903753`*^9, {3.5758468970966253`*^9, 3.5758469396435003`*^9}, 
   3.5758470312528753`*^9, 3.5758470654560003`*^9, {3.5758471580497503`*^9, 
   3.5758471775966253`*^9}, 3.5758472617060003`*^9, 3.5758473001747503`*^9, 
   3.5758473918935003`*^9, 3.5758476717216253`*^9, 3.5758477486278753`*^9, 
   3.5758486030653753`*^9, 3.5758486552841253`*^9, 3.5758488585966253`*^9, 
   3.5758490065185003`*^9, 3.5758569504872503`*^9, {3.5758570418466253`*^9, 
   3.5758570580497503`*^9}, 3.5758572759247503`*^9, {3.5758573626591253`*^9, 
   3.5758573889716253`*^9}, 3.5758574708778753`*^9, 3.5758575736591253`*^9, 
   3.5758576143935003`*^9, 3.5758578028310003`*^9, 3.5758578653622503`*^9, 
   3.5758579225497503`*^9, {3.5758579643466253`*^9, 3.5758579902997503`*^9}, {
   3.5758583039403753`*^9, 3.5758583354716253`*^9}, {3.5758586284247503`*^9, 
   3.5758586734247503`*^9}, 3.5758594010653753`*^9, 3.5758594470028753`*^9, 
   3.5758595046903753`*^9, {3.5758597358466253`*^9, 3.5758597650966253`*^9}, {
   3.5758597990653753`*^9, 3.5758598220653753`*^9}, 3.5758598611747503`*^9, 
   3.5758600093935003`*^9, {3.5758600632528753`*^9, 3.5758600838622503`*^9}, 
   3.5758601467997503`*^9, {3.5758602037060003`*^9, 3.5758602564872503`*^9}, 
   3.5758608193153753`*^9, 3.5758608574716253`*^9, 3.5758610893622503`*^9, 
   3.5758611583466253`*^9, 3.5758612284247503`*^9, 3.5758612598310003`*^9, 
   3.575934533875*^9, 3.57593458065625*^9, 3.575941398140625*^9, 
   3.57594146296875*^9, 3.575941835453125*^9, 3.575941888078125*^9, 
   3.575945409625*^9, 3.575946444921875*^9, 3.57594649840625*^9, 
   3.575948339890625*^9, 3.575948496578125*^9, 3.575948728921875*^9, {
   3.57594898040625*^9, 3.575948991984375*^9}, 3.57594903325*^9, 
   3.575949115703125*^9, 3.575949155640625*^9, 3.575949251015625*^9, 
   3.575949350671875*^9, {3.575949388359375*^9, 3.57594941734375*^9}, 
   3.5759495165*^9, 3.57594971078125*^9, {3.575949776546875*^9, 
   3.57594979434375*^9}, 3.5759518016875*^9, 3.57595201125*^9, 
   3.575952258515625*^9, 3.575952311703125*^9, 3.575953898390625*^9, {
   3.575953993296875*^9, 3.57595401328125*^9}, 3.57595407771875*^9, 
   3.575954155234375*^9, 3.57595502959375*^9, 3.57595568559375*^9, 
   3.57595574596875*^9, 3.575955977015625*^9, 3.575956028375*^9, 
   3.5759563530625*^9, 3.5759565219375*^9, 3.57595679515625*^9, 
   3.575956899359375*^9, 3.5759569669375*^9, {3.5759570733125*^9, 
   3.575957093890625*^9}, 3.575957139734375*^9, {3.57595731953125*^9, 
   3.575957333046875*^9}, 3.5759573639375*^9, {3.57596074084375*^9, 
   3.57596075459375*^9}, 3.57596090459375*^9, 3.575961214515625*^9, 
   3.5759612939375*^9, {3.575961432515625*^9, 3.57596144009375*^9}, 
   3.575961528796875*^9, {3.575961610265625*^9, 3.575961636953125*^9}, 
   3.575961919890625*^9, 3.57596195228125*^9, {3.575963163125*^9, 
   3.575963183484375*^9}, 3.57596335953125*^9, 3.575963440609375*^9, {
   3.575963645125*^9, 3.575963674515625*^9}, 3.575963829375*^9, 
   3.575963871953125*^9, 3.575963954328125*^9, 3.575963985453125*^9, 
   3.57596446553125*^9, {3.575964585734375*^9, 3.57596460478125*^9}, 
   3.5759650146875*^9, 3.575965213234375*^9, 3.57596589434375*^9, 
   3.575965966828125*^9, 3.575966112984375*^9, 3.575966185171875*^9, 
   3.575966401203125*^9, 3.5759664430625*^9, 3.575966948359375*^9, 
   3.575967033953125*^9, 3.575967551484375*^9, 3.5759678169375*^9, 
   3.575967853796875*^9, 3.5759685070625*^9, 3.575968591265625*^9, 
   3.575968622859375*^9, {3.575969249*^9, 3.575969260875*^9}, 
   3.57596930859375*^9, 3.575969350875*^9, 3.575969626453125*^9, 
   3.575969763359375*^9, {3.575969979734375*^9, 3.57597002028125*^9}, {
   3.57597020221875*^9, 3.57597020678125*^9}, 3.5759703934375*^9, 
   3.57597043259375*^9, 3.575970506359375*^9, 3.5760023729375*^9, 
   3.5760029798125*^9, 3.576003110890625*^9, 3.576003984359375*^9, 
   3.57600528340625*^9, 3.57600718740625*^9, 3.57600813075*^9, 
   3.576008243453125*^9, 3.5760083004375*^9, 3.57600834959375*^9, 
   3.57600869059375*^9, 3.57600881365625*^9, {3.576009293078125*^9, 
   3.576009299890625*^9}, 3.576012860140625*^9, 3.576013185328125*^9, 
   3.5760132291875*^9, 3.576013276296875*^9, 3.57601356153125*^9, 
   3.57601361496875*^9, 3.5760137899375*^9, {3.576014332203125*^9, 
   3.576014341671875*^9}, 3.576014373890625*^9, 3.5760147744375*^9, 
   3.576014832859375*^9, {3.576014964328125*^9, 3.576014979015625*^9}, 
   3.57601570778125*^9, 3.5760159418125*^9, 3.576016617546875*^9, 
   3.576016813671875*^9, 3.576016920859375*^9, 3.576016991703125*^9, {
   3.576017051625*^9, 3.576017059953125*^9}, 3.576019077*^9, 
   3.57601919784375*^9, 3.57601935809375*^9, 3.57601947959375*^9, 
   3.576019568078125*^9, 3.576019909828125*^9, 3.5760203965*^9, 
   3.576020533453125*^9, 3.57602061328125*^9, 3.576020800546875*^9, {
   3.576021218375*^9, 3.576021255265625*^9}, 3.57602128915625*^9, 
   3.5760213625625*^9, 3.57602149090625*^9, {3.57602155521875*^9, 
   3.576021570640625*^9}, 3.57602177659375*^9, {3.576021822015625*^9, 
   3.5760218401875*^9}, 3.57602191*^9, 3.5760223040625*^9, 
   3.576022370859375*^9, {3.576025108625*^9, 3.576025129125*^9}, {
   3.5760256184375*^9, 3.576025659484375*^9}, {3.57602596075*^9, 
   3.5760259758125*^9}, {3.57602609921875*^9, 3.576026122375*^9}, 
   3.57602749284375*^9, 3.576027653328125*^9, 3.57602867278125*^9, {
   3.576029684796875*^9, 3.576029696890625*^9}, 3.576029741625*^9, 
   3.576030319234375*^9, 3.576030523484375*^9, 3.576031950953125*^9, {
   3.57603203175*^9, 3.57603205821875*^9}, 3.576032149828125*^9, 
   3.57603220065625*^9, 3.576032238890625*^9, 3.57603228221875*^9, 
   3.57609270521875*^9, {3.576092769140625*^9, 3.57609279534375*^9}, 
   3.576135975109375*^9, 3.576136208375*^9, 3.57613636546875*^9, 
   3.57613640478125*^9, 3.57613645125*^9, 3.576136511265625*^9, 
   3.576136568015625*^9, 3.5761366874375*^9, {3.5761367273125*^9, 
   3.576136757296875*^9}, 3.57613680103125*^9, {3.576136832734375*^9, 
   3.576136854890625*^9}, 3.576136930703125*^9, {3.5761370086875*^9, 
   3.5761370620625*^9}, 3.5761370954375*^9, {3.57613723075*^9, 
   3.57613725634375*^9}, 3.5761374916875*^9, {3.57613778553125*^9, 
   3.576137842828125*^9}, 3.576137887078125*^9, 3.576137933296875*^9, 
   3.576137985328125*^9, 3.5761383730625*^9, 3.576138885796875*^9, 
   3.576138929046875*^9, {3.576138972890625*^9, 3.5761390185625*^9}, 
   3.5761390770625*^9, 3.57613911015625*^9, 3.576139338546875*^9, {
   3.576139385078125*^9, 3.57613939359375*^9}, {3.57613942471875*^9, 
   3.5761394406875*^9}, {3.5761395199375*^9, 3.576139570859375*^9}, 
   3.576139602109375*^9, 3.57613974596875*^9, {3.5761773021875*^9, 
   3.576177327078125*^9}, 3.576177424921875*^9, 3.576177462296875*^9, {
   3.57617756209375*^9, 3.576177596453125*^9}, {3.576177636390625*^9, 
   3.576177668765625*^9}, 3.576186312921875*^9, 3.576186415875*^9, 
   3.576186572703125*^9, 3.576186605953125*^9, 3.576186692171875*^9, 
   3.57618714153125*^9, {3.5761874161875*^9, 3.576187428421875*^9}, 
   3.576187788515625*^9, 3.576187881046875*^9, 3.5761882283125*^9, 
   3.576189232921875*^9, {3.576189330625*^9, 3.5761893530625*^9}, 
   3.576190006*^9, 3.576190152703125*^9, {3.576190778234375*^9, 
   3.576190807703125*^9}, 3.57619083815625*^9, {3.576190946390625*^9, 
   3.57619096353125*^9}, 3.5762026775747976`*^9, 3.576202732117832*^9, 
   3.5762028234395275`*^9, {3.5762029127301164`*^9, 3.5762029702416925`*^9}, 
   3.576203066047447*^9, {3.5762038961875*^9, 3.576203949171875*^9}, {
   3.57620400778125*^9, 3.57620406909375*^9}, {3.576204099265625*^9, 
   3.5762041308125*^9}, 3.576204174140625*^9, 3.576204232359375*^9, 
   3.576207972703125*^9, 3.576210862625*^9, {3.57621098971875*^9, 
   3.576211001921875*^9}, {3.576211192578125*^9, 3.57621120690625*^9}, 
   3.576211342921875*^9, {3.576211507109375*^9, 3.576211514953125*^9}, 
   3.57621169459375*^9, 3.57621173803125*^9, 3.57621218246875*^9, 
   3.5762122266875*^9, 3.57621235228125*^9, 3.576212408125*^9, {
   3.576212447671875*^9, 3.576212510375*^9}, {3.576212556671875*^9, 
   3.576212576234375*^9}, {3.576212697671875*^9, 3.57621273353125*^9}, 
   3.576213102328125*^9, 3.576213303375*^9, 3.576213517796875*^9, 
   3.57621355275*^9, {3.5762136176875*^9, 3.57621363071875*^9}, {
   3.576213673296875*^9, 3.57621370321875*^9}, 3.5762138059375*^9, 
   3.57621389378125*^9, 3.576213953015625*^9, 3.576214008359375*^9, {
   3.576214100890625*^9, 3.5762141249375*^9}, 3.576220920984375*^9, 
   3.5762210044375*^9, 3.576221037171875*^9, 3.57622111759375*^9, 
   3.576221413625*^9, 3.576221604109375*^9, 3.576225071453125*^9, 
   3.576225115640625*^9, 3.576225155484375*^9, 3.5762252003125*^9, 
   3.576225251453125*^9, 3.576225396046875*^9, 3.5762254953125*^9, 
   3.57622554571875*^9, 3.576225585203125*^9, 3.576225653875*^9, 
   3.57622570584375*^9, 3.57622573659375*^9, 3.57622588078125*^9, 
   3.5762264563125*^9, {3.57626287125*^9, 3.57626294334375*^9}, 
   3.5762629740625*^9, 3.57626300796875*^9, 3.5762778014853396`*^9, 
   3.5762781634106665`*^9, 3.576278205594927*^9, 3.576278236452129*^9, 
   3.57627831121249*^9, 3.576278419923587*^9, 3.5762784740604*^9, 
   3.576278515026266*^9, 3.576278603473164*^9, 3.576278650829164*^9, 
   3.5762787011378*^9, 3.5762943994153433`*^9, 3.576294555419985*^9, 
   3.5762946132440386`*^9, 3.576294754124745*^9, 3.5762948959428854`*^9, {
   3.5762949409397173`*^9, 3.5762951901877937`*^9}, {3.5762952240135374`*^9, 
   3.576295267182373*^9}, {3.576295362222557*^9, 3.576295384158512*^9}, 
   3.576295417468667*^9, {3.576295457840825*^9, 3.5762955239455457`*^9}, 
   3.576306639459861*^9, 3.5763106219336443`*^9, 3.576310859482231*^9, 
   3.5763113410657763`*^9, 3.5763114694061165`*^9, 3.5763116098031473`*^9, 
   3.5763117059086437`*^9, 3.57631186441271*^9, 3.5763119197848773`*^9, 
   3.5763119763511124`*^9, 3.5763120456700773`*^9, 3.576312121491414*^9, 
   3.57635000246875*^9, 3.576351490765625*^9, 3.57635159028125*^9, 
   3.576351757546875*^9, 3.576355441390625*^9, 3.576355743078125*^9, {
   3.57635729246875*^9, 3.57635731753125*^9}, 3.57635735803125*^9, 
   3.576357484671875*^9, 3.576357567359375*^9, 3.5763576605*^9, 
   3.576357706125*^9, 3.5763631292409763`*^9, 3.5763648630461407`*^9, 
   3.576364924869913*^9, 3.5763650144417315`*^9, 3.57636507340633*^9, {
   3.5763705637503138`*^9, 3.576370592608396*^9}, 3.5763708035051975`*^9, 
   3.5763752282052*^9, 3.5763752696593866`*^9, 3.5763754025994253`*^9, 
   3.576380148988289*^9, 3.576380208829741*^9, 3.5763802853893013`*^9, 
   3.576380334574912*^9, 3.576380386916652*^9, 3.576380469132245*^9, {
   3.5763805293018093`*^9, 3.5763805563007727`*^9}, {3.5764597380161247`*^9, 
   3.5764597597504997`*^9}, 3.5764601444223747`*^9, 3.5764604468286247`*^9, 
   3.5764604941723747`*^9, 3.5764605359692497`*^9, 3.5764605919067497`*^9, 
   3.5764607034379997`*^9, 3.5764607738286247`*^9, 3.5764608338286247`*^9, 
   3.5764608835786247`*^9, 3.5764609209379997`*^9, 3.5764610754848747`*^9, {
   3.5764611269223747`*^9, 3.5764611523754997`*^9}, 3.576706405546875*^9, {
   3.576706654734375*^9, 3.57670667721875*^9}, 3.576706754890625*^9, {
   3.5767068015625*^9, 3.57670682534375*^9}, 3.576785654328125*^9, 
   3.576786202*^9, 3.57678708509375*^9, 3.576787161296875*^9, 
   3.57678834471875*^9, {3.57678928021875*^9, 3.5767893075*^9}, 
   3.576789486*^9, 3.576789562515625*^9, 3.57678962534375*^9, 
   3.57679069165625*^9, 3.576790934078125*^9, 3.576791107625*^9, 
   3.576791687125*^9, 3.576895905609375*^9, 3.576895951890625*^9, 
   3.5768960855625*^9, 3.57689613640625*^9, 3.576896377265625*^9, 
   3.576896734953125*^9, {3.576897014609375*^9, 3.576897051015625*^9}, 
   3.57689719109375*^9, 3.576897240875*^9, 3.576899896515625*^9, 
   3.57696096315625*^9, 3.576961066*^9, 3.576961137984375*^9}]
}, Open  ]],

Cell["Plot the polygon and the reference point", "Text",
 CellChangeTimes->{{3.575839347828125*^9, 3.575839355953125*^9}, {
   3.575840777578125*^9, 3.575840778859375*^9}, {3.575841388171875*^9, 
   3.5758413960625*^9}, {3.5758418238935003`*^9, 3.5758418262997503`*^9}, {
   3.57602608384375*^9, 3.5760260849375*^9}, {3.576207784796875*^9, 
   3.5762078048125*^9}, 3.5762214624375*^9, {3.576351344375*^9, 
   3.5763513445625*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Graphics", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"Yellow", ",", 
     RowBox[{"Polygon", "[", "polygonvertices", "]"}], ",", 
     "\[IndentingNewLine]", "Red", ",", "Dashed", ",", 
     RowBox[{"Circle", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0", ",", "0"}], "}"}], ",", "R"}], "]"}], ",", 
     "\[IndentingNewLine]", "Red", ",", "Dashed", ",", 
     RowBox[{"Line", "[", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"-", "R"}], ",", "0"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"R", ",", "0"}], "}"}]}], "}"}], "]"}], ",", 
     "\[IndentingNewLine]", "Red", ",", "Dashed", ",", 
     RowBox[{"Line", "[", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"0", ",", "R"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"0", ",", 
          RowBox[{"-", "R"}]}], "}"}]}], "}"}], "]"}], ",", 
     "\[IndentingNewLine]", "Blue", ",", 
     RowBox[{"PointSize", "[", "Large", "]"}], ",", 
     RowBox[{"Point", "[", "ref", "]"}]}], "}"}], ",", 
   RowBox[{"Frame", "\[Rule]", " ", "True"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.5758401700625*^9, 3.575840187671875*^9}, {
  3.575840256390625*^9, 3.575840309015625*^9}, {3.575840350578125*^9, 
  3.5758403509375*^9}, {3.575840431921875*^9, 3.575840475921875*^9}, {
  3.57584052753125*^9, 3.575840587640625*^9}, {3.575840621359375*^9, 
  3.575840714296875*^9}, {3.575840835765625*^9, 3.57584089559375*^9}, {
  3.575840942125*^9, 3.57584095534375*^9}, {3.57584122596875*^9, 
  3.57584123465625*^9}, {3.5758413008125*^9, 3.575841303328125*^9}, {
  3.575841374109375*^9, 3.57584138284375*^9}, {3.5758415243153753`*^9, 
  3.5758415257060003`*^9}, {3.5758426824872503`*^9, 3.5758426964716253`*^9}, {
  3.575934566359375*^9, 3.575934575921875*^9}}],

Cell[BoxData[
 GraphicsBox[{
   {RGBColor[1, 1, 0], PolygonBox[{{1, 0}, {0, 1}, {-1, 0}, {0, -1}}]}, 
   {RGBColor[1, 0, 0], Dashing[{Small, Small}], CircleBox[{0, 0}]}, 
   {RGBColor[1, 0, 0], Dashing[{Small, Small}], LineBox[{{-1, 0}, {1, 0}}]}, 
   {RGBColor[1, 0, 0], Dashing[{Small, Small}], LineBox[{{0, 1}, {0, -1}}], 
    {RGBColor[0, 0, 1], PointSize[Large], 
     PointBox[NCache[{Rational[1, 2], Rational[-1, 2]}, {0.5, -0.5}]]}}},
  Frame->True]], "Output",
 CellChangeTimes->{
  3.575840957421875*^9, 3.575840991671875*^9, 3.575841035171875*^9, 
   3.57584118734375*^9, {3.575841229515625*^9, 3.5758412598125*^9}, 
   3.575841306875*^9, {3.5758413765625*^9, 3.5758413919091253`*^9}, {
   3.5758415467060003`*^9, 3.5758415606903753`*^9}, {3.5758418091435003`*^9, 
   3.5758418289091253`*^9}, 3.5758424498310003`*^9, {3.5758424844403753`*^9, 
   3.5758425137372503`*^9}, 3.5758425669872503`*^9, 3.5758426453935003`*^9, 
   3.5758426984560003`*^9, 3.5758433160028753`*^9, 3.5758433553310003`*^9, 
   3.5758437472997503`*^9, {3.5758438835966253`*^9, 3.5758439278310003`*^9}, 
   3.5758440884247503`*^9, 3.5758443262060003`*^9, 3.5758443955497503`*^9, 
   3.5758444348935003`*^9, 3.5758457766591253`*^9, 3.5758460381278753`*^9, 
   3.5758460947216253`*^9, {3.5758468971435003`*^9, 3.5758469396903753`*^9}, 
   3.5758470312685003`*^9, 3.5758470655028753`*^9, {3.5758471580810003`*^9, 
   3.5758471776435003`*^9}, 3.5758472617372503`*^9, 3.5758473001903753`*^9, 
   3.5758473919247503`*^9, 3.5758476717528753`*^9, 3.5758477486747503`*^9, 
   3.5758486031122503`*^9, 3.5758486553153753`*^9, 3.5758488586278753`*^9, 
   3.5758490065497503`*^9, 3.5758569505185003`*^9, {3.5758570418778753`*^9, 
   3.5758570580653753`*^9}, 3.5758572759716253`*^9, {3.5758573626903753`*^9, 
   3.5758573890028753`*^9}, 3.5758574709091253`*^9, 3.5758575736903753`*^9, 
   3.5758576144247503`*^9, 3.5758578028466253`*^9, 3.5758578654091253`*^9, 
   3.5758579225966253`*^9, {3.5758579643778753`*^9, 3.5758579903310003`*^9}, {
   3.5758583039872503`*^9, 3.5758583354872503`*^9}, {3.5758586284716253`*^9, 
   3.5758586734560003`*^9}, 3.5758594010966253`*^9, 3.5758594470497503`*^9, 
   3.5758595047216253`*^9, {3.5758597358778753`*^9, 3.5758597651278753`*^9}, {
   3.5758597990810003`*^9, 3.5758598220810003`*^9}, 3.5758598612060003`*^9, 
   3.5758600094247503`*^9, {3.5758600632997503`*^9, 3.5758600838935003`*^9}, 
   3.5758601468310003`*^9, {3.5758602037372503`*^9, 3.5758602565341253`*^9}, 
   3.5758608193466253`*^9, 3.5758608575028753`*^9, 3.5758610893778753`*^9, 
   3.5758611583778753`*^9, 3.5758612284403753`*^9, 3.5758612598622503`*^9, 
   3.575934533921875*^9, 3.575934580671875*^9, 3.575941398171875*^9, 
   3.575941463*^9, 3.57594183546875*^9, 3.575941888109375*^9, 
   3.575945409671875*^9, 3.575946444953125*^9, 3.5759464984375*^9, 
   3.575948339921875*^9, 3.575948496625*^9, 3.575948728953125*^9, {
   3.575948980453125*^9, 3.57594899203125*^9}, 3.57594903328125*^9, 
   3.57594911575*^9, 3.575949155671875*^9, 3.575949251046875*^9, 
   3.575949350703125*^9, {3.575949388390625*^9, 3.575949417375*^9}, 
   3.57594951653125*^9, 3.575949710796875*^9, {3.575949776578125*^9, 
   3.575949794390625*^9}, 3.57595180171875*^9, 3.575952011296875*^9, 
   3.57595225853125*^9, 3.575952311734375*^9, 3.57595389840625*^9, {
   3.575953993328125*^9, 3.5759540133125*^9}, 3.575954077765625*^9, 
   3.57595415528125*^9, 3.575955029640625*^9, 3.575955685640625*^9, 
   3.575955746*^9, 3.575955977046875*^9, 3.575956028421875*^9, 
   3.57595635309375*^9, 3.57595652196875*^9, 3.5759567951875*^9, 
   3.57595689940625*^9, 3.57595696696875*^9, {3.57595707334375*^9, 
   3.575957093921875*^9}, 3.575957139765625*^9, {3.5759573195625*^9, 
   3.575957333078125*^9}, 3.57595736396875*^9, {3.575960740890625*^9, 
   3.575960754640625*^9}, 3.575960904640625*^9, 3.5759612145625*^9, 
   3.57596129396875*^9, {3.5759614325625*^9, 3.575961440140625*^9}, 
   3.575961528828125*^9, {3.575961610296875*^9, 3.575961637*^9}, 
   3.575961919921875*^9, 3.575961952328125*^9, {3.57596316315625*^9, 
   3.57596318353125*^9}, 3.5759633595625*^9, 3.575963440640625*^9, {
   3.575963645171875*^9, 3.575963674546875*^9}, 3.575963829421875*^9, 
   3.575963872*^9, 3.575963954390625*^9, 3.57596398553125*^9, 
   3.57596446559375*^9, {3.575964585765625*^9, 3.57596460484375*^9}, 
   3.57596501471875*^9, 3.575965213265625*^9, 3.575965894375*^9, 
   3.57596596690625*^9, 3.575966113015625*^9, 3.5759661851875*^9, 
   3.575966401234375*^9, 3.57596644309375*^9, 3.575966948390625*^9, 
   3.575967033984375*^9, 3.575967551515625*^9, 3.575967816984375*^9, 
   3.57596785384375*^9, 3.57596850709375*^9, 3.575968591296875*^9, 
   3.57596862290625*^9, {3.57596924903125*^9, 3.575969260921875*^9}, 
   3.575969308625*^9, 3.575969350921875*^9, 3.575969626484375*^9, 
   3.575969763390625*^9, {3.57596997978125*^9, 3.5759700203125*^9}, {
   3.575970202265625*^9, 3.575970206828125*^9}, 3.575970393484375*^9, 
   3.575970432625*^9, 3.57597050640625*^9, 3.576002372984375*^9, 
   3.576002979875*^9, 3.576003110953125*^9, 3.576003984421875*^9, 
   3.57600528346875*^9, 3.5760071874375*^9, 3.576008130796875*^9, 
   3.576008243546875*^9, 3.576008300484375*^9, 3.576008349671875*^9, 
   3.57600869065625*^9, 3.5760088136875*^9, {3.576009293125*^9, 
   3.576009299953125*^9}, 3.576012860171875*^9, 3.576013185375*^9, 
   3.57601322925*^9, 3.57601327634375*^9, 3.5760135615625*^9, 3.576013615*^9, 
   3.57601379*^9, {3.57601433225*^9, 3.576014341703125*^9}, 
   3.576014373921875*^9, 3.576014774484375*^9, 3.576014832890625*^9, {
   3.576014964359375*^9, 3.576014979109375*^9}, 3.576015707828125*^9, 
   3.576015941859375*^9, 3.576016617625*^9, 3.576016813734375*^9, 
   3.57601692090625*^9, 3.576016991734375*^9, {3.57601705165625*^9, 
   3.57601706003125*^9}, 3.576019077046875*^9, 3.576019197890625*^9, 
   3.576019358140625*^9, 3.576019479640625*^9, 3.576019568109375*^9, 
   3.576019909875*^9, 3.57602039653125*^9, 3.5760205335*^9, 
   3.5760206133125*^9, 3.57602080059375*^9, {3.57602121840625*^9, 
   3.576021255296875*^9}, 3.5760212891875*^9, 3.57602136259375*^9, 
   3.5760214909375*^9, {3.57602155525*^9, 3.576021570671875*^9}, 
   3.576021776640625*^9, {3.576021822046875*^9, 3.57602184021875*^9}, 
   3.57602191003125*^9, 3.57602230409375*^9, 3.576022370890625*^9, {
   3.576025108671875*^9, 3.57602512915625*^9}, {3.57602561846875*^9, 
   3.57602565953125*^9}, {3.57602596078125*^9, 3.576025975859375*^9}, {
   3.57602609925*^9, 3.57602612240625*^9}, 3.576027492890625*^9, 
   3.576027653375*^9, 3.5760286728125*^9, {3.576029684828125*^9, 
   3.576029696921875*^9}, 3.57602974165625*^9, 3.57603031928125*^9, 
   3.57603052353125*^9, 3.576031951*^9, {3.57603203178125*^9, 
   3.57603205825*^9}, 3.576032149875*^9, 3.5760322006875*^9, 
   3.576032238921875*^9, 3.57603228225*^9, 3.57609270525*^9, {
   3.5760927691875*^9, 3.576092795375*^9}, 3.57613597515625*^9, 
   3.57613620840625*^9, 3.576136365515625*^9, 3.57613640484375*^9, 
   3.57613645128125*^9, 3.576136511296875*^9, 3.576136568046875*^9, 
   3.57613668746875*^9, {3.576136727359375*^9, 3.576136757328125*^9}, 
   3.5761368010625*^9, {3.576136832765625*^9, 3.5761368549375*^9}, 
   3.57613693075*^9, {3.57613700875*^9, 3.57613706209375*^9}, 
   3.5761370955*^9, {3.576137230796875*^9, 3.576137256359375*^9}, 
   3.57613749175*^9, {3.576137785578125*^9, 3.576137842859375*^9}, 
   3.576137887125*^9, 3.57613793334375*^9, 3.576137985375*^9, 
   3.57613837309375*^9, 3.57613888584375*^9, 3.576138929078125*^9, {
   3.576138972921875*^9, 3.576139018609375*^9}, 3.576139077125*^9, 
   3.5761391101875*^9, 3.576139338578125*^9, {3.576139385109375*^9, 
   3.576139393640625*^9}, {3.57613942478125*^9, 3.57613944071875*^9}, {
   3.576139519984375*^9, 3.57613957090625*^9}, 3.576139602140625*^9, 
   3.576139746*^9, {3.576177302234375*^9, 3.576177327109375*^9}, 
   3.57617742496875*^9, 3.576177462328125*^9, {3.576177562125*^9, 
   3.5761775965*^9}, {3.576177636703125*^9, 3.576177668796875*^9}, 
   3.576186312953125*^9, 3.576186415953125*^9, 3.576186572796875*^9, 
   3.57618660603125*^9, 3.57618669225*^9, 3.57618714159375*^9, {
   3.576187416296875*^9, 3.576187428484375*^9}, 3.576187788578125*^9, 
   3.576187881125*^9, 3.576188228375*^9, 3.576189232984375*^9, {
   3.5761893306875*^9, 3.576189353125*^9}, 3.5761900060625*^9, 
   3.576190152765625*^9, {3.576190778296875*^9, 3.576190807765625*^9}, 
   3.57619083821875*^9, {3.576190946484375*^9, 3.57619096359375*^9}, 
   3.57620267902782*^9, 3.5762027333208723`*^9, 3.5762028245644484`*^9, {
   3.576202913605055*^9, 3.576202970257316*^9}, 3.576203066063071*^9, {
   3.576203896234375*^9, 3.576203949203125*^9}, {3.5762040078125*^9, 
   3.576204069140625*^9}, {3.57620409928125*^9, 3.57620413084375*^9}, 
   3.576204174171875*^9, 3.576204232390625*^9, 3.57620797275*^9, 
   3.576210862671875*^9, {3.576210989765625*^9, 3.57621100196875*^9}, {
   3.57621119259375*^9, 3.5762112069375*^9}, 3.576211342984375*^9, {
   3.57621150715625*^9, 3.576211514984375*^9}, 3.576211694625*^9, 
   3.5762117380625*^9, 3.576212182515625*^9, 3.57621222671875*^9, 
   3.5762123523125*^9, 3.576212408171875*^9, {3.57621244771875*^9, 
   3.576212510421875*^9}, {3.576212556703125*^9, 3.576212576265625*^9}, {
   3.576212697703125*^9, 3.576212733578125*^9}, 3.576213102359375*^9, 
   3.57621330340625*^9, 3.576213517828125*^9, 3.576213552796875*^9, {
   3.57621361771875*^9, 3.57621363075*^9}, {3.57621367334375*^9, 
   3.57621370325*^9}, 3.57621380596875*^9, 3.5762138938125*^9, 
   3.5762139530625*^9, 3.57621400840625*^9, {3.576214100921875*^9, 
   3.57621412496875*^9}, 3.576220921015625*^9, 3.576221004453125*^9, 
   3.576221037203125*^9, 3.576221117640625*^9, 3.57622141365625*^9, 
   3.576221604125*^9, 3.576225071484375*^9, 3.576225115703125*^9, 
   3.5762251555*^9, 3.576225200359375*^9, 3.5762252515*^9, 
   3.576225396109375*^9, 3.57622549534375*^9, 3.57622554575*^9, 
   3.57622558525*^9, 3.576225653890625*^9, 3.576225705890625*^9, 
   3.576225736640625*^9, 3.57622588084375*^9, 3.57622645634375*^9, {
   3.57626287134375*^9, 3.576262943390625*^9}, 3.576262974109375*^9, 
   3.576263008015625*^9, 3.576277803875781*^9, 3.5762781648949275`*^9, 
   3.5762782056105504`*^9, 3.5762782375770497`*^9, 3.576278312743633*^9, 
   3.5762784211891227`*^9, 3.5762784751228256`*^9, 3.5762785165574083`*^9, 
   3.576278604582461*^9, 3.57627865204782*^9, 3.5762787024189515`*^9, 
   3.5762944006027594`*^9, 3.5762945571073656`*^9, 3.5762946139939857`*^9, 
   3.5762947541403685`*^9, 3.5762948959741325`*^9, {3.5762949409553413`*^9, 
   3.576295190219042*^9}, {3.576295224060409*^9, 3.576295267197997*^9}, {
   3.576295362253804*^9, 3.57629538418976*^9}, 3.576295417499915*^9, {
   3.5762954578564487`*^9, 3.5762955239611692`*^9}, 3.5763066410510635`*^9, 
   3.5763106231587143`*^9, 3.5763108608833113`*^9, 3.576311342112836*^9, 
   3.576311469474121*^9, 3.576311609907153*^9, 3.5763117059826484`*^9, 
   3.576311864473714*^9, 3.576311919852881*^9, 3.576311976433117*^9, 
   3.576312045816086*^9, 3.576312121560418*^9, 3.576350002515625*^9, 
   3.576351490828125*^9, 3.5763515903125*^9, 3.576351757578125*^9, 
   3.5763554414375*^9, 3.576355743125*^9, {3.576357292484375*^9, 
   3.5763573175625*^9}, 3.5763573580625*^9, 3.576357484703125*^9, 
   3.576357567390625*^9, 3.576357660546875*^9, 3.57635770615625*^9, 
   3.5763631307721477`*^9, 3.5763648630773883`*^9, 3.5763649249011607`*^9, 
   3.5763650144573555`*^9, {3.5763705637659383`*^9, 3.5763705926240206`*^9}, 
   3.5763708035208216`*^9, 3.5763752282208257`*^9, 3.576375269675012*^9, 
   3.5763754026306744`*^9, 3.5763801490039134`*^9, 3.5763802088453655`*^9, 
   3.5763802854049253`*^9, 3.5763803345905366`*^9, 3.5763803869322767`*^9, 
   3.576380469147869*^9, {3.576380529317434*^9, 3.5763805563163967`*^9}, {
   3.5764597380473747`*^9, 3.5764597597661247`*^9}, 3.5764601444692497`*^9, 
   3.5764604468598747`*^9, 3.5764604942036247`*^9, 3.5764605360004997`*^9, 
   3.5764605919536247`*^9, 3.5764607035004997`*^9, 3.5764607738754997`*^9, 
   3.5764608338754997`*^9, 3.5764608836254997`*^9, 3.5764609209692497`*^9, 
   3.5764610755317497`*^9, {3.5764611269692497`*^9, 3.5764611531879997`*^9}, 
   3.57670640559375*^9, {3.576706654796875*^9, 3.576706677265625*^9}, 
   3.576706754921875*^9, {3.57670680159375*^9, 3.576706825375*^9}, 
   3.57678565440625*^9, 3.5767862020625*^9, 3.576787085171875*^9, 
   3.576787161359375*^9, 3.576788344765625*^9, {3.57678928028125*^9, 
   3.576789307546875*^9}, 3.57678948609375*^9, 3.576789562578125*^9, 
   3.57678962540625*^9, 3.57679069171875*^9, 3.576790934125*^9, 
   3.576791107671875*^9, 3.57679168715625*^9, 3.576895905671875*^9, 
   3.576895951953125*^9, 3.576896085609375*^9, 3.576896136453125*^9, 
   3.576896377296875*^9, 3.576896734984375*^9, {3.576897014640625*^9, 
   3.576897051078125*^9}, 3.576897191109375*^9, 3.57689724090625*^9, 
   3.576899896546875*^9, 3.5769609631875*^9, 3.576961066046875*^9, 
   3.576961138015625*^9}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
3. Define the distance calculation functions and then find the distances: \
Section II in [1]\
\>", "Section",
 CellChangeTimes->{{3.576026155828125*^9, 3.57602618475*^9}, {
  3.576092733046875*^9, 3.576092734078125*^9}, {3.576224732859375*^9, 
  3.576224733578125*^9}, {3.57635135425*^9, 3.57635136353125*^9}, {
  3.57635567440625*^9, 3.57635568528125*^9}}],

Cell["\<\
Rotation operator: Equations (3) and (4) in [1]\
\>", "Text",
 CellChangeTimes->{{3.5758575378935003`*^9, 3.5758575457997503`*^9}, {
  3.5759667716875*^9, 3.5759667735625*^9}, {3.576026180546875*^9, 
  3.5760262041875*^9}, {3.576354178203125*^9, 3.5763541866875*^9}}],

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"Rotx", "[", "l_", "]"}], ":=", 
   RowBox[{
    RowBox[{
     RowBox[{"Cos", "[", 
      RowBox[{"l", " ", "\[CurlyTheta]"}], "]"}], " ", "x"}], " ", "-", 
    RowBox[{
     RowBox[{"Sin", "[", 
      RowBox[{"l", " ", "\[CurlyTheta]"}], "]"}], " ", "y"}]}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"Roty", "[", "l_", "]"}], ":=", 
   RowBox[{
    RowBox[{
     RowBox[{"Sin", "[", 
      RowBox[{"l", " ", "\[CurlyTheta]"}], "]"}], " ", "x"}], " ", "+", " ", 
    RowBox[{
     RowBox[{"Cos", "[", 
      RowBox[{"l", " ", "\[CurlyTheta]"}], "]"}], " ", "y"}]}]}], 
  ";"}]}], "Input",
 CellChangeTimes->{{3.57593664325*^9, 3.575936700265625*^9}, {
   3.575936767546875*^9, 3.5759368075*^9}, {3.575937015*^9, 
   3.575937050671875*^9}, {3.575937110828125*^9, 3.575937205859375*^9}, {
   3.575937316484375*^9, 3.575937376640625*^9}, {3.575937415984375*^9, 
   3.575937491328125*^9}, {3.57593752875*^9, 3.57593758315625*^9}, {
   3.575937613671875*^9, 3.575937653828125*^9}, {3.57593771815625*^9, 
   3.5759378189375*^9}, {3.575937870234375*^9, 3.575937886203125*^9}, 
   3.57594132115625*^9, {3.575941594171875*^9, 3.57594162346875*^9}, 
   3.575941790734375*^9, {3.575945392671875*^9, 3.57594540784375*^9}, {
   3.575949918046875*^9, 3.575949920671875*^9}, {3.57595565109375*^9, 
   3.57595567653125*^9}, {3.5759557220625*^9, 3.575955734390625*^9}, {
   3.5759559763125*^9, 3.57595596534375*^9}, 3.5759560248125*^9, {
   3.57595622009375*^9, 3.575956253390625*^9}, 3.5759563096875*^9, 
   3.575956347625*^9, {3.575956422296875*^9, 3.575956454828125*^9}, {
   3.57595651346875*^9, 3.57595651528125*^9}, 3.57595668840625*^9, {
   3.575956790796875*^9, 3.57595679146875*^9}, {3.575956839796875*^9, 
   3.57595689803125*^9}, {3.575956939796875*^9, 3.575956954796875*^9}, {
   3.575957016453125*^9, 3.5759570720625*^9}, {3.575960634328125*^9, 
   3.57596073771875*^9}, {3.575960828171875*^9, 3.575960895953125*^9}, {
   3.575961092390625*^9, 3.5759610930625*^9}, {3.57596114171875*^9, 
   3.575961212890625*^9}, {3.57596125521875*^9, 3.575961291984375*^9}, {
   3.576025081046875*^9, 3.576025103859375*^9}, {3.576025284734375*^9, 
   3.57602530084375*^9}, {3.576025413046875*^9, 3.576025459265625*^9}, {
   3.576025503671875*^9, 3.576025504984375*^9}, {3.576025541171875*^9, 
   3.5760255548125*^9}, {3.576025585171875*^9, 3.576025600234375*^9}, {
   3.57602611703125*^9, 3.576026120328125*^9}, 3.5760262106875*^9, {
   3.57602624159375*^9, 3.576026242828125*^9}, {3.576026288890625*^9, 
   3.57602629065625*^9}}],

Cell["\<\
Distance to the vertices: Equations (5) and (6) in [1]\
\>", "Text",
 CellChangeTimes->{{3.576026224390625*^9, 3.576026233875*^9}, {
  3.57602627309375*^9, 3.576026276265625*^9}, {3.576354198265625*^9, 
  3.576354203203125*^9}}],

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"duV1", "[", 
    RowBox[{"x_", ",", "y_"}], "]"}], ":=", 
   SqrtBox[
    RowBox[{
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{"x", "-", "R"}], ")"}], "2"], "+", 
     SuperscriptBox["y", "2"]}]]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"duVL", "[", 
    RowBox[{"x_", ",", "y_", ",", "l_"}], "]"}], ":=", 
   RowBox[{"duV1", "[", 
    RowBox[{
     RowBox[{"Rotx", "[", 
      RowBox[{"-", 
       RowBox[{"(", 
        RowBox[{"l", "-", "1"}], ")"}]}], "]"}], ",", 
     RowBox[{"Roty", "[", 
      RowBox[{"-", 
       RowBox[{"(", 
        RowBox[{"l", "-", "1"}], ")"}]}], "]"}]}], "]"}]}], ";"}]}], "Input"],

Cell["\<\
Perpendicular distance to the sides: Equations (7) and (9) in [1]\
\>", "Text",
 CellChangeTimes->{{3.576026224390625*^9, 3.5760262820625*^9}, {
  3.57635421246875*^9, 3.576354221328125*^9}}],

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"pduS1", "[", 
    RowBox[{"x_", ",", "y_"}], "]"}], ":=", 
   FractionBox[
    RowBox[{"Abs", "[", 
     RowBox[{"y", " ", "+", " ", 
      RowBox[{"x", " ", 
       RowBox[{"Tan", "[", 
        FractionBox[
         RowBox[{" ", "\[Theta]"}], "2"], "]"}]}], "-", 
      RowBox[{"R", " ", 
       RowBox[{"Tan", "[", 
        FractionBox[
         RowBox[{" ", "\[Theta]"}], "2"], "]"}]}]}], "]"}], 
    SqrtBox[
     RowBox[{"1", "+", 
      SuperscriptBox[
       RowBox[{"Tan", "[", 
        FractionBox[
         RowBox[{" ", "\[Theta]"}], "2"], "]"}], "2"]}]]]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"pduSL", "[", 
    RowBox[{"x_", ",", "y_", ",", "l_"}], "]"}], ":=", 
   RowBox[{"pduS1", "[", 
    RowBox[{
     RowBox[{"Rotx", "[", 
      RowBox[{"-", 
       RowBox[{"(", 
        RowBox[{"l", "-", "1"}], ")"}]}], "]"}], ",", 
     RowBox[{"Roty", "[", 
      RowBox[{"-", 
       RowBox[{"(", 
        RowBox[{"l", "-", "1"}], ")"}]}], "]"}]}], "]"}]}], ";"}]}], "Input"],

Cell["\<\
Shortest distance to the sides: Equations (8) and (9) in [1]\
\>", "Text",
 CellChangeTimes->{{3.576026224390625*^9, 3.57602630965625*^9}, {
  3.576354227359375*^9, 3.57635423453125*^9}}],

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"w", "[", 
    RowBox[{"x_", ",", "y_"}], "]"}], ":=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"R", "-", 
      FractionBox[
       RowBox[{
        RowBox[{
         RowBox[{"(", 
          RowBox[{"x", "-", "R"}], ")"}], 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"Cos", "[", "\[CurlyTheta]", "]"}], "-", "1"}], ")"}]}], 
        "+", 
        RowBox[{"y", " ", 
         RowBox[{"Sin", "[", "\[CurlyTheta]", "]"}]}]}], "2"]}], ",", 
     RowBox[{
      FractionBox[
       RowBox[{"Sin", "[", "\[CurlyTheta]", "]"}], 
       RowBox[{"2", 
        RowBox[{"(", 
         RowBox[{"1", "-", 
          RowBox[{"Cos", "[", "\[CurlyTheta]", "]"}]}], ")"}]}]], 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         RowBox[{"(", 
          RowBox[{"x", "-", "R"}], ")"}], 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"Cos", "[", "\[CurlyTheta]", "]"}], "-", "1"}], ")"}]}], 
        "+", 
        RowBox[{"y", " ", 
         RowBox[{"Sin", "[", "\[CurlyTheta]", "]"}]}]}], ")"}]}]}], "}"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"dwV1", "[", 
    RowBox[{"x_", ",", "y_"}], "]"}], ":=", 
   RowBox[{"EuclideanDistance", "[", 
    RowBox[{
     RowBox[{"w", "[", 
      RowBox[{"x", ",", "y"}], "]"}], ",", 
     RowBox[{"polygonvertices", "[", 
      RowBox[{"[", "1", "]"}], "]"}]}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"dwV2", "[", 
    RowBox[{"x_", ",", "y_"}], "]"}], ":=", 
   RowBox[{"EuclideanDistance", "[", 
    RowBox[{
     RowBox[{"w", "[", 
      RowBox[{"x", ",", "y"}], "]"}], ",", 
     RowBox[{"polygonvertices", "[", 
      RowBox[{"[", "2", "]"}], "]"}]}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"duV1new", "[", 
    RowBox[{"x_", ",", "y_"}], "]"}], ":=", 
   RowBox[{"EuclideanDistance", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"x", ",", "y"}], "}"}], ",", 
     RowBox[{"polygonvertices", "[", 
      RowBox[{"[", "1", "]"}], "]"}]}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"duV2new", "[", 
    RowBox[{"x_", ",", "y_"}], "]"}], ":=", 
   RowBox[{"EuclideanDistance", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"x", ",", "y"}], "}"}], ",", 
     RowBox[{"polygonvertices", "[", 
      RowBox[{"[", "2", "]"}], "]"}]}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"duS1", "[", 
    RowBox[{"x_", ",", "y_"}], "]"}], ":=", 
   RowBox[{"If", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"Max", "[", 
       RowBox[{
        RowBox[{"dwV1", "[", 
         RowBox[{"x", ",", "y"}], "]"}], ",", 
        RowBox[{"dwV2", "[", 
         RowBox[{"x", ",", "y"}], "]"}]}], "]"}], ">", "sidelength"}], ",", 
     RowBox[{"Min", "[", 
      RowBox[{
       RowBox[{"duV1new", "[", 
        RowBox[{"x", ",", "y"}], "]"}], ",", 
       RowBox[{"duV2new", "[", 
        RowBox[{"x", ",", "y"}], "]"}]}], "]"}], ",", 
     RowBox[{"pduS1", "[", 
      RowBox[{"x", ",", "y"}], "]"}]}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"duSL", "[", 
    RowBox[{"x_", ",", "y_", ",", "l_"}], "]"}], ":=", 
   RowBox[{"duS1", "[", 
    RowBox[{
     RowBox[{"Rotx", "[", 
      RowBox[{"-", 
       RowBox[{"(", 
        RowBox[{"l", "-", "1"}], ")"}]}], "]"}], ",", 
     RowBox[{"Roty", "[", 
      RowBox[{"-", 
       RowBox[{"(", 
        RowBox[{"l", "-", "1"}], ")"}]}], "]"}]}], "]"}]}], ";"}]}], "Input",
 CellChangeTimes->{
  3.576026368265625*^9, {3.5761871249375*^9, 3.576187137453125*^9}, {
   3.5761873215*^9, 3.57618741059375*^9}, {3.576187724671875*^9, 
   3.576187785125*^9}, 3.57618787671875*^9, 3.57618819953125*^9, {
   3.576189201828125*^9, 3.57618925384375*^9}, {3.576189914546875*^9, 
   3.57618994571875*^9}, 3.576190033640625*^9, {3.576190093703125*^9, 
   3.57619012734375*^9}, {3.57619062615625*^9, 3.576190627703125*^9}, {
   3.576190699734375*^9, 3.576190703046875*^9}, {3.576190756640625*^9, 
   3.576190800109375*^9}, 3.57619095978125*^9, 3.576202686511668*^9, 
   3.5762030626883087`*^9}],

Cell["Generate the distances", "Text",
 CellChangeTimes->{{3.575839347828125*^9, 3.575839355953125*^9}, {
  3.5758416181903753`*^9, 3.5758416285810003`*^9}, {3.5758607010810003`*^9, 
  3.5758607629247503`*^9}, {3.576026358359375*^9, 3.5760263613125*^9}, {
  3.576026566421875*^9, 3.57602657353125*^9}, {3.576026696640625*^9, 
  3.576026697015625*^9}, {3.57635042153125*^9, 3.576350427140625*^9}, {
  3.576350458453125*^9, 3.5763504950625*^9}, {3.57635054071875*^9, 
  3.5763505418125*^9}, {3.5764599691567497`*^9, 3.5764599708286247`*^9}}],

Cell[BoxData[{
 RowBox[{
  RowBox[{"distancetovertices", "=", 
   RowBox[{"Table", "[", 
    RowBox[{
     RowBox[{"duVL", "[", 
      RowBox[{"x", ",", "y", ",", "l"}], "]"}], ",", 
     RowBox[{"{", 
      RowBox[{"l", ",", "1", ",", "L", ",", "1"}], "}"}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"pdistancetosides", " ", "=", " ", 
   RowBox[{"Table", "[", 
    RowBox[{
     RowBox[{"pduSL", "[", 
      RowBox[{"x", ",", "y", ",", "l"}], "]"}], ",", 
     RowBox[{"{", 
      RowBox[{"l", ",", "1", ",", "L", ",", "1"}], "}"}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"distancetosides", " ", "=", " ", 
   RowBox[{"Table", "[", 
    RowBox[{
     RowBox[{"duSL", "[", 
      RowBox[{"x", ",", "y", ",", "l"}], "]"}], ",", 
     RowBox[{"{", 
      RowBox[{"l", ",", "1", ",", "L", ",", "1"}], "}"}]}], "]"}]}], 
  ";"}]}], "Input",
 CellChangeTimes->{{3.575838787609375*^9, 3.575838788125*^9}, {
   3.5758388525625*^9, 3.5758388530625*^9}, {3.57583936471875*^9, 
   3.57583938865625*^9}, 3.575839433015625*^9, {3.575839482453125*^9, 
   3.575839492*^9}, {3.5758398399375*^9, 3.57583984665625*^9}, {
   3.575839927921875*^9, 3.575839948859375*^9}, 3.57584008434375*^9, {
   3.57584074175*^9, 3.57584074228125*^9}, {3.57584099978125*^9, 
   3.575841001609375*^9}, {3.575841162640625*^9, 3.575841180203125*^9}, {
   3.5758415044872503`*^9, 3.5758415067685003`*^9}, {3.5758419289872503`*^9, 
   3.5758419443622503`*^9}, {3.5758419780497503`*^9, 
   3.5758421533935003`*^9}, {3.5758422486435003`*^9, 
   3.5758422527528753`*^9}, {3.5758422872997503`*^9, 
   3.5758422898466253`*^9}, {3.5758423710810003`*^9, 
   3.5758424327216253`*^9}, {3.5758425882060003`*^9, 
   3.5758426418935003`*^9}, {3.5758427058466253`*^9, 3.5758427087372503`*^9}, 
   3.5758429355341253`*^9, {3.5758431105028753`*^9, 3.5758431122216253`*^9}, {
   3.5758433483935003`*^9, 3.5758433527216253`*^9}, {3.5758443209403753`*^9, 
   3.5758443340028753`*^9}, {3.5758604482216253`*^9, 
   3.5758604953622503`*^9}, {3.5758605396122503`*^9, 
   3.5758605558153753`*^9}, {3.5758605870341253`*^9, 
   3.5758606837997503`*^9}, {3.5758607380028753`*^9, 
   3.5758607420497503`*^9}, {3.5758608026278753`*^9, 
   3.5758608130810003`*^9}, {3.5758610574091253`*^9, 
   3.5758610853153753`*^9}, {3.5758611171903753`*^9, 
   3.5758611488622503`*^9}, {3.5758612458778753`*^9, 
   3.5758612585028753`*^9}, {3.575941364828125*^9, 3.575941460328125*^9}, {
   3.575941803328125*^9, 3.575941886578125*^9}, {3.57594206596875*^9, 
   3.575942086765625*^9}, {3.575948724234375*^9, 3.57594872709375*^9}, {
   3.575949791296875*^9, 3.575949793015625*^9}, {3.57595179784375*^9, 
   3.575951798828125*^9}, {3.5759519225*^9, 3.575951932796875*^9}, {
   3.57595209203125*^9, 3.57595209346875*^9}, {3.5759538968125*^9, 
   3.575953897125*^9}, {3.5759541514375*^9, 3.575954184*^9}, {
   3.575955011828125*^9, 3.5759550181875*^9}, {3.5759615259375*^9, 
   3.575961527015625*^9}, {3.5759615934375*^9, 3.575961620859375*^9}, {
   3.57602639009375*^9, 3.576026481671875*^9}, {3.576026587234375*^9, 
   3.576026587609375*^9}, {3.5760266784375*^9, 3.576026690625*^9}, {
   3.57618806190625*^9, 3.576188087609375*^9}, {3.576188183859375*^9, 
   3.576188204125*^9}, {3.576190830765625*^9, 3.576190831515625*^9}, {
   3.57619099446875*^9, 3.57619109121875*^9}, {3.576191268625*^9, 
   3.5761912718125*^9}, {3.5762026971671677`*^9, 3.5762026977452526`*^9}, {
   3.57629408556244*^9, 3.576294161166492*^9}, {3.5762944224762197`*^9, 
   3.5762944524897313`*^9}, {3.5763498230625*^9, 3.576349834765625*^9}, {
   3.576350413375*^9, 3.5763504175*^9}, {3.57635052121875*^9, 
   3.57635053096875*^9}, {3.5764599587817497`*^9, 3.5764599636254997`*^9}, {
   3.57678717259375*^9, 3.576787205328125*^9}, {3.576787407578125*^9, 
   3.576787425734375*^9}}],

Cell["\<\
Check for effects of finite precision, which can show up in the distances\
\>", "Text",
 CellChangeTimes->CompressedData["
1:eJxTTMoPSmViYGAQAWIQzdBQ5Re/5JUjQ0OdP4juE3fLSgDR0ydlQ+hFuzPB
dOzhTLC60/N2gWgGrflguuHsDgh/404IX+QkhFY4CRW/FbEUxE+5DaH97oNp
hkePIfT0lxB6F5iWYFGN6APRLVFgmoHh0wq9ZSA6cQ2YbojcAuEn7Ybwma9A
6NirEPEnjyH8uU8h/LM/IHzenxBanVMfTMtxgWmGOfYQvpUDhGZqgNCajRD5
/1uTwfT3bWC6YeVjCL3vKYgGAJBSlGs=
  "]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"totaldistance", "=", 
   RowBox[{"Join", "[", 
    RowBox[{
    "distancetovertices", ",", "pdistancetosides", " ", ",", 
     "distancetosides"}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{"totaldistance1", "=", 
  RowBox[{"Union", "[", "totaldistance", "]"}]}], "\[IndentingNewLine]", 
 RowBox[{"temp0", "=", 
  RowBox[{"Differences", "[", "totaldistance1", "]"}]}]}], "Input",
 CellChangeTimes->{
  3.576788336390625*^9, {3.576789352984375*^9, 3.57678938728125*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"0", ",", 
   FractionBox["1", 
    SqrtBox["2"]], ",", 
   SqrtBox["2"], ",", 
   SqrtBox[
    FractionBox["5", "2"]]}], "}"}]], "Output",
 CellChangeTimes->{
  3.5767883449375*^9, {3.576789280453125*^9, 3.576789307640625*^9}, 
   3.576789358875*^9, 3.57678948621875*^9, 3.576789562703125*^9, 
   3.576789625546875*^9, 3.576790691796875*^9, 3.576790934203125*^9, 
   3.57679110775*^9, 3.57679168721875*^9, 3.57689590575*^9, 
   3.576895952015625*^9, 3.576896085671875*^9, 3.57689613653125*^9, 
   3.576896377375*^9, 3.5768967350625*^9, {3.57689701471875*^9, 
   3.576897051140625*^9}, 3.576897191203125*^9, 3.576897240953125*^9, 
   3.576899896625*^9, 3.57696096325*^9, 3.576961066265625*^9, 
   3.5769611380625*^9}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   FractionBox["1", 
    SqrtBox["2"]], ",", 
   RowBox[{
    RowBox[{"-", 
     FractionBox["1", 
      SqrtBox["2"]]}], "+", 
    SqrtBox["2"]}], ",", 
   RowBox[{
    RowBox[{"-", 
     SqrtBox["2"]}], "+", 
    SqrtBox[
     FractionBox["5", "2"]]}]}], "}"}]], "Output",
 CellChangeTimes->{
  3.5767883449375*^9, {3.576789280453125*^9, 3.576789307640625*^9}, 
   3.576789358875*^9, 3.57678948621875*^9, 3.576789562703125*^9, 
   3.576789625546875*^9, 3.576790691796875*^9, 3.576790934203125*^9, 
   3.57679110775*^9, 3.57679168721875*^9, 3.57689590575*^9, 
   3.576895952015625*^9, 3.576896085671875*^9, 3.57689613653125*^9, 
   3.576896377375*^9, 3.5768967350625*^9, {3.57689701471875*^9, 
   3.576897051140625*^9}, 3.576897191203125*^9, 3.576897240953125*^9, 
   3.576899896625*^9, 3.57696096325*^9, 3.576961066265625*^9, 
   3.5769611380625*^9}]
}, Open  ]],

Cell["\<\
If present, remove the effects of finite precision in the distance \
calculations: 
(1st check) if the absolute value of any distance (distance to a vertex or \
perpendicular distance to a side or minimum distance to a side) is less than \
a tolerance value, it is set to 0\
\>", "Text",
 CellChangeTimes->{{3.576350504703125*^9, 3.576350517125*^9}, {
   3.576350580703125*^9, 3.57635058446875*^9}, {3.5767057385625*^9, 
   3.57670599375*^9}, {3.57670606203125*^9, 3.57670607453125*^9}, {
   3.576706129953125*^9, 3.57670619559375*^9}, {3.57670626728125*^9, 
   3.57670631728125*^9}, {3.576785241203125*^9, 3.576785262171875*^9}, {
   3.576785332140625*^9, 3.57678537971875*^9}, {3.576785465609375*^9, 
   3.576785474859375*^9}, {3.576785526359375*^9, 3.576785537796875*^9}, {
   3.576785980421875*^9, 3.576785984625*^9}, {3.576786538140625*^9, 
   3.57678655253125*^9}, {3.57678791215625*^9, 3.576787930484375*^9}, {
   3.576788465171875*^9, 3.57678860275*^9}, {3.5767887441875*^9, 
   3.57678874478125*^9}, {3.57678895090625*^9, 3.576788955015625*^9}, {
   3.57678910584375*^9, 3.576789150109375*^9}, {3.5767892283125*^9, 
   3.576789275015625*^9}, 3.57678939771875*^9}],

Cell[BoxData[{
 RowBox[{
  RowBox[{"distancetovertices", "=", 
   RowBox[{"Chop", "[", 
    RowBox[{"distancetovertices", ",", "tol"}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"pdistancetosides", " ", "=", " ", 
   RowBox[{"Chop", "[", 
    RowBox[{"pdistancetosides", " ", ",", "tol"}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"distancetosides", " ", "=", " ", 
   RowBox[{"Chop", "[", 
    RowBox[{"distancetosides", ",", "tol"}], "]"}]}], ";"}]}], "Input",
 CellChangeTimes->{{3.57689698428125*^9, 3.5768969954375*^9}, {
  3.576897098921875*^9, 3.576897134640625*^9}}],

Cell["\<\
(2nd check) if any two distances in the \[OpenCurlyDoubleQuote]totaldistance\
\[CloseCurlyDoubleQuote] list are the same, within the tolerance limit, then \
they are set as the same (first) distance value\
\>", "Text",
 CellChangeTimes->{{3.576350504703125*^9, 3.576350517125*^9}, {
   3.576350580703125*^9, 3.57635058446875*^9}, {3.5767057385625*^9, 
   3.57670599375*^9}, {3.57670606203125*^9, 3.57670607453125*^9}, {
   3.576706129953125*^9, 3.57670619559375*^9}, {3.57670626728125*^9, 
   3.57670631728125*^9}, {3.576785241203125*^9, 3.576785262171875*^9}, {
   3.576785332140625*^9, 3.57678537971875*^9}, {3.576785465609375*^9, 
   3.576785474859375*^9}, {3.576785526359375*^9, 3.576785537796875*^9}, {
   3.576785980421875*^9, 3.576785984625*^9}, {3.576786538140625*^9, 
   3.57678655253125*^9}, {3.57678791215625*^9, 3.576787930484375*^9}, {
   3.576788465171875*^9, 3.57678860275*^9}, {3.576788749375*^9, 
   3.576788749671875*^9}, {3.576788958515625*^9, 3.57678896153125*^9}, {
   3.576789176875*^9, 3.576789195859375*^9}, {3.57678925334375*^9, 
   3.5767892595625*^9}, 3.576789412984375*^9}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"kk", "=", "1"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{"samedistance", "=", 
  RowBox[{"Table", "[", 
   RowBox[{
    RowBox[{"0", "*", "l"}], ",", 
    RowBox[{"{", 
     RowBox[{"l", ",", "1", ",", 
      RowBox[{"Length", "[", 
       RowBox[{"Select", "[", 
        RowBox[{
         RowBox[{"Abs", "[", "temp0", "]"}], ",", 
         RowBox[{
          RowBox[{"#", "<", "tol"}], "&"}]}], "]"}], "]"}], ",", "1"}], 
     "}"}]}], "]"}]}], "\[IndentingNewLine]", 
 RowBox[{"For", "[", 
  RowBox[{
   RowBox[{"l", "=", "1"}], ",", 
   RowBox[{"l", "\[LessEqual]", 
    RowBox[{"Length", "[", "temp0", "]"}]}], ",", 
   RowBox[{"l", "++"}], ",", 
   RowBox[{
    RowBox[{"Which", "[", 
     RowBox[{
      RowBox[{
       RowBox[{"Abs", "[", 
        RowBox[{"temp0", "[", 
         RowBox[{"[", "l", "]"}], "]"}], "]"}], "<", "tol"}], ",", 
      RowBox[{
       RowBox[{"samedistance", "[", 
        RowBox[{"[", "kk", "]"}], "]"}], "=", 
       RowBox[{"totaldistance1", "[", 
        RowBox[{"[", "l", "]"}], "]"}]}]}], "]"}], ";", " ", 
    RowBox[{"Which", "[", 
     RowBox[{
      RowBox[{
       RowBox[{"Abs", "[", 
        RowBox[{"temp0", "[", 
         RowBox[{"[", "l", "]"}], "]"}], "]"}], "<", "tol"}], ",", 
      RowBox[{"kk", "=", 
       RowBox[{"kk", "+", "1"}]}]}], "]"}], ";"}]}], 
  "]"}], "\[IndentingNewLine]", "samedistance", "\[IndentingNewLine]", 
 RowBox[{"For", "[", 
  RowBox[{
   RowBox[{"ll", "=", "1"}], ",", 
   RowBox[{"ll", "\[LessEqual]", 
    RowBox[{"Length", "[", "samedistance", "]"}]}], ",", 
   RowBox[{"ll", "++"}], ",", "\[IndentingNewLine]", 
   RowBox[{"For", "[", 
    RowBox[{
     RowBox[{"l", "=", "1"}], ",", 
     RowBox[{"l", "\[LessEqual]", 
      RowBox[{"Length", "[", "distancetovertices", "]"}]}], ",", 
     RowBox[{"l", "++"}], ",", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"Which", "[", 
       RowBox[{
        RowBox[{
         RowBox[{"Abs", "[", 
          RowBox[{
           RowBox[{"distancetovertices", "[", 
            RowBox[{"[", "l", "]"}], "]"}], "-", 
           RowBox[{"samedistance", "[", 
            RowBox[{"[", "ll", "]"}], "]"}]}], "]"}], "<", "tol"}], ",", 
        RowBox[{
         RowBox[{
          RowBox[{"distancetovertices", "[", 
           RowBox[{"[", "l", "]"}], "]"}], "=", 
          RowBox[{"samedistance", "[", 
           RowBox[{"[", "ll", "]"}], "]"}]}], ";"}]}], "]"}], ";", 
      "\[IndentingNewLine]", 
      RowBox[{"Which", "[", 
       RowBox[{
        RowBox[{
         RowBox[{"Abs", "[", 
          RowBox[{
           RowBox[{"pdistancetosides", "[", 
            RowBox[{"[", "l", "]"}], "]"}], "-", 
           RowBox[{"samedistance", "[", 
            RowBox[{"[", "ll", "]"}], "]"}]}], "]"}], "<", "tol"}], ",", 
        RowBox[{
         RowBox[{
          RowBox[{"pdistancetosides", "[", 
           RowBox[{"[", "l", "]"}], "]"}], "=", 
          RowBox[{"samedistance", "[", 
           RowBox[{"[", "ll", "]"}], "]"}]}], ";"}]}], "]"}], ";", 
      "\[IndentingNewLine]", 
      RowBox[{"Which", "[", 
       RowBox[{
        RowBox[{
         RowBox[{"Abs", "[", 
          RowBox[{
           RowBox[{"distancetosides", "[", 
            RowBox[{"[", "l", "]"}], "]"}], "-", 
           RowBox[{"samedistance", "[", 
            RowBox[{"[", "ll", "]"}], "]"}]}], "]"}], "<", "tol"}], ",", 
        RowBox[{
         RowBox[{
          RowBox[{"distancetosides", "[", 
           RowBox[{"[", "l", "]"}], "]"}], "=", 
          RowBox[{"samedistance", "[", 
           RowBox[{"[", "ll", "]"}], "]"}]}], ";"}]}], "]"}], ";"}]}], 
    "\[IndentingNewLine]", "]"}]}], "\[IndentingNewLine]", "]"}]}], "Input"],

Cell[BoxData[
 RowBox[{"{", "}"}]], "Output",
 CellChangeTimes->{3.57696096328125*^9, 3.576961066296875*^9, 
  3.576961138078125*^9}],

Cell[BoxData[
 RowBox[{"{", "}"}]], "Output",
 CellChangeTimes->{3.57696096328125*^9, 3.576961066296875*^9, 
  3.576961138078125*^9}]
}, Open  ]],

Cell["Display the distances", "Text",
 CellChangeTimes->{{3.5764600717817497`*^9, 3.5764600754223747`*^9}, {
  3.57678902690625*^9, 3.576789031984375*^9}, {3.576789464359375*^9, 
  3.576789479890625*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{"distancetovertices", "\[IndentingNewLine]", \
"pdistancetosides", "\[IndentingNewLine]", "distancetosides"}], "Input",
 CellChangeTimes->{{3.5764600905629997`*^9, 3.5764600988598747`*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   FractionBox["1", 
    SqrtBox["2"]], ",", 
   SqrtBox[
    FractionBox["5", "2"]], ",", 
   SqrtBox[
    FractionBox["5", "2"]], ",", 
   FractionBox["1", 
    SqrtBox["2"]]}], "}"}]], "Output",
 CellChangeTimes->{
  3.5764601445786247`*^9, 3.5764604469536247`*^9, 3.5764604946254997`*^9, 
   3.5764605361567497`*^9, 3.5764605920317497`*^9, 3.5764607036254997`*^9, 
   3.5764607739692497`*^9, 3.5764608339536247`*^9, 3.5764608837817497`*^9, 
   3.5764609210317497`*^9, 3.5764610756723747`*^9, {3.5764611270786247`*^9, 
   3.5764611537192497`*^9}, 3.576706405671875*^9, {3.576706654890625*^9, 
   3.5767066778125*^9}, 3.576706755*^9, {3.57670680165625*^9, 
   3.57670682546875*^9}, 3.576785654625*^9, 3.576786202203125*^9, 
   3.576787085359375*^9, 3.576787161484375*^9, 3.57678834503125*^9, {
   3.5767892805625*^9, 3.576789307734375*^9}, 3.576789486375*^9, 
   3.576789562796875*^9, 3.57678962565625*^9, 3.576790691890625*^9, 
   3.57679093428125*^9, 3.57679110784375*^9, 3.576791687265625*^9, 
   3.57689590584375*^9, 3.576895952125*^9, 3.57689608578125*^9, 
   3.57689613659375*^9, 3.5768963774375*^9, 3.576896735125*^9, {
   3.576897014875*^9, 3.57689705128125*^9}, 3.5768971913125*^9, 
   3.576897241*^9, 3.576899896703125*^9, 3.5769609633125*^9, 
   3.5769610663125*^9, 3.57696113809375*^9}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   FractionBox["1", 
    SqrtBox["2"]], ",", 
   SqrtBox["2"], ",", 
   FractionBox["1", 
    SqrtBox["2"]], ",", "0"}], "}"}]], "Output",
 CellChangeTimes->{
  3.5764601445786247`*^9, 3.5764604469536247`*^9, 3.5764604946254997`*^9, 
   3.5764605361567497`*^9, 3.5764605920317497`*^9, 3.5764607036254997`*^9, 
   3.5764607739692497`*^9, 3.5764608339536247`*^9, 3.5764608837817497`*^9, 
   3.5764609210317497`*^9, 3.5764610756723747`*^9, {3.5764611270786247`*^9, 
   3.5764611537192497`*^9}, 3.576706405671875*^9, {3.576706654890625*^9, 
   3.5767066778125*^9}, 3.576706755*^9, {3.57670680165625*^9, 
   3.57670682546875*^9}, 3.576785654625*^9, 3.576786202203125*^9, 
   3.576787085359375*^9, 3.576787161484375*^9, 3.57678834503125*^9, {
   3.5767892805625*^9, 3.576789307734375*^9}, 3.576789486375*^9, 
   3.576789562796875*^9, 3.57678962565625*^9, 3.576790691890625*^9, 
   3.57679093428125*^9, 3.57679110784375*^9, 3.576791687265625*^9, 
   3.57689590584375*^9, 3.576895952125*^9, 3.57689608578125*^9, 
   3.57689613659375*^9, 3.5768963774375*^9, 3.576896735125*^9, {
   3.576897014875*^9, 3.57689705128125*^9}, 3.5768971913125*^9, 
   3.576897241*^9, 3.576899896703125*^9, 3.5769609633125*^9, 
   3.5769610663125*^9, 3.57696113809375*^9}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   FractionBox["1", 
    SqrtBox["2"]], ",", 
   SqrtBox["2"], ",", 
   FractionBox["1", 
    SqrtBox["2"]], ",", "0"}], "}"}]], "Output",
 CellChangeTimes->{
  3.5764601445786247`*^9, 3.5764604469536247`*^9, 3.5764604946254997`*^9, 
   3.5764605361567497`*^9, 3.5764605920317497`*^9, 3.5764607036254997`*^9, 
   3.5764607739692497`*^9, 3.5764608339536247`*^9, 3.5764608837817497`*^9, 
   3.5764609210317497`*^9, 3.5764610756723747`*^9, {3.5764611270786247`*^9, 
   3.5764611537192497`*^9}, 3.576706405671875*^9, {3.576706654890625*^9, 
   3.5767066778125*^9}, 3.576706755*^9, {3.57670680165625*^9, 
   3.57670682546875*^9}, 3.576785654625*^9, 3.576786202203125*^9, 
   3.576787085359375*^9, 3.576787161484375*^9, 3.57678834503125*^9, {
   3.5767892805625*^9, 3.576789307734375*^9}, 3.576789486375*^9, 
   3.576789562796875*^9, 3.57678962565625*^9, 3.576790691890625*^9, 
   3.57679093428125*^9, 3.57679110784375*^9, 3.576791687265625*^9, 
   3.57689590584375*^9, 3.576895952125*^9, 3.57689608578125*^9, 
   3.57689613659375*^9, 3.5768963774375*^9, 3.576896735125*^9, {
   3.576897014875*^9, 3.57689705128125*^9}, 3.5768971913125*^9, 
   3.576897241*^9, 3.576899896703125*^9, 3.5769609633125*^9, 
   3.5769610663125*^9, 3.57696113809375*^9}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
4. Border and corner effects: Section IV in [1]\
\>", "Section",
 CellChangeTimes->{{3.57602688996875*^9, 3.576026902734375*^9}, {
   3.5760927389375*^9, 3.5760927399375*^9}, 3.57635144478125*^9, {
   3.576355641328125*^9, 3.576355646609375*^9}}],

Cell["\<\
Define the rule for picking a side or vertex: Follows the convention in [1] \
that the sides/vertices are numbered in anticlockwise direction\
\>", "Text",
 CellChangeTimes->{{3.576350552921875*^9, 3.576350556625*^9}, {
  3.5767055593125*^9, 3.576705582875*^9}, {3.576705643046875*^9, 
  3.576705648359375*^9}, {3.57670644896875*^9, 3.576706469953125*^9}, {
  3.576706573765625*^9, 3.576706594796875*^9}, {3.57678568578125*^9, 
  3.576785722546875*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"newMod", "[", 
     RowBox[{"a_", ",", "b_"}], "]"}], ":=", 
    RowBox[{"If", "[", 
     RowBox[{
      RowBox[{
       RowBox[{"Mod", "[", 
        RowBox[{"a", ",", "b"}], "]"}], "==", "0"}], ",", "L", ",", 
      RowBox[{"Mod", "[", 
       RowBox[{"a", ",", "b"}], "]"}]}], "]"}]}], ";"}], " "}]], "Input",
 CellChangeTimes->{{3.576294228849227*^9, 3.5762942395828457`*^9}, {
  3.576706629546875*^9, 3.57670665*^9}}],

Cell["\<\
Define the border and corner effects to calculate the PDF f_R(r) and store in \
a list: Equations (22) and (23) in [1]\
\>", "Text",
 CellChangeTimes->{{3.5758575378935003`*^9, 3.5758575457997503`*^9}, {
  3.5759667716875*^9, 3.5759667885*^9}, {3.57596990803125*^9, 
  3.57596991471875*^9}, {3.576021729*^9, 3.576021729328125*^9}, {
  3.576026919890625*^9, 3.576026921046875*^9}, {3.576027036515625*^9, 
  3.576027040265625*^9}, {3.5760271961875*^9, 3.576027196734375*^9}, {
  3.57603009475*^9, 3.576030096671875*^9}, {3.5762247558125*^9, 
  3.576224756390625*^9}, {3.57635037209375*^9, 3.57635038515625*^9}, {
  3.57635059184375*^9, 3.576350597234375*^9}, {3.57635425303125*^9, 
  3.576354268125*^9}}],

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"PartialBL", "[", "l_", "]"}], " ", ":=", " ", 
   RowBox[{"2", "r", " ", 
    RowBox[{"ArcCos", "[", 
     FractionBox[
      RowBox[{"pdistancetosides", " ", "[", 
       RowBox[{"[", 
        RowBox[{"newMod", "[", 
         RowBox[{"l", ",", "L"}], "]"}], "]"}], "]"}], "r"], "]"}]}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"PartialCL", "[", "l_", "]"}], " ", ":=", 
   RowBox[{"r", " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"ArcCos", "[", 
       FractionBox[
        RowBox[{"pdistancetosides", " ", "[", 
         RowBox[{"[", 
          RowBox[{"newMod", "[", 
           RowBox[{"l", ",", "L"}], "]"}], "]"}], "]"}], "r"], "]"}], "+", 
      RowBox[{"ArcCos", "[", 
       FractionBox[
        RowBox[{"pdistancetosides", " ", "[", 
         RowBox[{"[", 
          RowBox[{"newMod", "[", 
           RowBox[{
            RowBox[{"l", "-", "1"}], ",", "L"}], "]"}], "]"}], "]"}], "r"], 
       "]"}], "+", 
      FractionBox[
       RowBox[{"\[Pi]", 
        RowBox[{"(", 
         RowBox[{"L", "-", "2"}], ")"}], " "}], "L"], "-", "\[Pi]"}], 
     ")"}]}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"temp1", "=", 
   RowBox[{"Table", "[", 
    RowBox[{
     RowBox[{"PartialBL", "[", "l", "]"}], ",", 
     RowBox[{"{", 
      RowBox[{"l", ",", "1", ",", "L", ",", "1"}], "}"}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"temp2", "=", 
   RowBox[{"Table", "[", 
    RowBox[{
     RowBox[{"PartialCL", "[", "l", "]"}], ",", 
     RowBox[{"{", 
      RowBox[{"l", ",", "1", ",", "L", ",", "1"}], "}"}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"boundaryeffects", "=", 
   RowBox[{"Chop", "[", 
    RowBox[{
     RowBox[{"Flatten", "[", 
      RowBox[{"Append", "[", 
       RowBox[{"temp1", ",", 
        RowBox[{"-", "temp2"}]}], "]"}], "]"}], ",", "tol"}], "]"}]}], 
  ";"}]}], "Input",
 CellChangeTimes->{{3.576013610515625*^9, 3.576013610875*^9}, {
   3.576013722609375*^9, 3.576013759*^9}, {3.576014748765625*^9, 
   3.576014772203125*^9}, {3.576026989828125*^9, 3.576027021375*^9}, {
   3.576027116328125*^9, 3.576027153765625*^9}, {3.57602722484375*^9, 
   3.57602722871875*^9}, {3.576294256597273*^9, 3.576294363136647*^9}, {
   3.57629446991038*^9, 3.5762944722695885`*^9}, 3.576350352109375*^9, {
   3.576896227140625*^9, 3.576896234515625*^9}, {3.576896430140625*^9, 
   3.576896436625*^9}, {3.576897375671875*^9, 3.576897376359375*^9}}],

Cell["\<\
Define the border and corner effects to calculate the CDF F_R (r) and store \
in a list: Equations (13), (14), (15) and (16) in [1]\
\>", "Text",
 CellChangeTimes->{{3.57635039178125*^9, 3.576350402859375*^9}, {
  3.576350606546875*^9, 3.57635061240625*^9}, {3.576354274828125*^9, 
  3.576354311984375*^9}}],

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"BL", "[", "l_", "]"}], ":=", "  ", 
   RowBox[{"If", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"distancetosides", " ", "[", 
       RowBox[{"[", 
        RowBox[{"newMod", "[", 
         RowBox[{"l", ",", "L"}], "]"}], "]"}], "]"}], "\[NotEqual]", "0"}], 
     ",", 
     RowBox[{
      RowBox[{
       SuperscriptBox["r", "2"], " ", 
       RowBox[{"ArcCos", "[", 
        FractionBox[
         RowBox[{"pdistancetosides", " ", "[", 
          RowBox[{"[", 
           RowBox[{"newMod", "[", 
            RowBox[{"l", ",", "L"}], "]"}], "]"}], "]"}], "r"], "]"}]}], "-", 
      RowBox[{
       SuperscriptBox[
        RowBox[{"distancetosides", " ", "[", 
         RowBox[{"[", 
          RowBox[{"newMod", "[", 
           RowBox[{"l", ",", "L"}], "]"}], "]"}], "]"}], "2"], " ", 
       RowBox[{"ArcCos", "[", 
        FractionBox[
         RowBox[{"pdistancetosides", " ", "[", 
          RowBox[{"[", 
           RowBox[{"newMod", "[", 
            RowBox[{"l", ",", "L"}], "]"}], "]"}], "]"}], 
         RowBox[{"distancetosides", " ", "[", 
          RowBox[{"[", "l", "]"}], "]"}]], "]"}]}], "-", 
      RowBox[{
       RowBox[{"pdistancetosides", " ", "[", 
        RowBox[{"[", 
         RowBox[{"newMod", "[", 
          RowBox[{"l", ",", "L"}], "]"}], "]"}], "]"}], 
       RowBox[{"(", 
        RowBox[{
         SqrtBox[
          RowBox[{
           SuperscriptBox["r", "2"], " ", "-", " ", 
           SuperscriptBox[
            RowBox[{"pdistancetosides", " ", "[", 
             RowBox[{"[", 
              RowBox[{"newMod", "[", 
               RowBox[{"l", ",", "L"}], "]"}], "]"}], "]"}], "2"]}]], "-", 
         RowBox[{"\[Sqrt]", 
          RowBox[{"(", 
           RowBox[{
            SuperscriptBox[
             RowBox[{"distancetosides", " ", "[", 
              RowBox[{"[", 
               RowBox[{"newMod", "[", 
                RowBox[{"l", ",", "L"}], "]"}], "]"}], "]"}], "2"], "-", 
            SuperscriptBox[
             RowBox[{"pdistancetosides", " ", "[", 
              RowBox[{"[", 
               RowBox[{"newMod", "[", 
                RowBox[{"l", ",", "L"}], "]"}], "]"}], "]"}], "2"]}], 
           ")"}]}]}], ")"}]}]}], ",", 
     RowBox[{
      RowBox[{
       SuperscriptBox["r", "2"], " ", 
       RowBox[{"ArcCos", "[", 
        FractionBox[
         RowBox[{"pdistancetosides", " ", "[", 
          RowBox[{"[", 
           RowBox[{"newMod", "[", 
            RowBox[{"l", ",", "L"}], "]"}], "]"}], "]"}], "r"], "]"}]}], "-", 
      RowBox[{
       RowBox[{"pdistancetosides", " ", "[", 
        RowBox[{"[", 
         RowBox[{"newMod", "[", 
          RowBox[{"l", ",", "L"}], "]"}], "]"}], "]"}], 
       RowBox[{"(", 
        RowBox[{
         SqrtBox[
          RowBox[{
           SuperscriptBox["r", "2"], " ", "-", " ", 
           SuperscriptBox[
            RowBox[{"pdistancetosides", " ", "[", 
             RowBox[{"[", 
              RowBox[{"newMod", "[", 
               RowBox[{"l", ",", "L"}], "]"}], "]"}], "]"}], "2"]}]], "-", 
         RowBox[{"\[Sqrt]", 
          RowBox[{"(", 
           RowBox[{
            SuperscriptBox[
             RowBox[{"distancetosides", " ", "[", 
              RowBox[{"[", 
               RowBox[{"newMod", "[", 
                RowBox[{"l", ",", "L"}], "]"}], "]"}], "]"}], "2"], "-", 
            SuperscriptBox[
             RowBox[{"pdistancetosides", " ", "[", 
              RowBox[{"[", 
               RowBox[{"newMod", "[", 
                RowBox[{"l", ",", "L"}], "]"}], "]"}], "]"}], "2"]}], 
           ")"}]}]}], ")"}]}]}]}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"CL", "[", "l_", "]"}], " ", ":=", 
   RowBox[{"If", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"distancetovertices", " ", "[", 
       RowBox[{"[", 
        RowBox[{"newMod", "[", 
         RowBox[{"l", ",", "L"}], "]"}], "]"}], "]"}], "\[NotEqual]", "0"}], 
     ",", 
     RowBox[{
      RowBox[{
       FractionBox[
        SuperscriptBox["r", "2"], "2"], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"ArcCos", "[", 
          FractionBox[
           RowBox[{"pdistancetosides", " ", "[", 
            RowBox[{"[", 
             RowBox[{"newMod", "[", 
              RowBox[{"l", ",", "L"}], "]"}], "]"}], "]"}], "r"], "]"}], "+", 
         RowBox[{"ArcCos", "[", 
          FractionBox[
           RowBox[{"pdistancetosides", " ", "[", 
            RowBox[{"[", 
             RowBox[{"newMod", "[", 
              RowBox[{
               RowBox[{"l", "-", "1"}], ",", "L"}], "]"}], "]"}], "]"}], "r"],
           "]"}]}], ")"}]}], "-", "\[IndentingNewLine]", 
      RowBox[{
       FractionBox[
        SuperscriptBox[
         RowBox[{"distancetovertices", " ", "[", 
          RowBox[{"[", 
           RowBox[{"newMod", "[", 
            RowBox[{"l", ",", "L"}], "]"}], "]"}], "]"}], "2"], "2"], 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"ArcCos", "[", 
          FractionBox[
           RowBox[{"pdistancetosides", " ", "[", 
            RowBox[{"[", 
             RowBox[{"newMod", "[", 
              RowBox[{"l", ",", "L"}], "]"}], "]"}], "]"}], 
           RowBox[{"distancetovertices", " ", "[", 
            RowBox[{"[", 
             RowBox[{"newMod", "[", 
              RowBox[{"l", ",", "L"}], "]"}], "]"}], "]"}]], "]"}], "+", 
         RowBox[{"ArcCos", "[", 
          FractionBox[
           RowBox[{"pdistancetosides", " ", "[", 
            RowBox[{"[", 
             RowBox[{"newMod", "[", 
              RowBox[{
               RowBox[{"l", "-", "1"}], ",", "L"}], "]"}], "]"}], "]"}], 
           RowBox[{"distancetovertices", " ", "[", 
            RowBox[{"[", 
             RowBox[{"newMod", "[", 
              RowBox[{"l", ",", "L"}], "]"}], "]"}], "]"}]], "]"}]}], ")"}]}],
       "+", 
      RowBox[{
       FractionBox[
        RowBox[{"pdistancetosides", " ", "[", 
         RowBox[{"[", 
          RowBox[{"newMod", "[", 
           RowBox[{"l", ",", "L"}], "]"}], "]"}], "]"}], "2"], 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"\[Sqrt]", 
          RowBox[{"(", 
           RowBox[{
            SuperscriptBox[
             RowBox[{"distancetovertices", " ", "[", 
              RowBox[{"[", 
               RowBox[{"newMod", "[", 
                RowBox[{"l", ",", "L"}], "]"}], "]"}], "]"}], "2"], " ", "-", 
            " ", 
            SuperscriptBox[
             RowBox[{"pdistancetosides", " ", "[", 
              RowBox[{"[", 
               RowBox[{"newMod", "[", 
                RowBox[{"l", ",", "L"}], "]"}], "]"}], "]"}], "2"]}], ")"}]}],
          "-", 
         SqrtBox[
          RowBox[{
           SuperscriptBox["r", "2"], "-", 
           SuperscriptBox[
            RowBox[{"pdistancetosides", " ", "[", 
             RowBox[{"[", 
              RowBox[{"newMod", "[", 
               RowBox[{"l", ",", "L"}], "]"}], "]"}], "]"}], "2"]}]]}], 
        ")"}]}], "+", " ", 
      RowBox[{
       FractionBox[
        RowBox[{"pdistancetosides", " ", "[", 
         RowBox[{"[", 
          RowBox[{"newMod", "[", 
           RowBox[{
            RowBox[{"l", "-", "1"}], ",", "L"}], "]"}], "]"}], "]"}], "2"], 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"\[Sqrt]", 
          RowBox[{"(", 
           RowBox[{
            SuperscriptBox[
             RowBox[{"distancetovertices", " ", "[", 
              RowBox[{"[", 
               RowBox[{"newMod", "[", 
                RowBox[{"l", ",", "L"}], "]"}], "]"}], "]"}], "2"], " ", "-", 
            " ", 
            SuperscriptBox[
             RowBox[{"pdistancetosides", " ", "[", 
              RowBox[{"[", 
               RowBox[{"newMod", "[", 
                RowBox[{
                 RowBox[{"l", "-", "1"}], ",", "L"}], "]"}], "]"}], "]"}], 
             "2"]}], ")"}]}], "-", 
         SqrtBox[
          RowBox[{
           SuperscriptBox["r", "2"], "-", 
           SuperscriptBox[
            RowBox[{"pdistancetosides", " ", "[", 
             RowBox[{"[", 
              RowBox[{"newMod", "[", 
               RowBox[{
                RowBox[{"l", "-", "1"}], ",", "L"}], "]"}], "]"}], "]"}], 
            "2"]}]]}], ")"}]}], "-", 
      RowBox[{
       FractionBox["\[Pi]", "L"], 
       RowBox[{"(", 
        RowBox[{
         SuperscriptBox["r", "2"], "-", 
         SuperscriptBox[
          RowBox[{"distancetovertices", " ", "[", 
           RowBox[{"[", 
            RowBox[{"newMod", "[", 
             RowBox[{"l", ",", "L"}], "]"}], "]"}], "]"}], "2"]}], ")"}]}]}], 
     ",", 
     RowBox[{
      RowBox[{
       FractionBox[
        SuperscriptBox["r", "2"], "2"], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"ArcCos", "[", 
          FractionBox[
           RowBox[{"pdistancetosides", " ", "[", 
            RowBox[{"[", 
             RowBox[{"newMod", "[", 
              RowBox[{"l", ",", "L"}], "]"}], "]"}], "]"}], "r"], "]"}], "+", 
         RowBox[{"ArcCos", "[", 
          FractionBox[
           RowBox[{"pdistancetosides", " ", "[", 
            RowBox[{"[", 
             RowBox[{"newMod", "[", 
              RowBox[{
               RowBox[{"l", "-", "1"}], ",", "L"}], "]"}], "]"}], "]"}], "r"],
           "]"}]}], ")"}]}], "+", 
      RowBox[{
       FractionBox[
        RowBox[{"pdistancetosides", " ", "[", 
         RowBox[{"[", 
          RowBox[{"newMod", "[", 
           RowBox[{"l", ",", "L"}], "]"}], "]"}], "]"}], "2"], 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"\[Sqrt]", 
          RowBox[{"(", 
           RowBox[{
            SuperscriptBox[
             RowBox[{"distancetovertices", " ", "[", 
              RowBox[{"[", 
               RowBox[{"newMod", "[", 
                RowBox[{"l", ",", "L"}], "]"}], "]"}], "]"}], "2"], " ", "-", 
            " ", 
            SuperscriptBox[
             RowBox[{"pdistancetosides", " ", "[", 
              RowBox[{"[", 
               RowBox[{"newMod", "[", 
                RowBox[{"l", ",", "L"}], "]"}], "]"}], "]"}], "2"]}], ")"}]}],
          "-", 
         SqrtBox[
          RowBox[{
           SuperscriptBox["r", "2"], "-", 
           SuperscriptBox[
            RowBox[{"pdistancetosides", " ", "[", 
             RowBox[{"[", 
              RowBox[{"newMod", "[", 
               RowBox[{"l", ",", "L"}], "]"}], "]"}], "]"}], "2"]}]]}], 
        ")"}]}], "+", " ", 
      RowBox[{
       FractionBox[
        RowBox[{"pdistancetosides", " ", "[", 
         RowBox[{"[", 
          RowBox[{"newMod", "[", 
           RowBox[{
            RowBox[{"l", "-", "1"}], ",", "L"}], "]"}], "]"}], "]"}], "2"], 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"\[Sqrt]", 
          RowBox[{"(", 
           RowBox[{
            SuperscriptBox[
             RowBox[{"distancetovertices", " ", "[", 
              RowBox[{"[", 
               RowBox[{"newMod", "[", 
                RowBox[{"l", ",", "L"}], "]"}], "]"}], "]"}], "2"], " ", "-", 
            " ", 
            SuperscriptBox[
             RowBox[{"pdistancetosides", " ", "[", 
              RowBox[{"[", 
               RowBox[{"newMod", "[", 
                RowBox[{
                 RowBox[{"l", "-", "1"}], ",", "L"}], "]"}], "]"}], "]"}], 
             "2"]}], ")"}]}], "-", 
         SqrtBox[
          RowBox[{
           SuperscriptBox["r", "2"], "-", 
           SuperscriptBox[
            RowBox[{"pdistancetosides", " ", "[", 
             RowBox[{"[", 
              RowBox[{"newMod", "[", 
               RowBox[{
                RowBox[{"l", "-", "1"}], ",", "L"}], "]"}], "]"}], "]"}], 
            "2"]}]]}], ")"}]}], "-", 
      RowBox[{
       FractionBox["\[Pi]", "L"], 
       RowBox[{"(", 
        RowBox[{
         SuperscriptBox["r", "2"], "-", 
         SuperscriptBox[
          RowBox[{"distancetovertices", " ", "[", 
           RowBox[{"[", 
            RowBox[{"newMod", "[", 
             RowBox[{"l", ",", "L"}], "]"}], "]"}], "]"}], "2"]}], 
        ")"}]}]}]}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"temp1CDF", "=", 
   RowBox[{"Table", "[", 
    RowBox[{
     RowBox[{"BL", "[", "l", "]"}], ",", 
     RowBox[{"{", 
      RowBox[{"l", ",", "1", ",", "L", ",", "1"}], "}"}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"temp2CDF", "=", 
   RowBox[{"Table", "[", 
    RowBox[{
     RowBox[{"CL", "[", "l", "]"}], ",", 
     RowBox[{"{", 
      RowBox[{"l", ",", "1", ",", "L", ",", "1"}], "}"}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"boundaryeffectsCDF", "=", 
   RowBox[{"Chop", "[", 
    RowBox[{
     RowBox[{"Flatten", "[", 
      RowBox[{"Append", "[", 
       RowBox[{"temp1CDF", ",", 
        RowBox[{"-", "temp2CDF"}]}], "]"}], "]"}], ",", "tol"}], "]"}]}], 
  ";"}]}], "Input",
 CellChangeTimes->{{3.5762961242536097`*^9, 3.5762961602669725`*^9}, {
   3.576296192575836*^9, 3.576296263320837*^9}, {3.576296305508366*^9, 
   3.5762964763611345`*^9}, {3.5762965865741334`*^9, 3.576296631484407*^9}, {
   3.576306076751272*^9, 3.576306164002226*^9}, {3.576306288708845*^9, 
   3.5763063011108665`*^9}, {3.5763063333249235`*^9, 3.576306382059409*^9}, 
   3.576307134776331*^9, {3.5763105427431145`*^9, 3.5763106119810753`*^9}, 
   3.576350341859375*^9, 3.576896193796875*^9, {3.57689635625*^9, 
   3.57689635990625*^9}, 3.576896744671875*^9, {3.576897360015625*^9, 
   3.576897360671875*^9}}]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
5. Implement the proposed algorithm in Section V in [1] to automatically pick \
the correct border and corner effects for all distance ranges\
\>", "Section",
 CellChangeTimes->{{3.576027393578125*^9, 3.5760274014375*^9}, {
   3.576092745171875*^9, 3.576092746046875*^9}, {3.5762215409375*^9, 
   3.576221546359375*^9}, 3.576351455515625*^9, {3.57635566071875*^9, 
   3.576355665453125*^9}, {3.576706334078125*^9, 3.576706374265625*^9}, {
   3.57678542803125*^9, 3.57678542990625*^9}}],

Cell["\<\
Find and sort the distance vector and then find the indices k: Equation (10) \
and Steps 1 & 2 in Algorithm 1 in [1]\
\>", "Text",
 CellChangeTimes->{{3.5758598382841253`*^9, 3.5758598474872503`*^9}, 
   3.57594974540625*^9, {3.57602647625*^9, 3.576026476609375*^9}, {
   3.5760266014375*^9, 3.57602665015625*^9}, {3.576026684296875*^9, 
   3.57602671296875*^9}, {3.5761374898125*^9, 3.5761374903125*^9}, {
   3.57613777378125*^9, 3.576137777890625*^9}, {3.576139226609375*^9, 
   3.57613922709375*^9}, {3.576139939203125*^9, 3.5761399694375*^9}, {
   3.57622153275*^9, 3.57622153871875*^9}, {3.576350660578125*^9, 
   3.576350684484375*^9}, {3.57635434896875*^9, 3.5763544164375*^9}, {
   3.576375151890747*^9, 3.576375155125204*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"distances", "=", 
   RowBox[{"Join", "[", 
    RowBox[{"distancetosides", ",", "distancetovertices"}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{"Sorteddistances", " ", "=", " ", 
  RowBox[{"Sort", "[", 
   RowBox[{"distances", ",", "Less"}], "]"}]}], "\[IndentingNewLine]", 
 RowBox[{"k", "=", 
  RowBox[{"Reverse", "[", 
   RowBox[{"Ordering", "[", 
    RowBox[{"distances", ",", "All", ",", "Greater"}], "]"}], 
   "]"}]}]}], "Input",
 CellChangeTimes->{{3.57594839265625*^9, 3.57594840984375*^9}, {
   3.575948452140625*^9, 3.575948466421875*^9}, {3.57594882915625*^9, 
   3.57594889553125*^9}, {3.575948959859375*^9, 3.5759489905625*^9}, {
   3.57594910503125*^9, 3.5759491139375*^9}, {3.575949150875*^9, 
   3.575949152296875*^9}, {3.575949205984375*^9, 3.57594924771875*^9}, 
   3.57594928065625*^9, {3.5759493455*^9, 3.57594938725*^9}, {
   3.575949489703125*^9, 3.575949524359375*^9}, {3.5759496805625*^9, 
   3.5759496913125*^9}, {3.5759497509375*^9, 3.57594978346875*^9}, {
   3.5759523463125*^9, 3.575952346484375*^9}, {3.575953708359375*^9, 
   3.575953740953125*^9}, {3.575953865359375*^9, 3.575953881671875*^9}, {
   3.57595393771875*^9, 3.57595394375*^9}, {3.57595405265625*^9, 
   3.5759540756875*^9}, 3.575955405046875*^9, 3.57595582603125*^9, {
   3.575957267859375*^9, 3.57595731803125*^9}, 3.5759698075*^9, {
   3.57597006690625*^9, 3.575970088328125*^9}, {3.57597015528125*^9, 
   3.57597015596875*^9}, {3.57601003321875*^9, 3.576010045375*^9}, {
   3.576010206671875*^9, 3.5760102714375*^9}, {3.576010338671875*^9, 
   3.57601034925*^9}, {3.576010453375*^9, 3.576010453890625*^9}, {
   3.576010510828125*^9, 3.576010519890625*^9}, {3.57601088228125*^9, 
   3.576010979703125*^9}, {3.576011133046875*^9, 3.576011183*^9}, {
   3.576011215796875*^9, 3.576011248640625*^9}, {3.576011329328125*^9, 
   3.576011332140625*^9}, {3.576011409625*^9, 3.5760114208125*^9}, {
   3.5760116659375*^9, 3.576011673671875*^9}, {3.576011778125*^9, 
   3.5760118604375*^9}, {3.576012115859375*^9, 3.57601216090625*^9}, {
   3.576012428671875*^9, 3.576012479046875*^9}, {3.57601251728125*^9, 
   3.576012673375*^9}, {3.576013837921875*^9, 3.576013843453125*^9}, {
   3.576013944*^9, 3.576013977890625*^9}, {3.57601435190625*^9, 
   3.576014355046875*^9}, {3.57601702078125*^9, 3.576017065609375*^9}, 
   3.576019068609375*^9, {3.57602066096875*^9, 3.576020675125*^9}, 
   3.57602236746875*^9, {3.57602655725*^9, 3.576026606015625*^9}, {
   3.576026658125*^9, 3.576026681625*^9}, {3.57602672009375*^9, 
   3.576026723484375*^9}, {3.57613746978125*^9, 3.5761374874375*^9}, {
   3.57613775184375*^9, 3.576137784046875*^9}, {3.57620394540625*^9, 
   3.57620394715625*^9}, {3.576204264625*^9, 3.576204275296875*^9}, {
   3.57620791365625*^9, 3.576207915671875*^9}, 3.576275436104391*^9, {
   3.576278061527867*^9, 3.576278118554737*^9}, {3.5762787293856306`*^9, 
   3.5762787304636726`*^9}, {3.5762940311131487`*^9, 
   3.5762940717509127`*^9}, {3.576364815722729*^9, 3.5763648163945227`*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"0", ",", 
   FractionBox["1", 
    SqrtBox["2"]], ",", 
   FractionBox["1", 
    SqrtBox["2"]], ",", 
   FractionBox["1", 
    SqrtBox["2"]], ",", 
   FractionBox["1", 
    SqrtBox["2"]], ",", 
   SqrtBox["2"], ",", 
   SqrtBox[
    FractionBox["5", "2"]], ",", 
   SqrtBox[
    FractionBox["5", "2"]]}], "}"}]], "Output",
 CellChangeTimes->{
  3.5758473356591253`*^9, {3.5758473866747503`*^9, 3.5758473920341253`*^9}, {
   3.5758474295497503`*^9, 3.5758474437216253`*^9}, {3.5758475103935003`*^9, 
   3.5758475235497503`*^9}, 3.5758476718622503`*^9, 3.5758477487528753`*^9, 
   3.5758486032528753`*^9, 3.5758486554403753`*^9, 3.5758488587841253`*^9, 
   3.5758490066903753`*^9, 3.5758569506747503`*^9, {3.5758570420341253`*^9, 
   3.5758570582216253`*^9}, 3.5758572761278753`*^9, {3.5758573628778753`*^9, 
   3.5758573891591253`*^9}, 3.5758574710497503`*^9, 3.5758576145341253`*^9, 
   3.5758578030185003`*^9, 3.5758578655653753`*^9, 3.5758579227841253`*^9, {
   3.5758579644872503`*^9, 3.5758579904560003`*^9}, {3.5758583041747503`*^9, 
   3.5758583356591253`*^9}, {3.5758586286435003`*^9, 3.5758586735966253`*^9}, 
   3.5758594012841253`*^9, 3.5758594471747503`*^9, 3.5758595048310003`*^9, {
   3.5758597360497503`*^9, 3.5758597652685003`*^9}, {3.5758597991903753`*^9, 
   3.5758598222060003`*^9}, 3.5758598613935003`*^9, 3.5758600095966253`*^9, {
   3.5758600634560003`*^9, 3.5758600840028753`*^9}, 3.5758601469560003`*^9, {
   3.5758602039091253`*^9, 3.5758602566747503`*^9}, 3.5758608193935003`*^9, 
   3.5758608576122503`*^9, 3.5758610894560003`*^9, 3.5758611584560003`*^9, 
   3.5758612285028753`*^9, 3.5758612599560003`*^9, 3.575934534015625*^9, 
   3.57593458075*^9, 3.57594139825*^9, 3.575941463078125*^9, 
   3.57594183553125*^9, 3.57594188815625*^9, 3.57594540975*^9, 
   3.575946445015625*^9, 3.575946498484375*^9, 3.575948340296875*^9, {
   3.575948403859375*^9, 3.57594841071875*^9}, {3.5759484675625*^9, 
   3.57594849671875*^9}, 3.57594855965625*^9, 3.575948605046875*^9, 
   3.57594872903125*^9, {3.5759488693125*^9, 3.575948882921875*^9}, {
   3.575948973453125*^9, 3.575948992125*^9}, 3.575949033375*^9, {
   3.575949106109375*^9, 3.5759491158125*^9}, 3.57594915575*^9, 
   3.575949251140625*^9, 3.575949286015625*^9, {3.575949350796875*^9, 
   3.5759494174375*^9}, {3.57594951659375*^9, 3.57594952528125*^9}, {
   3.575949683765625*^9, 3.575949710859375*^9}, {3.575949776640625*^9, 
   3.575949794421875*^9}, 3.575951801796875*^9, 3.57595201146875*^9, 
   3.575952258609375*^9, 3.57595231178125*^9, 3.575952347515625*^9, {
   3.575953728921875*^9, 3.575953745765625*^9}, {3.575953883609375*^9, 
   3.5759538984375*^9}, 3.57595394584375*^9, {3.575953993375*^9, 
   3.575954013328125*^9}, {3.575954055390625*^9, 3.575954077828125*^9}, 
   3.575954155328125*^9, 3.575955029703125*^9, 3.57595540796875*^9, 
   3.575955685703125*^9, 3.5759557460625*^9, 3.575955977125*^9, 
   3.5759560285*^9, 3.575956353171875*^9, 3.57595652203125*^9, 
   3.57595679525*^9, 3.57595689946875*^9, 3.575956967015625*^9, {
   3.575957073390625*^9, 3.57595709396875*^9}, 3.5759571398125*^9, {
   3.575957319640625*^9, 3.575957333125*^9}, 3.575957364015625*^9, {
   3.575960740953125*^9, 3.5759607546875*^9}, 3.575960904671875*^9, 
   3.57596121459375*^9, 3.575961294015625*^9, {3.57596143265625*^9, 
   3.575961440203125*^9}, 3.575961528859375*^9, {3.575961610359375*^9, 
   3.57596163715625*^9}, 3.575961920015625*^9, 3.575961952421875*^9, {
   3.575963163265625*^9, 3.57596318359375*^9}, 3.57596335965625*^9, 
   3.575963440734375*^9, {3.575963645265625*^9, 3.5759636746875*^9}, 
   3.575963829578125*^9, 3.57596387209375*^9, 3.5759639545*^9, 
   3.575963986625*^9, 3.575964466359375*^9, {3.575964586515625*^9, 
   3.575964605703125*^9}, 3.5759650155*^9, 3.575965214109375*^9, 
   3.57596589446875*^9, 3.57596596715625*^9, 3.57596611325*^9, 
   3.575966185328125*^9, 3.575966401328125*^9, 3.5759664431875*^9, 
   3.575966948625*^9, 3.575967034109375*^9, 3.575967551734375*^9, 
   3.575967817078125*^9, 3.57596785390625*^9, 3.57596850725*^9, 
   3.575968591421875*^9, 3.57596862409375*^9, {3.575969249171875*^9, 
   3.575969261109375*^9}, 3.575969308703125*^9, 3.575969351015625*^9, 
   3.57596962659375*^9, 3.575969763484375*^9, {3.575969979875*^9, 
   3.575970020390625*^9}, {3.575970071640625*^9, 3.575970091828125*^9}, 
   3.57597015815625*^9, {3.57597020240625*^9, 3.575970206921875*^9}, 
   3.575970393703125*^9, 3.575970432859375*^9, 3.57597050678125*^9, 
   3.57600237415625*^9, 3.576002980265625*^9, 3.5760031113125*^9, 
   3.576003984703125*^9, 3.5760052838125*^9, 3.576007187796875*^9, 
   3.576008131078125*^9, 3.576008243953125*^9, 3.576008300546875*^9, 
   3.576008349765625*^9, 3.576008690703125*^9, 3.57600881378125*^9, {
   3.576009293203125*^9, 3.576009300078125*^9}, 3.576010046828125*^9, {
   3.57601026603125*^9, 3.576010273390625*^9}, 3.57601035046875*^9, 
   3.57601045615625*^9, 3.576010515921875*^9, 3.576010980953125*^9, {
   3.5760111435*^9, 3.57601118009375*^9}, {3.576011221109375*^9, 
   3.576011253359375*^9}, 3.576011334953125*^9, {3.57601141259375*^9, 
   3.57601142140625*^9}, 3.57601167571875*^9, {3.57601179071875*^9, 
   3.576011862640625*^9}, {3.5760121236875*^9, 3.576012162296875*^9}, {
   3.576012452546875*^9, 3.576012472671875*^9}, {3.576012519703125*^9, 
   3.576012586546875*^9}, {3.5760126405625*^9, 3.57601266409375*^9}, 
   3.57601286025*^9, 3.5760131854375*^9, 3.576013229375*^9, 3.576013276375*^9,
    3.576013561609375*^9, 3.57601361503125*^9, 3.576013790046875*^9, 
   3.5760138460625*^9, 3.57601394809375*^9, 3.57601397965625*^9, {
   3.576014332296875*^9, 3.57601434178125*^9}, 3.576014373984375*^9, 
   3.5760147745625*^9, 3.57601483296875*^9, {3.576014964453125*^9, 
   3.5760149791875*^9}, 3.576015707859375*^9, 3.57601594190625*^9, 
   3.576016617703125*^9, 3.576016813796875*^9, 3.57601692096875*^9, 
   3.576016991765625*^9, {3.57601702659375*^9, 3.576017060125*^9}, 
   3.576019077109375*^9, 3.57601919796875*^9, 3.576019358171875*^9, 
   3.5760194796875*^9, 3.576019568171875*^9, 3.576019909984375*^9, 
   3.57602039659375*^9, 3.5760205335625*^9, 3.576020613390625*^9, 
   3.576020662625*^9, 3.576020800671875*^9, {3.57602121846875*^9, 
   3.576021255359375*^9}, 3.576021289234375*^9, 3.576021362625*^9, 
   3.5760214910625*^9, {3.576021555296875*^9, 3.576021570734375*^9}, 
   3.576021776671875*^9, {3.576021822078125*^9, 3.57602184025*^9}, 
   3.5760219100625*^9, 3.57602230415625*^9, 3.5760223709375*^9, {
   3.576025108734375*^9, 3.57602512921875*^9}, {3.57602561853125*^9, 
   3.576025659578125*^9}, {3.576025960828125*^9, 3.57602597590625*^9}, {
   3.576026099328125*^9, 3.5760261225625*^9}, 3.576026664765625*^9, {
   3.5760267023125*^9, 3.5760267244375*^9}, 3.576027493046875*^9, 
   3.5760276534375*^9, 3.576028672875*^9, {3.576029684890625*^9, 
   3.576029697015625*^9}, 3.57602974171875*^9, 3.576030319375*^9, 
   3.576030523625*^9, 3.576031951109375*^9, {3.576032031859375*^9, 
   3.576032058328125*^9}, 3.576032149921875*^9, 3.57603220075*^9, 
   3.57603223896875*^9, 3.576032282296875*^9, 3.576092705421875*^9, {
   3.57609276928125*^9, 3.576092795453125*^9}, 3.576135975265625*^9, 
   3.576136208484375*^9, 3.57613636559375*^9, 3.576136404953125*^9, 
   3.5761364514375*^9, 3.57613651134375*^9, 3.576136568140625*^9, 
   3.576136687578125*^9, {3.57613672740625*^9, 3.576136757390625*^9}, 
   3.576136801109375*^9, {3.576136832828125*^9, 3.576136855421875*^9}, 
   3.57613693084375*^9, {3.576137008859375*^9, 3.57613706215625*^9}, 
   3.576137095578125*^9, {3.576137230890625*^9, 3.57613725640625*^9}, {
   3.5761374775*^9, 3.576137491859375*^9}, 3.576137753625*^9, {
   3.57613778565625*^9, 3.576137842984375*^9}, 3.5761378871875*^9, 
   3.576137933421875*^9, 3.576137985484375*^9, 3.5761383731875*^9, 
   3.5761388859375*^9, 3.576138929171875*^9, {3.576138973*^9, 
   3.576139018671875*^9}, 3.576139077265625*^9, 3.576139110234375*^9, 
   3.576139338625*^9, {3.576139385171875*^9, 3.57613939375*^9}, {
   3.57613942490625*^9, 3.57613944078125*^9}, {3.5761395200625*^9, 
   3.57613957096875*^9}, 3.5761396021875*^9, 3.576139746046875*^9, {
   3.576177302328125*^9, 3.57617732715625*^9}, 3.576177425078125*^9, 
   3.57617746240625*^9, {3.57617756246875*^9, 3.5761775965625*^9}, {
   3.57617763675*^9, 3.576177668890625*^9}, 3.57618631303125*^9, 
   3.576186416140625*^9, 3.576186572984375*^9, 3.576186606234375*^9, 
   3.5761866924375*^9, 3.5761871418125*^9, {3.5761874165*^9, 
   3.576187428609375*^9}, 3.57618778875*^9, 3.57618788134375*^9, 
   3.576188228578125*^9, 3.5761892331875*^9, {3.576189330875*^9, 
   3.576189353328125*^9}, 3.576190006234375*^9, 3.57619015296875*^9, 
   3.576190370796875*^9, {3.576190778546875*^9, 3.576190808015625*^9}, 
   3.5761908385*^9, {3.57619094671875*^9, 3.5761909638125*^9}, 
   3.5762027040885553`*^9, 3.5762027407109776`*^9, 3.5762028849351983`*^9, {
   3.5762029420874243`*^9, 3.576202970319812*^9}, 3.5762030661411905`*^9, {
   3.576203896421875*^9, 3.576203949296875*^9}, {3.576204007859375*^9, 
   3.57620406925*^9}, {3.576204099375*^9, 3.576204130890625*^9}, 
   3.576204174234375*^9, 3.576204232421875*^9, {3.57620426575*^9, 
   3.57620427590625*^9}, 3.576207972890625*^9, 3.576210862828125*^9, {
   3.576210989890625*^9, 3.57621100215625*^9}, {3.57621119278125*^9, 
   3.5762112070625*^9}, 3.576211343234375*^9, {3.57621150725*^9, 
   3.57621151515625*^9}, 3.57621169484375*^9, 3.576211738234375*^9, 
   3.576212182875*^9, 3.576212226859375*^9, 3.576212352484375*^9, 
   3.576212408390625*^9, {3.57621244815625*^9, 3.576212510671875*^9}, {
   3.57621255684375*^9, 3.5762125764375*^9}, {3.576212698015625*^9, 
   3.57621273384375*^9}, 3.576213102625*^9, 3.576213303671875*^9, 
   3.57621351803125*^9, 3.57621355296875*^9, {3.576213617953125*^9, 
   3.576213630953125*^9}, {3.576213673453125*^9, 3.576213703359375*^9}, 
   3.576213806203125*^9, 3.57621389403125*^9, 3.576213953265625*^9, 
   3.576214008609375*^9, {3.576214101078125*^9, 3.576214125125*^9}, 
   3.57622092115625*^9, 3.576221004625*^9, 3.576221037328125*^9, 
   3.576221117765625*^9, 3.5762214138125*^9, 3.5762216043125*^9, 
   3.57622507165625*^9, 3.576225115890625*^9, 3.576225155625*^9, 
   3.576225200609375*^9, 3.576225251609375*^9, 3.57622539625*^9, 
   3.576225495453125*^9, 3.576225545859375*^9, 3.576225585421875*^9, 
   3.576225654015625*^9, 3.57622570596875*^9, 3.57622573678125*^9, 
   3.57622588109375*^9, 3.5762264564375*^9, {3.57626287171875*^9, 
   3.576262943546875*^9}, 3.576262974296875*^9, 3.576263008125*^9, 
   3.57627543738551*^9, 3.5762778227649555`*^9, 3.5762780872758894`*^9, 
   3.5762781197577696`*^9, {3.576278178300148*^9, 3.57627820568867*^9}, 
   3.5762782504042716`*^9, 3.576278324008465*^9, 3.576278447046677*^9, 
   3.5762784863407855`*^9, 3.576278541274418*^9, 3.5762786147692437`*^9, 
   3.5762786625938854`*^9, 3.576278715292963*^9, 3.576294478831627*^9, 
   3.5762945761372757`*^9, 3.5762946297897487`*^9, 3.576294754218488*^9, 
   3.5762948960678763`*^9, {3.5762949410490847`*^9, 3.576295190297161*^9}, {
   3.576295224122905*^9, 3.5762952673073645`*^9}, {3.576295362347548*^9, 
   3.5762953842678795`*^9}, 3.5762954176092825`*^9, {3.576295457950192*^9, 
   3.5762955240549126`*^9}, 3.5763067191760006`*^9, 3.5763106731165714`*^9, 
   3.576311435766193*^9, 3.5763114700461535`*^9, 3.5763116107232*^9, 
   3.57631170653368*^9, 3.5763118649427404`*^9, 3.5763119203759108`*^9, 
   3.576311977096155*^9, 3.5763120464471216`*^9, 3.576312122134451*^9, 
   3.576350002828125*^9, 3.57635149103125*^9, 3.576351590484375*^9, 
   3.57635175778125*^9, 3.576355441671875*^9, 3.576355743296875*^9, {
   3.57635729265625*^9, 3.57635731765625*^9}, 3.57635735828125*^9, 
   3.576357484890625*^9, 3.576357567546875*^9, 3.5763577063125*^9, 
   3.5763647911007233`*^9, 3.5763648633273706`*^9, 3.576364925010528*^9, 
   3.576365014566723*^9, {3.5763705638909326`*^9, 3.5763705927333903`*^9}, 
   3.5763708036614404`*^9, 3.5763752698468914`*^9, 3.5763754028025465`*^9, 
   3.57638014909766*^9, 3.576380208985985*^9, 3.5763802855142965`*^9, 
   3.5763803346999073`*^9, 3.5763803870416474`*^9, 3.5763804692728643`*^9, {
   3.5763805294111805`*^9, 3.576380556425768*^9}, {3.5764597383442497`*^9, 
   3.5764597598911247`*^9}, 3.5764601446879997`*^9, 3.5764604470317497`*^9, 
   3.5764605362661247`*^9, 3.5764605921254997`*^9, 3.5764607038129997`*^9, 
   3.5764607740629997`*^9, 3.5764608340317497`*^9, 3.5764609211879997`*^9, 
   3.5764610757817497`*^9, {3.5764611272661247`*^9, 3.5764611542192497`*^9}, 
   3.57670640575*^9, {3.5767066549375*^9, 3.576706677875*^9}, 
   3.5767067550625*^9, {3.576706801703125*^9, 3.576706825515625*^9}, 
   3.576785654765625*^9, 3.5767862023125*^9, 3.57678708615625*^9, 
   3.576787161578125*^9, 3.576788345140625*^9, {3.576789280671875*^9, 
   3.57678930784375*^9}, 3.5767894865*^9, 3.576789562921875*^9, 
   3.576789625765625*^9, 3.576790691984375*^9, 3.576790934390625*^9, 
   3.5767911079375*^9, 3.576791687359375*^9, 3.57689590596875*^9, 
   3.576895952203125*^9, 3.576896085828125*^9, 3.576896136625*^9, 
   3.576896377484375*^9, 3.5768967351875*^9, {3.5768970149375*^9, 
   3.576897051328125*^9}, 3.576897191375*^9, 3.576897241046875*^9, 
   3.57689989678125*^9, 3.576960963375*^9, 3.576961066359375*^9, 
   3.576961138140625*^9}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
  "4", ",", "1", ",", "3", ",", "5", ",", "8", ",", "2", ",", "6", ",", "7"}],
   "}"}]], "Output",
 CellChangeTimes->{
  3.5758473356591253`*^9, {3.5758473866747503`*^9, 3.5758473920341253`*^9}, {
   3.5758474295497503`*^9, 3.5758474437216253`*^9}, {3.5758475103935003`*^9, 
   3.5758475235497503`*^9}, 3.5758476718622503`*^9, 3.5758477487528753`*^9, 
   3.5758486032528753`*^9, 3.5758486554403753`*^9, 3.5758488587841253`*^9, 
   3.5758490066903753`*^9, 3.5758569506747503`*^9, {3.5758570420341253`*^9, 
   3.5758570582216253`*^9}, 3.5758572761278753`*^9, {3.5758573628778753`*^9, 
   3.5758573891591253`*^9}, 3.5758574710497503`*^9, 3.5758576145341253`*^9, 
   3.5758578030185003`*^9, 3.5758578655653753`*^9, 3.5758579227841253`*^9, {
   3.5758579644872503`*^9, 3.5758579904560003`*^9}, {3.5758583041747503`*^9, 
   3.5758583356591253`*^9}, {3.5758586286435003`*^9, 3.5758586735966253`*^9}, 
   3.5758594012841253`*^9, 3.5758594471747503`*^9, 3.5758595048310003`*^9, {
   3.5758597360497503`*^9, 3.5758597652685003`*^9}, {3.5758597991903753`*^9, 
   3.5758598222060003`*^9}, 3.5758598613935003`*^9, 3.5758600095966253`*^9, {
   3.5758600634560003`*^9, 3.5758600840028753`*^9}, 3.5758601469560003`*^9, {
   3.5758602039091253`*^9, 3.5758602566747503`*^9}, 3.5758608193935003`*^9, 
   3.5758608576122503`*^9, 3.5758610894560003`*^9, 3.5758611584560003`*^9, 
   3.5758612285028753`*^9, 3.5758612599560003`*^9, 3.575934534015625*^9, 
   3.57593458075*^9, 3.57594139825*^9, 3.575941463078125*^9, 
   3.57594183553125*^9, 3.57594188815625*^9, 3.57594540975*^9, 
   3.575946445015625*^9, 3.575946498484375*^9, 3.575948340296875*^9, {
   3.575948403859375*^9, 3.57594841071875*^9}, {3.5759484675625*^9, 
   3.57594849671875*^9}, 3.57594855965625*^9, 3.575948605046875*^9, 
   3.57594872903125*^9, {3.5759488693125*^9, 3.575948882921875*^9}, {
   3.575948973453125*^9, 3.575948992125*^9}, 3.575949033375*^9, {
   3.575949106109375*^9, 3.5759491158125*^9}, 3.57594915575*^9, 
   3.575949251140625*^9, 3.575949286015625*^9, {3.575949350796875*^9, 
   3.5759494174375*^9}, {3.57594951659375*^9, 3.57594952528125*^9}, {
   3.575949683765625*^9, 3.575949710859375*^9}, {3.575949776640625*^9, 
   3.575949794421875*^9}, 3.575951801796875*^9, 3.57595201146875*^9, 
   3.575952258609375*^9, 3.57595231178125*^9, 3.575952347515625*^9, {
   3.575953728921875*^9, 3.575953745765625*^9}, {3.575953883609375*^9, 
   3.5759538984375*^9}, 3.57595394584375*^9, {3.575953993375*^9, 
   3.575954013328125*^9}, {3.575954055390625*^9, 3.575954077828125*^9}, 
   3.575954155328125*^9, 3.575955029703125*^9, 3.57595540796875*^9, 
   3.575955685703125*^9, 3.5759557460625*^9, 3.575955977125*^9, 
   3.5759560285*^9, 3.575956353171875*^9, 3.57595652203125*^9, 
   3.57595679525*^9, 3.57595689946875*^9, 3.575956967015625*^9, {
   3.575957073390625*^9, 3.57595709396875*^9}, 3.5759571398125*^9, {
   3.575957319640625*^9, 3.575957333125*^9}, 3.575957364015625*^9, {
   3.575960740953125*^9, 3.5759607546875*^9}, 3.575960904671875*^9, 
   3.57596121459375*^9, 3.575961294015625*^9, {3.57596143265625*^9, 
   3.575961440203125*^9}, 3.575961528859375*^9, {3.575961610359375*^9, 
   3.57596163715625*^9}, 3.575961920015625*^9, 3.575961952421875*^9, {
   3.575963163265625*^9, 3.57596318359375*^9}, 3.57596335965625*^9, 
   3.575963440734375*^9, {3.575963645265625*^9, 3.5759636746875*^9}, 
   3.575963829578125*^9, 3.57596387209375*^9, 3.5759639545*^9, 
   3.575963986625*^9, 3.575964466359375*^9, {3.575964586515625*^9, 
   3.575964605703125*^9}, 3.5759650155*^9, 3.575965214109375*^9, 
   3.57596589446875*^9, 3.57596596715625*^9, 3.57596611325*^9, 
   3.575966185328125*^9, 3.575966401328125*^9, 3.5759664431875*^9, 
   3.575966948625*^9, 3.575967034109375*^9, 3.575967551734375*^9, 
   3.575967817078125*^9, 3.57596785390625*^9, 3.57596850725*^9, 
   3.575968591421875*^9, 3.57596862409375*^9, {3.575969249171875*^9, 
   3.575969261109375*^9}, 3.575969308703125*^9, 3.575969351015625*^9, 
   3.57596962659375*^9, 3.575969763484375*^9, {3.575969979875*^9, 
   3.575970020390625*^9}, {3.575970071640625*^9, 3.575970091828125*^9}, 
   3.57597015815625*^9, {3.57597020240625*^9, 3.575970206921875*^9}, 
   3.575970393703125*^9, 3.575970432859375*^9, 3.57597050678125*^9, 
   3.57600237415625*^9, 3.576002980265625*^9, 3.5760031113125*^9, 
   3.576003984703125*^9, 3.5760052838125*^9, 3.576007187796875*^9, 
   3.576008131078125*^9, 3.576008243953125*^9, 3.576008300546875*^9, 
   3.576008349765625*^9, 3.576008690703125*^9, 3.57600881378125*^9, {
   3.576009293203125*^9, 3.576009300078125*^9}, 3.576010046828125*^9, {
   3.57601026603125*^9, 3.576010273390625*^9}, 3.57601035046875*^9, 
   3.57601045615625*^9, 3.576010515921875*^9, 3.576010980953125*^9, {
   3.5760111435*^9, 3.57601118009375*^9}, {3.576011221109375*^9, 
   3.576011253359375*^9}, 3.576011334953125*^9, {3.57601141259375*^9, 
   3.57601142140625*^9}, 3.57601167571875*^9, {3.57601179071875*^9, 
   3.576011862640625*^9}, {3.5760121236875*^9, 3.576012162296875*^9}, {
   3.576012452546875*^9, 3.576012472671875*^9}, {3.576012519703125*^9, 
   3.576012586546875*^9}, {3.5760126405625*^9, 3.57601266409375*^9}, 
   3.57601286025*^9, 3.5760131854375*^9, 3.576013229375*^9, 3.576013276375*^9,
    3.576013561609375*^9, 3.57601361503125*^9, 3.576013790046875*^9, 
   3.5760138460625*^9, 3.57601394809375*^9, 3.57601397965625*^9, {
   3.576014332296875*^9, 3.57601434178125*^9}, 3.576014373984375*^9, 
   3.5760147745625*^9, 3.57601483296875*^9, {3.576014964453125*^9, 
   3.5760149791875*^9}, 3.576015707859375*^9, 3.57601594190625*^9, 
   3.576016617703125*^9, 3.576016813796875*^9, 3.57601692096875*^9, 
   3.576016991765625*^9, {3.57601702659375*^9, 3.576017060125*^9}, 
   3.576019077109375*^9, 3.57601919796875*^9, 3.576019358171875*^9, 
   3.5760194796875*^9, 3.576019568171875*^9, 3.576019909984375*^9, 
   3.57602039659375*^9, 3.5760205335625*^9, 3.576020613390625*^9, 
   3.576020662625*^9, 3.576020800671875*^9, {3.57602121846875*^9, 
   3.576021255359375*^9}, 3.576021289234375*^9, 3.576021362625*^9, 
   3.5760214910625*^9, {3.576021555296875*^9, 3.576021570734375*^9}, 
   3.576021776671875*^9, {3.576021822078125*^9, 3.57602184025*^9}, 
   3.5760219100625*^9, 3.57602230415625*^9, 3.5760223709375*^9, {
   3.576025108734375*^9, 3.57602512921875*^9}, {3.57602561853125*^9, 
   3.576025659578125*^9}, {3.576025960828125*^9, 3.57602597590625*^9}, {
   3.576026099328125*^9, 3.5760261225625*^9}, 3.576026664765625*^9, {
   3.5760267023125*^9, 3.5760267244375*^9}, 3.576027493046875*^9, 
   3.5760276534375*^9, 3.576028672875*^9, {3.576029684890625*^9, 
   3.576029697015625*^9}, 3.57602974171875*^9, 3.576030319375*^9, 
   3.576030523625*^9, 3.576031951109375*^9, {3.576032031859375*^9, 
   3.576032058328125*^9}, 3.576032149921875*^9, 3.57603220075*^9, 
   3.57603223896875*^9, 3.576032282296875*^9, 3.576092705421875*^9, {
   3.57609276928125*^9, 3.576092795453125*^9}, 3.576135975265625*^9, 
   3.576136208484375*^9, 3.57613636559375*^9, 3.576136404953125*^9, 
   3.5761364514375*^9, 3.57613651134375*^9, 3.576136568140625*^9, 
   3.576136687578125*^9, {3.57613672740625*^9, 3.576136757390625*^9}, 
   3.576136801109375*^9, {3.576136832828125*^9, 3.576136855421875*^9}, 
   3.57613693084375*^9, {3.576137008859375*^9, 3.57613706215625*^9}, 
   3.576137095578125*^9, {3.576137230890625*^9, 3.57613725640625*^9}, {
   3.5761374775*^9, 3.576137491859375*^9}, 3.576137753625*^9, {
   3.57613778565625*^9, 3.576137842984375*^9}, 3.5761378871875*^9, 
   3.576137933421875*^9, 3.576137985484375*^9, 3.5761383731875*^9, 
   3.5761388859375*^9, 3.576138929171875*^9, {3.576138973*^9, 
   3.576139018671875*^9}, 3.576139077265625*^9, 3.576139110234375*^9, 
   3.576139338625*^9, {3.576139385171875*^9, 3.57613939375*^9}, {
   3.57613942490625*^9, 3.57613944078125*^9}, {3.5761395200625*^9, 
   3.57613957096875*^9}, 3.5761396021875*^9, 3.576139746046875*^9, {
   3.576177302328125*^9, 3.57617732715625*^9}, 3.576177425078125*^9, 
   3.57617746240625*^9, {3.57617756246875*^9, 3.5761775965625*^9}, {
   3.57617763675*^9, 3.576177668890625*^9}, 3.57618631303125*^9, 
   3.576186416140625*^9, 3.576186572984375*^9, 3.576186606234375*^9, 
   3.5761866924375*^9, 3.5761871418125*^9, {3.5761874165*^9, 
   3.576187428609375*^9}, 3.57618778875*^9, 3.57618788134375*^9, 
   3.576188228578125*^9, 3.5761892331875*^9, {3.576189330875*^9, 
   3.576189353328125*^9}, 3.576190006234375*^9, 3.57619015296875*^9, 
   3.576190370796875*^9, {3.576190778546875*^9, 3.576190808015625*^9}, 
   3.5761908385*^9, {3.57619094671875*^9, 3.5761909638125*^9}, 
   3.5762027040885553`*^9, 3.5762027407109776`*^9, 3.5762028849351983`*^9, {
   3.5762029420874243`*^9, 3.576202970319812*^9}, 3.5762030661411905`*^9, {
   3.576203896421875*^9, 3.576203949296875*^9}, {3.576204007859375*^9, 
   3.57620406925*^9}, {3.576204099375*^9, 3.576204130890625*^9}, 
   3.576204174234375*^9, 3.576204232421875*^9, {3.57620426575*^9, 
   3.57620427590625*^9}, 3.576207972890625*^9, 3.576210862828125*^9, {
   3.576210989890625*^9, 3.57621100215625*^9}, {3.57621119278125*^9, 
   3.5762112070625*^9}, 3.576211343234375*^9, {3.57621150725*^9, 
   3.57621151515625*^9}, 3.57621169484375*^9, 3.576211738234375*^9, 
   3.576212182875*^9, 3.576212226859375*^9, 3.576212352484375*^9, 
   3.576212408390625*^9, {3.57621244815625*^9, 3.576212510671875*^9}, {
   3.57621255684375*^9, 3.5762125764375*^9}, {3.576212698015625*^9, 
   3.57621273384375*^9}, 3.576213102625*^9, 3.576213303671875*^9, 
   3.57621351803125*^9, 3.57621355296875*^9, {3.576213617953125*^9, 
   3.576213630953125*^9}, {3.576213673453125*^9, 3.576213703359375*^9}, 
   3.576213806203125*^9, 3.57621389403125*^9, 3.576213953265625*^9, 
   3.576214008609375*^9, {3.576214101078125*^9, 3.576214125125*^9}, 
   3.57622092115625*^9, 3.576221004625*^9, 3.576221037328125*^9, 
   3.576221117765625*^9, 3.5762214138125*^9, 3.5762216043125*^9, 
   3.57622507165625*^9, 3.576225115890625*^9, 3.576225155625*^9, 
   3.576225200609375*^9, 3.576225251609375*^9, 3.57622539625*^9, 
   3.576225495453125*^9, 3.576225545859375*^9, 3.576225585421875*^9, 
   3.576225654015625*^9, 3.57622570596875*^9, 3.57622573678125*^9, 
   3.57622588109375*^9, 3.5762264564375*^9, {3.57626287171875*^9, 
   3.576262943546875*^9}, 3.576262974296875*^9, 3.576263008125*^9, 
   3.57627543738551*^9, 3.5762778227649555`*^9, 3.5762780872758894`*^9, 
   3.5762781197577696`*^9, {3.576278178300148*^9, 3.57627820568867*^9}, 
   3.5762782504042716`*^9, 3.576278324008465*^9, 3.576278447046677*^9, 
   3.5762784863407855`*^9, 3.576278541274418*^9, 3.5762786147692437`*^9, 
   3.5762786625938854`*^9, 3.576278715292963*^9, 3.576294478831627*^9, 
   3.5762945761372757`*^9, 3.5762946297897487`*^9, 3.576294754218488*^9, 
   3.5762948960678763`*^9, {3.5762949410490847`*^9, 3.576295190297161*^9}, {
   3.576295224122905*^9, 3.5762952673073645`*^9}, {3.576295362347548*^9, 
   3.5762953842678795`*^9}, 3.5762954176092825`*^9, {3.576295457950192*^9, 
   3.5762955240549126`*^9}, 3.5763067191760006`*^9, 3.5763106731165714`*^9, 
   3.576311435766193*^9, 3.5763114700461535`*^9, 3.5763116107232*^9, 
   3.57631170653368*^9, 3.5763118649427404`*^9, 3.5763119203759108`*^9, 
   3.576311977096155*^9, 3.5763120464471216`*^9, 3.576312122134451*^9, 
   3.576350002828125*^9, 3.57635149103125*^9, 3.576351590484375*^9, 
   3.57635175778125*^9, 3.576355441671875*^9, 3.576355743296875*^9, {
   3.57635729265625*^9, 3.57635731765625*^9}, 3.57635735828125*^9, 
   3.576357484890625*^9, 3.576357567546875*^9, 3.5763577063125*^9, 
   3.5763647911007233`*^9, 3.5763648633273706`*^9, 3.576364925010528*^9, 
   3.576365014566723*^9, {3.5763705638909326`*^9, 3.5763705927333903`*^9}, 
   3.5763708036614404`*^9, 3.5763752698468914`*^9, 3.5763754028025465`*^9, 
   3.57638014909766*^9, 3.576380208985985*^9, 3.5763802855142965`*^9, 
   3.5763803346999073`*^9, 3.5763803870416474`*^9, 3.5763804692728643`*^9, {
   3.5763805294111805`*^9, 3.576380556425768*^9}, {3.5764597383442497`*^9, 
   3.5764597598911247`*^9}, 3.5764601446879997`*^9, 3.5764604470317497`*^9, 
   3.5764605362661247`*^9, 3.5764605921254997`*^9, 3.5764607038129997`*^9, 
   3.5764607740629997`*^9, 3.5764608340317497`*^9, 3.5764609211879997`*^9, 
   3.5764610757817497`*^9, {3.5764611272661247`*^9, 3.5764611542192497`*^9}, 
   3.57670640575*^9, {3.5767066549375*^9, 3.576706677875*^9}, 
   3.5767067550625*^9, {3.576706801703125*^9, 3.576706825515625*^9}, 
   3.576785654765625*^9, 3.5767862023125*^9, 3.57678708615625*^9, 
   3.576787161578125*^9, 3.576788345140625*^9, {3.576789280671875*^9, 
   3.57678930784375*^9}, 3.5767894865*^9, 3.576789562921875*^9, 
   3.576789625765625*^9, 3.576790691984375*^9, 3.576790934390625*^9, 
   3.5767911079375*^9, 3.576791687359375*^9, 3.57689590596875*^9, 
   3.576895952203125*^9, 3.576896085828125*^9, 3.576896136625*^9, 
   3.576896377484375*^9, 3.5768967351875*^9, {3.5768970149375*^9, 
   3.576897051328125*^9}, 3.576897191375*^9, 3.576897241046875*^9, 
   3.57689989678125*^9, 3.576960963375*^9, 3.576961066359375*^9, 
   3.57696113815625*^9}]
}, Open  ]],

Cell["\<\
Find the correct indices of the correct border and corner effects: Step 3 in \
Algorithm 1 in [1]\
\>", "Text",
 CellChangeTimes->{{3.57602674096875*^9, 3.576026764859375*^9}, {
  3.576027270546875*^9, 3.576027271953125*^9}, {3.5763544223125*^9, 
  3.57635443290625*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"temp3", "=", 
   RowBox[{"Chop", "[", 
    RowBox[{
     RowBox[{"N", "[", 
      RowBox[{"Differences", "[", "Sorteddistances", "]"}], "]"}], ",", 
     "tol"}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{"indices", "=", 
  RowBox[{"Flatten", "[", 
   RowBox[{"Drop", "[", 
    RowBox[{
     RowBox[{"Map", "[", 
      RowBox[{"First", ",", 
       RowBox[{"ArrayRules", "[", "temp3", "]"}]}], "]"}], ",", 
     RowBox[{"-", "1"}]}], "]"}], "]"}]}]}], "Input",
 CellChangeTimes->{{3.5760267885625*^9, 3.576026861984375*^9}, {
   3.576027340484375*^9, 3.576027342765625*^9}, 3.576203975265625*^9, 
   3.5762754417756853`*^9, {3.5762772895226383`*^9, 3.576277290288209*^9}, {
   3.576277853653208*^9, 3.576277892072132*^9}, {3.5762787371975307`*^9, 
   3.5762787374631352`*^9}, {3.5762941701658583`*^9, 3.576294196429634*^9}, {
   3.576375373771427*^9, 3.576375376896507*^9}, {3.576375444317374*^9, 
   3.576375475738646*^9}, {3.5764601995004997`*^9, 3.5764602030317497`*^9}, 
   3.5764604392036247`*^9, {3.576899870921875*^9, 3.576899888453125*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"1", ",", "5", ",", "6"}], "}"}]], "Output",
 CellChangeTimes->{
  3.576026791*^9, 3.576026845078125*^9, 3.576027344703125*^9, 
   3.57602749321875*^9, 3.576027653515625*^9, 3.576028672953125*^9, {
   3.576029684984375*^9, 3.576029697109375*^9}, 3.57602974178125*^9, 
   3.57603031965625*^9, 3.57603052421875*^9, 3.57603195125*^9, {
   3.5760320319375*^9, 3.576032058390625*^9}, 3.57603215*^9, 
   3.576032200828125*^9, 3.576032239046875*^9, 3.576032282359375*^9, 
   3.576092705546875*^9, {3.576092769359375*^9, 3.5760927955625*^9}, 
   3.576135975453125*^9, 3.576136208609375*^9, 3.576136365703125*^9, 
   3.57613640509375*^9, 3.576136451546875*^9, 3.576136511421875*^9, 
   3.57613656825*^9, 3.57613668765625*^9, {3.57613672746875*^9, 
   3.576136757453125*^9}, 3.576136801203125*^9, {3.57613683290625*^9, 
   3.5761368555625*^9}, 3.5761369309375*^9, {3.5761370089375*^9, 
   3.576137062265625*^9}, 3.576137095625*^9, {3.576137231*^9, 
   3.57613725646875*^9}, 3.576137491953125*^9, {3.57613778575*^9, 
   3.576137843078125*^9}, 3.576137887265625*^9, 3.576137933484375*^9, 
   3.576137985546875*^9, 3.576138373265625*^9, 3.576138886046875*^9, 
   3.576138929359375*^9, {3.57613897309375*^9, 3.57613901878125*^9}, 
   3.576139077375*^9, 3.576139110296875*^9, 3.576139338703125*^9, {
   3.576139385234375*^9, 3.57613939384375*^9}, {3.576139425*^9, 
   3.57613944084375*^9}, {3.576139520140625*^9, 3.57613957103125*^9}, 
   3.576139602265625*^9, 3.576139746125*^9, {3.576177302546875*^9, 
   3.57617732721875*^9}, 3.576177425171875*^9, 3.576177462484375*^9, {
   3.576177562578125*^9, 3.576177596640625*^9}, {3.576177636828125*^9, 
   3.57617766896875*^9}, 3.576186313125*^9, 3.57618641634375*^9, 
   3.576186573140625*^9, 3.5761866064375*^9, 3.576186692609375*^9, 
   3.57618714196875*^9, {3.576187416640625*^9, 3.57618742878125*^9}, 
   3.57618778890625*^9, 3.576187881484375*^9, 3.576188228703125*^9, 
   3.57618923334375*^9, {3.576189331015625*^9, 3.57618935346875*^9}, 
   3.57619000640625*^9, 3.576190153125*^9, 3.576190381859375*^9, {
   3.5761907786875*^9, 3.57619080815625*^9}, 3.576190838671875*^9, {
   3.576190946890625*^9, 3.576190963953125*^9}, 3.5762027091038275`*^9, 
   3.576202745476267*^9, 3.5762028894661293`*^9, {3.57620294214992*^9, 
   3.576202970382307*^9}, 3.5762030661880617`*^9, {3.5762038965*^9, 
   3.57620397659375*^9}, {3.5762040079375*^9, 3.576204069328125*^9}, {
   3.5762040994375*^9, 3.57620413096875*^9}, 3.576204174328125*^9, 
   3.576204232484375*^9, 3.57620797290625*^9, 3.576210862859375*^9, {
   3.576210989921875*^9, 3.5762110021875*^9}, {3.576211192796875*^9, 
   3.5762112070625*^9}, 3.57621134325*^9, {3.576211507265625*^9, 
   3.576211515203125*^9}, 3.576211694890625*^9, 3.57621173825*^9, 
   3.57621218290625*^9, 3.576212226875*^9, 3.576212352515625*^9, 
   3.57621240840625*^9, {3.5762124481875*^9, 3.5762125106875*^9}, {
   3.576212556859375*^9, 3.576212576453125*^9}, {3.576212698046875*^9, 
   3.576212733875*^9}, 3.576213102671875*^9, 3.576213303703125*^9, 
   3.5762135180625*^9, 3.576213553*^9, {3.576213617984375*^9, 
   3.57621363096875*^9}, {3.57621367346875*^9, 3.576213703375*^9}, 
   3.57621380625*^9, 3.576213894046875*^9, 3.57621395328125*^9, 
   3.576214008671875*^9, {3.57621410109375*^9, 3.576214125171875*^9}, 
   3.5762209211875*^9, 3.576221004640625*^9, 3.57622103734375*^9, 
   3.57622111778125*^9, 3.57622141384375*^9, 3.576221604375*^9, 
   3.576225071703125*^9, 3.57622511590625*^9, 3.57622515565625*^9, 
   3.576225200640625*^9, 3.576225251625*^9, 3.57622539628125*^9, 
   3.576225495484375*^9, 3.576225545890625*^9, 3.576225585453125*^9, 
   3.576225654046875*^9, 3.576225705984375*^9, 3.5762257368125*^9, 
   3.576225881140625*^9, 3.576226456453125*^9, {3.576262871765625*^9, 
   3.5762629435625*^9}, 3.576262974328125*^9, 3.57626300815625*^9, 
   3.576275443947338*^9, 3.5762772942410555`*^9, 3.576277827233362*^9, {
   3.576277869027027*^9, 3.5762778927127075`*^9}, 3.576278124648019*^9, {
   3.576278179940647*^9, 3.5762782057042937`*^9}, 3.576278251888542*^9, 
   3.5762783253989916`*^9, 3.576278450140209*^9, 3.5762784879031754`*^9, 
   3.5762785465084243`*^9, 3.576278616753479*^9, 3.576278668952772*^9, 
   3.5762944813470745`*^9, 3.5762945776371703`*^9, 3.576294632055214*^9, 
   3.576294754249736*^9, 3.5762948960835*^9, {3.5762949410647087`*^9, 
   3.5762951903284087`*^9}, {3.5762952241541524`*^9, 3.576295267322988*^9}, {
   3.5762953623631716`*^9, 3.5762953842991276`*^9}, 3.576295417624906*^9, {
   3.5762954579814396`*^9, 3.5762955240705366`*^9}, 3.576306720814004*^9, 
   3.576310674816669*^9, 3.5763114377363057`*^9, 3.576311470100157*^9, 
   3.5763116109792147`*^9, 3.576311706594683*^9, 3.5763118649947433`*^9, 
   3.5763119204329143`*^9, 3.5763119771711597`*^9, 3.5763120465991306`*^9, 
   3.5763121221974545`*^9, 3.576350002875*^9, 3.5763514910625*^9, 
   3.576351590515625*^9, 3.5763517578125*^9, 3.576355441734375*^9, 
   3.5763557433125*^9, {3.576357292671875*^9, 3.5763573176875*^9}, 
   3.576357358296875*^9, 3.57635748490625*^9, 3.5763575675625*^9, 
   3.576357706328125*^9, 3.57636479400662*^9, 3.5763648633586187`*^9, 
   3.5763649250261517`*^9, 3.576365014582347*^9, {3.576370563906557*^9, 
   3.576370592749015*^9}, 3.5763708036614404`*^9, 3.576375269862517*^9, {
   3.57637537800591*^9, 3.576375402818171*^9}, 3.5763754521609735`*^9, 
   3.576380149113284*^9, 3.5763802090016093`*^9, 3.5763802855299206`*^9, 
   3.576380334715532*^9, 3.5763803870416474`*^9, 3.5763804692884893`*^9, {
   3.5763805294268045`*^9, 3.576380556441392*^9}, {3.5764597383754997`*^9, 
   3.5764597599223747`*^9}, 3.5764601447192497`*^9, 3.5764602104067497`*^9, 
   3.5764604470473747`*^9, 3.5764605362817497`*^9, 3.5764605921567497`*^9, 
   3.5764607038286247`*^9, 3.5764607740942497`*^9, 3.5764608340786247`*^9, 
   3.5764609212036247`*^9, 3.5764610758286247`*^9, {3.5764611272973747`*^9, 
   3.5764611545786247`*^9}, 3.57670640578125*^9, {3.57670665496875*^9, 
   3.5767066779375*^9}, 3.576706755078125*^9, {3.57670680171875*^9, 
   3.57670682553125*^9}, 3.5767856548125*^9, 3.57678620234375*^9, 
   3.576787086296875*^9, 3.576787161609375*^9, 3.576788345203125*^9, {
   3.576789280734375*^9, 3.576789307890625*^9}, 3.5767894865625*^9, 
   3.576789562953125*^9, 3.5767896258125*^9, 3.57679069203125*^9, 
   3.5767909344375*^9, 3.576791107984375*^9, 3.576791687390625*^9, 
   3.576895906015625*^9, 3.57689595221875*^9, 3.576896085859375*^9, 
   3.57689613665625*^9, 3.5768963775*^9, 3.576896735203125*^9, {
   3.576897014984375*^9, 3.576897051359375*^9}, 3.576897191390625*^9, 
   3.576897241078125*^9, 3.576899896828125*^9, 3.57696096340625*^9, 
   3.576961066375*^9, 3.57696113815625*^9}]
}, Open  ]],

Cell["\<\
Find the terms in the expression for the PDF f_R(r)\
\>", "Text",
 CellChangeTimes->{{3.5760273629375*^9, 3.576027374984375*^9}, {
  3.57602741184375*^9, 3.57602742109375*^9}, {3.576138864859375*^9, 
  3.5761388749375*^9}, {3.57613948703125*^9, 3.57613949065625*^9}, {
  3.576203962109375*^9, 3.576203962828125*^9}, {3.57620786921875*^9, 
  3.57620788334375*^9}, {3.57621177675*^9, 3.576211779625*^9}, {
  3.576355264734375*^9, 3.57635528525*^9}, {3.5764602362973747`*^9, 
  3.5764602462192497`*^9}}],

Cell[BoxData[{
 RowBox[{
  RowBox[{"boundaryeffectsordered", "=", 
   RowBox[{"boundaryeffects", "[", 
    RowBox[{"[", "k", "]"}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"temp4", "=", 
   RowBox[{"FullSimplify", "[", 
    RowBox[{"Accumulate", "[", "boundaryeffectsordered", "]"}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"answer", "=", 
   RowBox[{"Apart", "[", 
    RowBox[{"FullSimplify", "[", 
     RowBox[{
      RowBox[{"2", " ", "\[Pi]", " ", "r"}], "-", 
      RowBox[{"temp4", "[", 
       RowBox[{"[", "indices", "]"}], "]"}]}], "]"}], "]"}]}], 
  ";"}]}], "Input",
 CellChangeTimes->{{3.575935636265625*^9, 3.575935652890625*^9}, {
   3.575935699484375*^9, 3.57593602053125*^9}, 3.575936055078125*^9, {
   3.575936140921875*^9, 3.57593619059375*^9}, {3.57594983046875*^9, 
   3.575949844109375*^9}, {3.575949885109375*^9, 3.575949891015625*^9}, {
   3.57594993921875*^9, 3.57595006953125*^9}, {3.5759507055*^9, 
   3.575950737015625*^9}, {3.57595087296875*^9, 3.575950948984375*^9}, {
   3.57595098884375*^9, 3.57595100315625*^9}, {3.575951166578125*^9, 
   3.57595117425*^9}, {3.57595137096875*^9, 3.575951409234375*^9}, {
   3.575951441421875*^9, 3.575951442234375*^9}, {3.57595147475*^9, 
   3.575951709625*^9}, {3.575951988796875*^9, 3.575952006765625*^9}, {
   3.575957375203125*^9, 3.57595743821875*^9}, {3.575960750375*^9, 
   3.575960751015625*^9}, {3.575960953265625*^9, 3.57596096940625*^9}, {
   3.57596134453125*^9, 3.575961387890625*^9}, {3.575961425765625*^9, 
   3.5759614305625*^9}, {3.575961518203125*^9, 3.575961584359375*^9}, {
   3.57596180196875*^9, 3.575961916203125*^9}, {3.575963224875*^9, 
   3.575963249125*^9}, {3.575963322859375*^9, 3.57596335603125*^9}, {
   3.575963422*^9, 3.575963433296875*^9}, {3.575963626875*^9, 
   3.575963642296875*^9}, {3.57596372253125*^9, 3.575963766015625*^9}, {
   3.575964449125*^9, 3.57596445265625*^9}, 3.57596457996875*^9, {
   3.575964997109375*^9, 3.57596500840625*^9}, {3.575965200375*^9, 
   3.575965207765625*^9}, 3.575965416984375*^9, {3.57596550065625*^9, 
   3.575965503203125*^9}, {3.57596811290625*^9, 3.57596815528125*^9}, {
   3.57596818690625*^9, 3.5759681905625*^9}, {3.575968403234375*^9, 
   3.575968404015625*^9}, {3.57596844340625*^9, 3.57596844565625*^9}, {
   3.575968478109375*^9, 3.575968522671875*^9}, {3.575968557140625*^9, 
   3.575968588734375*^9}, {3.57596880740625*^9, 3.5759688779375*^9}, {
   3.57596891325*^9, 3.57596900096875*^9}, {3.575969074390625*^9, 
   3.57596913146875*^9}, {3.57600714721875*^9, 3.576007193671875*^9}, {
   3.5760082248125*^9, 3.576008236921875*^9}, {3.5760086768125*^9, 
   3.576008677640625*^9}, {3.576008767625*^9, 3.576008771640625*^9}, {
   3.576008808921875*^9, 3.576008809359375*^9}, {3.576009224640625*^9, 
   3.576009265*^9}, {3.57600929740625*^9, 3.576009320578125*^9}, {
   3.576009420234375*^9, 3.57600946315625*^9}, {3.5760096704375*^9, 
   3.576009697375*^9}, {3.57600974084375*^9, 3.5760097433125*^9}, {
   3.5760098346875*^9, 3.57600986209375*^9}, {3.576009906796875*^9, 
   3.57600990753125*^9}, {3.576012705765625*^9, 3.576012819265625*^9}, {
   3.57601285790625*^9, 3.57601285825*^9}, {3.576012967171875*^9, 
   3.576012967609375*^9}, {3.576013073609375*^9, 3.576013180328125*^9}, {
   3.576013535265625*^9, 3.57601353765625*^9}, 3.576013785140625*^9, {
   3.576013866328125*^9, 3.576013884515625*^9}, {3.576014046578125*^9, 
   3.5760141490625*^9}, {3.5760143848125*^9, 3.576014422609375*^9}, {
   3.576014507828125*^9, 3.576014509015625*^9}, {3.57601478853125*^9, 
   3.5760147985625*^9}, {3.576014960515625*^9, 3.576014977375*^9}, {
   3.576015165859375*^9, 3.576015202546875*^9}, {3.57601580159375*^9, 
   3.576015900109375*^9}, {3.576015969140625*^9, 3.576015976921875*^9}, 
   3.57601602890625*^9, {3.57601607984375*^9, 3.576016088140625*^9}, {
   3.576016134328125*^9, 3.5760161355625*^9}, {3.576016393421875*^9, 
   3.57601639996875*^9}, {3.576016725953125*^9, 3.57601675065625*^9}, 
   3.576016800640625*^9, {3.5760191884375*^9, 3.576019195953125*^9}, {
   3.576019243484375*^9, 3.576019244328125*^9}, {3.5760193135*^9, 
   3.576019327546875*^9}, {3.576019863359375*^9, 3.576019865140625*^9}, {
   3.57601990409375*^9, 3.57601990796875*^9}, {3.576019973015625*^9, 
   3.57601997503125*^9}, {3.576020191703125*^9, 3.57602027771875*^9}, {
   3.576020365328125*^9, 3.576020383046875*^9}, {3.576020436203125*^9, 
   3.576020442*^9}, {3.576020479234375*^9, 3.576020540703125*^9}, {
   3.576020592109375*^9, 3.576020608734375*^9}, {3.57602070040625*^9, 
   3.576020713765625*^9}, {3.57602078059375*^9, 3.57602087871875*^9}, {
   3.576020965*^9, 3.576021052796875*^9}, {3.576021090015625*^9, 
   3.57602115009375*^9}, {3.57602126928125*^9, 3.57602128090625*^9}, 
   3.5760213155625*^9, {3.57602141646875*^9, 3.57602142640625*^9}, {
   3.57602147215625*^9, 3.57602153728125*^9}, {3.576021736109375*^9, 
   3.576021751125*^9}, 3.576027017078125*^9, 3.5760273554375*^9, {
   3.576027431828125*^9, 3.57602746934375*^9}, 3.576027513015625*^9, {
   3.57603199371875*^9, 3.5760320125*^9}, {3.57603217225*^9, 
   3.576032192109375*^9}, {3.576032265296875*^9, 3.576032266140625*^9}, 
   3.5761384144375*^9, {3.57613858140625*^9, 3.576138592671875*^9}, 
   3.5761396773125*^9, {3.5761398254375*^9, 3.57613983828125*^9}, 
   3.576177553*^9, {3.5762039815625*^9, 3.576203983953125*^9}, {
   3.576351679046875*^9, 3.576351704484375*^9}, {3.576357578578125*^9, 
   3.57635760596875*^9}, {3.576357794515625*^9, 3.57635779525*^9}, 
   3.5763579245625*^9, {3.5764610287348747`*^9, 3.5764610365161247`*^9}}],

Cell["\<\
Find the terms in the expression for the CDF F_R(r)\
\>", "Text",
 CellChangeTimes->{{3.5763065521777077`*^9, 3.5763065580277176`*^9}, {
  3.576355269234375*^9, 3.57635527975*^9}, {3.5764602417504997`*^9, 
  3.5764602501723747`*^9}}],

Cell[BoxData[{
 RowBox[{
  RowBox[{"boundaryeffectsorderedCDF", "=", 
   RowBox[{"boundaryeffectsCDF", "[", 
    RowBox[{"[", "k", "]"}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"temp4CDF", "=", 
   RowBox[{"FullSimplify", "[", 
    RowBox[{"Accumulate", "[", "boundaryeffectsorderedCDF", "]"}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"answerCDF", "=", 
   RowBox[{"Apart", "[", 
    RowBox[{"FullSimplify", "[", 
     RowBox[{
      RowBox[{"\[Pi]", " ", 
       SuperscriptBox["r", "2"]}], "-", 
      RowBox[{"temp4CDF", "[", 
       RowBox[{"[", "indices", "]"}], "]"}]}], "]"}], "]"}]}], 
  ";"}]}], "Input",
 CellChangeTimes->{{3.5763064918836017`*^9, 3.57630654233409*^9}, {
   3.5763516855*^9, 3.576351693265625*^9}, {3.57635778765625*^9, 
   3.576357788640625*^9}, 3.5764610175786247`*^9}],

Cell["\<\
Find the unique ranges and account for the effects of finite precision\
\>", "Text",
 CellChangeTimes->{{3.57602747228125*^9, 3.576027482875*^9}, {
  3.57613804234375*^9, 3.57613807309375*^9}, {3.57635071134375*^9, 
  3.576350715109375*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"Uniquedistances", "=", 
   RowBox[{"Join", "[", 
    RowBox[{
     RowBox[{"Sorteddistances", " ", "[", 
      RowBox[{"[", "indices", "]"}], "]"}], ",", 
     RowBox[{"{", 
      RowBox[{"Sorteddistances", "[", 
       RowBox[{"[", 
        RowBox[{"Length", "[", "Sorteddistances", "]"}], "]"}], "]"}], 
      "}"}]}], "]"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.57613652428125*^9, 3.576136532078125*^9}, {
   3.57613804534375*^9, 3.576138071203125*^9}, 3.5762777364122124`*^9, 
   3.5764610201254997`*^9}],

Cell["\<\
Account for the case that there may be a range with no border effects\
\>", "Text",
 CellChangeTimes->{{3.576177375390625*^9, 3.57617739090625*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{"Uniquedistancesnew", "=", 
  RowBox[{"If", "[", 
   RowBox[{
    RowBox[{
     RowBox[{"Uniquedistances", "[", 
      RowBox[{"[", "1", "]"}], "]"}], "\[NotEqual]", "0"}], ",", 
    RowBox[{"Prepend", "[", 
     RowBox[{"Uniquedistances", ",", "0"}], "]"}], ",", "Uniquedistances"}], 
   "]"}]}], "\[IndentingNewLine]", 
 RowBox[{"answernew", "=", 
  RowBox[{"If", "[", 
   RowBox[{
    RowBox[{
     RowBox[{"Uniquedistances", "[", 
      RowBox[{"[", "1", "]"}], "]"}], "\[NotEqual]", "0"}], ",", 
    RowBox[{"Prepend", "[", 
     RowBox[{"answer", ",", 
      RowBox[{"2", "  ", "\[Pi]", " ", "r"}]}], "]"}], ",", "answer"}], 
   "]"}]}], "\[IndentingNewLine]", 
 RowBox[{"answernewCDF", "=", 
  RowBox[{"If", "[", 
   RowBox[{
    RowBox[{
     RowBox[{"Uniquedistances", "[", 
      RowBox[{"[", "1", "]"}], "]"}], "\[NotEqual]", "0"}], ",", 
    RowBox[{"Prepend", "[", 
     RowBox[{"answerCDF", ",", 
      RowBox[{"\[Pi]", " ", 
       SuperscriptBox["r", "2"]}]}], "]"}], ",", "answerCDF"}], 
   "]"}]}]}], "Input",
 CellChangeTimes->{{3.576177130515625*^9, 3.576177281703125*^9}, {
  3.5763065930965796`*^9, 3.576306619788226*^9}, {3.5764610625317497`*^9, 
  3.5764610663754997`*^9}, {3.57679090640625*^9, 3.576790910546875*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"0", ",", 
   FractionBox["1", 
    SqrtBox["2"]], ",", 
   SqrtBox["2"], ",", 
   SqrtBox[
    FractionBox["5", "2"]]}], "}"}]], "Output",
 CellChangeTimes->{{3.5767909113125*^9, 3.57679093859375*^9}, 
   3.57679110840625*^9, 3.576791689109375*^9, 3.576895911203125*^9, 
   3.576895952515625*^9, 3.576896091109375*^9, 3.576896137*^9, 
   3.57689637784375*^9, 3.576896736375*^9, 3.576897016125*^9, 
   3.57689705228125*^9, 3.5768971919375*^9, 3.57689724140625*^9, 
   3.576899897296875*^9, 3.57696096628125*^9, 3.576961071890625*^9, 
   3.576961140609375*^9}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"\[Pi]", " ", "r"}], ",", 
   RowBox[{"2", " ", "r", " ", 
    RowBox[{"ArcCsc", "[", 
     RowBox[{
      SqrtBox["2"], " ", "r"}], "]"}]}], ",", 
   RowBox[{
    RowBox[{"2", " ", "r", " ", 
     RowBox[{"ArcCsc", "[", 
      RowBox[{
       SqrtBox["2"], " ", "r"}], "]"}]}], "-", 
    RowBox[{"2", " ", "r", " ", 
     RowBox[{"ArcSec", "[", 
      FractionBox["r", 
       SqrtBox["2"]], "]"}]}]}]}], "}"}]], "Output",
 CellChangeTimes->{{3.5767909113125*^9, 3.57679093859375*^9}, 
   3.57679110840625*^9, 3.576791689109375*^9, 3.576895911203125*^9, 
   3.576895952515625*^9, 3.576896091109375*^9, 3.576896137*^9, 
   3.57689637784375*^9, 3.576896736375*^9, 3.576897016125*^9, 
   3.57689705228125*^9, 3.5768971919375*^9, 3.57689724140625*^9, 
   3.576899897296875*^9, 3.57696096628125*^9, 3.576961071890625*^9, 
   3.576961140609375*^9}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   FractionBox[
    RowBox[{"\[Pi]", " ", 
     SuperscriptBox["r", "2"]}], "2"], ",", 
   RowBox[{
    RowBox[{
     FractionBox["1", "2"], " ", 
     SqrtBox[
      RowBox[{
       RowBox[{"-", "1"}], "+", 
       RowBox[{"2", " ", 
        SuperscriptBox["r", "2"]}]}]]}], "+", 
    RowBox[{
     SuperscriptBox["r", "2"], " ", 
     RowBox[{"ArcCsc", "[", 
      RowBox[{
       SqrtBox["2"], " ", "r"}], "]"}]}]}], ",", 
   RowBox[{
    RowBox[{
     SqrtBox["2"], " ", 
     SqrtBox[
      RowBox[{
       RowBox[{"-", "2"}], "+", 
       SuperscriptBox["r", "2"]}]]}], "+", 
    RowBox[{
     FractionBox["1", "2"], " ", 
     SqrtBox[
      RowBox[{
       RowBox[{"-", "1"}], "+", 
       RowBox[{"2", " ", 
        SuperscriptBox["r", "2"]}]}]]}], "+", 
    RowBox[{
     SuperscriptBox["r", "2"], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"ArcCsc", "[", 
        RowBox[{
         SqrtBox["2"], " ", "r"}], "]"}], "-", 
       RowBox[{"ArcSec", "[", 
        FractionBox["r", 
         SqrtBox["2"]], "]"}]}], ")"}]}]}]}], "}"}]], "Output",
 CellChangeTimes->{{3.5767909113125*^9, 3.57679093859375*^9}, 
   3.57679110840625*^9, 3.576791689109375*^9, 3.576895911203125*^9, 
   3.576895952515625*^9, 3.576896091109375*^9, 3.576896137*^9, 
   3.57689637784375*^9, 3.576896736375*^9, 3.576897016125*^9, 
   3.57689705228125*^9, 3.5768971919375*^9, 3.57689724140625*^9, 
   3.576899897296875*^9, 3.57696096628125*^9, 3.576961071890625*^9, 
   3.576961140609375*^9}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
6. Display the PDF f_R(r) and the CDF F_R(r)\
\>", "Section",
 CellChangeTimes->{{3.576027529953125*^9, 3.57602754075*^9}, {3.576213463*^9, 
  3.576213472*^9}, {3.57635014334375*^9, 3.576350153046875*^9}, {
  3.576350740421875*^9, 3.576350741453125*^9}, {3.57635146496875*^9, 
  3.576351465765625*^9}}],

Cell["Show and plot the PDF f_R(r)", "Text",
 CellChangeTimes->{{3.57621275771875*^9, 3.57621277521875*^9}, {
  3.576350750484375*^9, 3.576350751953125*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"fRr", "=", 
  RowBox[{
   FractionBox["1", "area"], 
   RowBox[{"Piecewise", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"{", 
       RowBox[{"#1", ",", 
        RowBox[{
         RowBox[{"#2", "[", 
          RowBox[{"[", "1", "]"}], "]"}], "\[LessEqual]", "r", "\[LessEqual]", 
         RowBox[{"#2", "[", 
          RowBox[{"[", "2", "]"}], "]"}]}]}], "}"}], "&"}], "@@@", 
     RowBox[{"Transpose", "@", 
      RowBox[{"{", 
       RowBox[{"answernew", ",", 
        RowBox[{"Partition", "[", 
         RowBox[{"Uniquedistancesnew", ",", "2", ",", "1"}], "]"}]}], 
       "}"}]}]}], "]"}]}]}]], "Input",
 CellChangeTimes->{{3.576135909515625*^9, 3.5761359691875*^9}, {
   3.576136139875*^9, 3.57613616365625*^9}, {3.57613620475*^9, 
   3.576136234171875*^9}, {3.5761371771875*^9, 3.57613719890625*^9}, {
   3.576177288640625*^9, 3.57617729134375*^9}, 3.57617741971875*^9, 
   3.5762108445*^9, {3.576211680703125*^9, 3.57621172821875*^9}, {
   3.576225331296875*^9, 3.57622534846875*^9}, {3.5763580180625*^9, 
   3.576358043296875*^9}}],

Cell[BoxData[
 RowBox[{
  FractionBox["1", "2"], " ", 
  RowBox[{"(", 
   TagBox[GridBox[{
      {"\[Piecewise]", GridBox[{
         {
          RowBox[{"\[Pi]", " ", "r"}], 
          RowBox[{"0", "\[LessEqual]", "r", "\[LessEqual]", 
           FractionBox["1", 
            SqrtBox["2"]]}]},
         {
          RowBox[{"2", " ", "r", " ", 
           RowBox[{"ArcCsc", "[", 
            RowBox[{
             SqrtBox["2"], " ", "r"}], "]"}]}], 
          RowBox[{
           FractionBox["1", 
            SqrtBox["2"]], "\[LessEqual]", "r", "\[LessEqual]", 
           SqrtBox["2"]}]},
         {
          RowBox[{
           RowBox[{"2", " ", "r", " ", 
            RowBox[{"ArcCsc", "[", 
             RowBox[{
              SqrtBox["2"], " ", "r"}], "]"}]}], "-", 
           RowBox[{"2", " ", "r", " ", 
            RowBox[{"ArcSec", "[", 
             FractionBox["r", 
              SqrtBox["2"]], "]"}]}]}], 
          RowBox[{
           SqrtBox["2"], "\[LessEqual]", "r", "\[LessEqual]", 
           SqrtBox[
            FractionBox["5", "2"]]}]},
         {"0", 
          TagBox["True",
           "PiecewiseDefault",
           AutoDelete->True]}
        },
        AllowedDimensions->{2, Automatic},
        Editable->True,
        GridBoxAlignment->{
         "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, 
          "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
        GridBoxItemSize->{
         "Columns" -> {{Automatic}}, "ColumnsIndexed" -> {}, "Rows" -> {{1.}},
           "RowsIndexed" -> {}},
        GridBoxSpacings->{"Columns" -> {
            Offset[0.27999999999999997`], {
             Offset[0.84]}, 
            Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
            Offset[0.2], {
             Offset[0.4]}, 
            Offset[0.2]}, "RowsIndexed" -> {}},
        Selectable->True]}
     },
     GridBoxAlignment->{
      "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
       "RowsIndexed" -> {}},
     GridBoxItemSize->{
      "Columns" -> {{Automatic}}, "ColumnsIndexed" -> {}, "Rows" -> {{1.}}, 
       "RowsIndexed" -> {}},
     GridBoxSpacings->{"Columns" -> {
         Offset[0.27999999999999997`], {
          Offset[0.35]}, 
         Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
         Offset[0.2], {
          Offset[0.4]}, 
         Offset[0.2]}, "RowsIndexed" -> {}}],
    "Piecewise",
    DeleteWithContents->True,
    Editable->False,
    SelectWithContents->True,
    Selectable->False], ")"}]}]], "Output",
 CellChangeTimes->{{3.57621173096875*^9, 3.5762117385625*^9}, 
   3.576212183328125*^9, 3.576212226984375*^9, {3.576212336765625*^9, 
   3.57621235265625*^9}, 3.57621240853125*^9, {3.5762124523125*^9, 
   3.576212510953125*^9}, {3.576212556984375*^9, 3.576212576671875*^9}, {
   3.5762126983125*^9, 3.576212734078125*^9}, 3.57621310296875*^9, 
   3.576213303953125*^9, 3.5762135181875*^9, 3.576213553125*^9, {
   3.576213618140625*^9, 3.576213631109375*^9}, {3.576213673578125*^9, 
   3.5762137035625*^9}, 3.5762138064375*^9, 3.57621389421875*^9, 
   3.576213953453125*^9, 3.5762140089375*^9, {3.576214101296875*^9, 
   3.57621412528125*^9}, 3.576220921390625*^9, 3.576221004796875*^9, 
   3.57622103746875*^9, 3.576221117921875*^9, 3.576221414046875*^9, 
   3.576221604671875*^9, 3.576225072*^9, 3.57622511615625*^9, {
   3.576225155859375*^9, 3.5762251726875*^9}, 3.576225251890625*^9, {
   3.576225336671875*^9, 3.576225350546875*^9}, 3.576225396421875*^9, 
   3.57622549565625*^9, 3.5762255460625*^9, 3.57622558575*^9, 
   3.576225654234375*^9, 3.576225706109375*^9, 3.5762257370625*^9, 
   3.576225881875*^9, 3.576226456640625*^9, {3.57626287328125*^9, 
   3.5762629436875*^9}, 3.5762629745*^9, 3.576263008359375*^9, 
   3.576277751754784*^9, 3.5762779795497885`*^9, 3.57627813328798*^9, {
   3.576278187111971*^9, 3.576278205813661*^9}, 3.5762782584193325`*^9, 
   3.5762783314454412`*^9, 3.576278457092845*^9, 3.576278561398001*^9, 
   3.5762786302994003`*^9, 3.576294489612118*^9, 3.576294586480298*^9, 
   3.5762946500070753`*^9, 3.576294754359103*^9, 3.5762948961928673`*^9, {
   3.5762949411740756`*^9, 3.5762951904065285`*^9}, {3.5762952242635193`*^9, 
   3.5762952674323554`*^9}, {3.576295362472539*^9, 3.5762953844241185`*^9}, 
   3.576295417765521*^9, {3.576295458106431*^9, 3.576295524179904*^9}, 
   3.5763067428100424`*^9, 3.5763106887004633`*^9, {3.5763114458497696`*^9, 
   3.576311471233221*^9}, 3.576311612148281*^9, 3.576311707501735*^9, 
   3.576311865616779*^9, 3.5763119211539555`*^9, 3.5763119778491983`*^9, 
   3.5763120471021595`*^9, 3.576312123544532*^9, 3.576350004*^9, 
   3.57635149134375*^9, 3.576351590890625*^9, 3.57635175975*^9, 
   3.57635544328125*^9, 3.576355744703125*^9, {3.576357293046875*^9, 
   3.576357317890625*^9}, 3.576357359734375*^9, 3.57635748525*^9, 
   3.5763575679375*^9, 3.57635770671875*^9, 3.576358026796875*^9, 
   3.5763648049896593`*^9, 3.5763648638742075`*^9, 3.576364925354254*^9, 
   3.576365015332294*^9, {3.5763705643596616`*^9, 3.576370593077125*^9}, 
   3.576370804645771*^9, 3.5763752703625298`*^9, 3.5763754033181615`*^9, 
   3.576380149582016*^9, 3.576380209423468*^9, 3.5763802859205303`*^9, 
   3.5763803349655223`*^9, 3.5763803872760134`*^9, 3.5763804694291086`*^9, {
   3.5763805295518*^9, 3.5763805569101243`*^9}, {3.5764597392504997`*^9, 
   3.5764597603911247`*^9}, 3.5764601452817497`*^9, 3.5764604475942497`*^9, 
   3.5764605372817497`*^9, 3.5764605953129997`*^9, 3.5764607749692497`*^9, 
   3.5764608344067497`*^9, 3.5764609281723747`*^9, 3.5764610815161247`*^9, {
   3.5764611303286247`*^9, 3.5764611566567497`*^9}, 3.57670640853125*^9, 
   3.576706656859375*^9, {3.57670680328125*^9, 3.576706827515625*^9}, 
   3.57678566209375*^9, 3.576786202859375*^9, 3.576787163453125*^9, 
   3.576788347453125*^9, {3.57678928265625*^9, 3.576789312140625*^9}, 
   3.5767894926875*^9, 3.576789568046875*^9, 3.576789630390625*^9, 
   3.576790694109375*^9, 3.576790938703125*^9, 3.576791108453125*^9, 
   3.576791690328125*^9, 3.57689591125*^9, 3.576895952546875*^9, 
   3.576896091140625*^9, 3.576896137015625*^9, 3.576896377875*^9, 
   3.57689673640625*^9, 3.5768970161875*^9, 3.576897052296875*^9, 
   3.57689719196875*^9, 3.5768972414375*^9, 3.576899897328125*^9, 
   3.57696096634375*^9, 3.576961072375*^9, 3.576961140625*^9}]
}, Open  ]],

Cell["Define range and plot", "Text",
 CellChangeTimes->{{3.576354490875*^9, 3.576354496984375*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"maxrange", "=", 
   RowBox[{"Max", "[", 
    RowBox[{"Uniquedistances", "+", "0.25"}], "]"}]}], ";", 
  RowBox[{"Plot", "[", 
   RowBox[{"fRr", ",", 
    RowBox[{"{", 
     RowBox[{"r", ",", "0", ",", "maxrange"}], "}"}], ",", 
    RowBox[{"Filling", "\[Rule]", "Bottom"}], ",", 
    RowBox[{"Frame", "\[Rule]", "True"}], ",", 
    RowBox[{"FrameLabel", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"Distance", " ", "r"}], ",", "PDF"}], "}"}]}]}], 
   "]"}]}]], "Input",
 CellChangeTimes->{{3.576136257546875*^9, 3.576136297328125*^9}, 
   3.576138766265625*^9, {3.57613951075*^9, 3.5761395110625*^9}, {
   3.576204053078125*^9, 3.57620405440625*^9}, {3.576207943703125*^9, 
   3.576207970546875*^9}, {3.576208023515625*^9, 3.57620802525*^9}, {
   3.576208094109375*^9, 3.57620809440625*^9}, {3.57620914078125*^9, 
   3.57620917984375*^9}, {3.57621055784375*^9, 3.576210559515625*^9}, 
   3.57621091121875*^9, {3.57621378209375*^9, 3.57621378321875*^9}, {
   3.576213842890625*^9, 3.5762138471875*^9}, {3.576214002390625*^9, 
   3.57621403403125*^9}, {3.576220929453125*^9, 3.576220929828125*^9}, {
   3.576221152*^9, 3.57622115275*^9}, {3.57622120946875*^9, 
   3.576221243171875*^9}, {3.57622130134375*^9, 3.57622137415625*^9}, {
   3.576350136265625*^9, 3.57635013734375*^9}, {3.576350785421875*^9, 
   3.576350787609375*^9}}],

Cell[BoxData[
 GraphicsBox[GraphicsComplexBox[CompressedData["
1:eJxlWHk0VXv7R3WbFIkSpaTJrMFNUh8VUhmiMoTELVyalEppkKEkYykpUySF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   "], {{{}, 
     {Hue[0.67, 0.6, 0.6], Opacity[0.2], EdgeForm[None], 
      GraphicsGroupBox[{PolygonBox[CompressedData["
1:eJwt0jssnWEcwOFzaF2q7gkbYXANBqSRkLhEsCF1SZiQYGFBm7CRGBoD9hYJ
G4kBCwaCHW1SW5sYsGAwiMHzhuH5fu/7/3LOl/c7J29gvHMsJhKJBE1EaXfp
oJYj+wZ90kpd0BdqrPf0jiLrfj3kkQr7Gd3gimz7ap1nm2vyzdp0lGXO+GCW
qX1Ms85fssyrtJURljgl1jxD00kjlRSS+UwSn0gkgXji+BieFT7/fu5KWhhm
kZMw992NfKWLXbN6vdVC7dUDHii3/65r/CHTvlSHmGOL/+RG395xD99Y5TcZ
5iXaSDdTrHAZzuZecfgN6GKSX1yEM7tXpIPMssk/cszr9Qc73FAQzqL73FNm
P6HPfLH+qefhHVoXanP07c9Qx7HlK1OVNx8=
         "]], PolygonBox[CompressedData["
1:eJwt0DlMVFEUgOHBBFQQKxEYEBh1TCAUkphRWRsqNhVrtilFGIUaQSu10AZQ
Fms3KqCAUGCpgiI1KFRgIaGAhFigfDeh+PKfe17em8mNJVOtvScikUgar/hP
q8NdDszX9KUeUmme1x3KzEldZI+rzk90ik0uONfpc2b5TTx8V/t5wypn7a5o
F4/5yAaF9rXhv9DHJD/Ito/rZS5xkRglFFMUfju8Tw13eMgEK5zxfoFWc5sH
jPOdLM+iWsUtUozxjUzP8sMd0EIvr1nmtGd52skQH/hFgf1Nbabn+H6XOGWf
qx0M8p6fRO1vaBP3GeUrJ+3PazuPeMc6+fbX9RkzbId7sWvUbkb4QoZdjr5g
jj+U2rXpAG9ZI88uoZ/Yp8L5qU6zFe7buUH/hTsyL+gu5eZ7+peEeVjr9LOm
6zmt1yMB+kOw
         "]]}]}, {}, {}}, {{}, {}, 
     {Hue[0.67, 0.6, 0.6], 
      LineBox[{1, 258, 197, 145, 103, 71, 51, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 
       12, 13, 14, 15, 16, 17, 18, 259, 198, 146, 104, 72, 52, 278, 217, 165, 
       123, 91, 19, 260, 199, 147, 105, 73, 290, 229, 177, 135, 53, 279, 218, 
       166, 124, 303, 242, 190, 92, 296, 235, 183, 313, 252, 141, 307, 246, 
       321, 194, 316}], LineBox[CompressedData["
1:eJwt0TdMlVEYgOHLIFWZ6KJyQUkkDJIYaSoLE0XgOksbkaIyi8AEDLKAUmSm
yAQMGAcZqZYZECd1gDBgQhwQnpM4PHnP+f785Z4bbe+JdcdFIpFxzqm2SdNL
uq5VOqb39K92UGx9rB+ptP6nNRRY/9Qlhiix/6Nr4X6y7Hd1lpc84bbZoa7y
mnTizTb+f9NTarlp9kuXGaaUbLM9naOPZjJIMN/UN3RSRxk55vs6zytayCTR
fEvf0kU95Vw1/64L9NMafgNJ5ts6QTePqAjfQ7JrOzpJDw3hjMK7SXHts07x
jEbuh/dw2bUvOs1zmnhALte4zg3yiJIfzjucC7e44v6v+o4XxHgY7jc/0PcM
0EYhqebfdIZeHofnmP3WFUbCfx/ebfZDFxnkjv2JfqKdIvsj/RDOwPpMR7lr
faoXjHVDBQ==
       "]], 
      LineBox[{322, 195, 317, 256, 325, 39, 271, 210, 158, 311, 250, 116, 301,
        240, 188, 84, 294, 233, 181, 139, 64, 286, 225, 173, 131, 99, 40, 272,
        211, 159, 117, 85, 65, 41, 273, 212, 160, 118, 86, 66, 42, 274, 213, 
       161, 119, 87, 67, 287, 226, 174, 132, 100, 43, 275, 214, 162, 120, 302,
        241, 189, 88, 295, 234, 320, 182}], 
      LineBox[{312, 251, 323, 140, 306, 245, 193, 68, 288, 227, 175, 133, 101,
        44, 276, 215, 163, 121, 89, 69, 45, 46, 47, 48, 49, 277, 216, 164, 
       122, 90, 70, 289, 228, 176, 134, 102, 299, 238, 186, 144, 309, 248, 
       196, 318, 257, 326, 50}]}, 
     {Hue[0.67, 0.6, 0.6], Opacity[0.2], LineBox[{328, 329, 327}], 
      LineBox[{331, 332, 330}], LineBox[{334, 335, 333}]}}, {{}, {}, {}}}],
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->True,
  AxesOrigin->{0, 0},
  Frame->True,
  FrameLabel->{
    FormBox[
     RowBox[{"Distance", " ", "r"}], TraditionalForm], 
    FormBox["PDF", TraditionalForm]},
  Method->{"AxesInFront" -> True},
  PlotRange->{{0, 1.8311388300841898`}, {0., 1.1098035323239832`}},
  PlotRangeClipping->True,
  PlotRangePadding->{
    Scaled[0.02], 
    Scaled[0.02]}]], "Output",
 CellChangeTimes->{
  3.576136299203125*^9, 3.5761363659375*^9, 3.576136405265625*^9, 
   3.576136451765625*^9, 3.576136511546875*^9, {3.5761365435625*^9, 
   3.576136570234375*^9}, 3.576136687796875*^9, 3.57613672759375*^9, 
   3.5761367576875*^9, 3.57613680134375*^9, {3.57613683303125*^9, 
   3.57613686040625*^9}, 3.57613693115625*^9, {3.576137009375*^9, 
   3.57613703925*^9}, 3.57613709578125*^9, {3.576137231140625*^9, 
   3.57613725659375*^9}, 3.576137492078125*^9, {3.57613778590625*^9, 
   3.57613785353125*^9}, 3.576137887390625*^9, 3.576137934890625*^9, 
   3.57613798571875*^9, 3.576138059765625*^9, 3.576138373484375*^9, 
   3.576138768625*^9, 3.576138810828125*^9, 3.57613888628125*^9, {
   3.576139018328125*^9, 3.576139019*^9}, 3.576139077625*^9, 
   3.5761391104375*^9, 3.5761393389375*^9, {3.576139385921875*^9, 
   3.576139393984375*^9}, {3.576139427546875*^9, 3.576139440984375*^9}, {
   3.57613951365625*^9, 3.57613957115625*^9}, 3.57613960240625*^9, 
   3.57613974625*^9, {3.576177303890625*^9, 3.576177327453125*^9}, 
   3.57617742559375*^9, 3.576177462765625*^9, {3.576177567828125*^9, 
   3.57617759684375*^9}, {3.576177637046875*^9, 3.576177669140625*^9}, 
   3.576186313375*^9, 3.576186418296875*^9, 3.576186574625*^9, 
   3.576186607046875*^9, 3.5761866930625*^9, 3.576187142359375*^9, {
   3.576187416984375*^9, 3.576187429125*^9}, 3.576187789265625*^9, 
   3.57618788178125*^9, 3.57618822903125*^9, 3.5761892338125*^9, {
   3.5761893313125*^9, 3.5761893538125*^9}, 3.5761900068125*^9, 
   3.57619015346875*^9, 3.576190412484375*^9, {3.57619077903125*^9, 
   3.5761908085*^9}, 3.5761908390625*^9, {3.576190947578125*^9, 
   3.576190964328125*^9}, 3.5762027173376226`*^9, 3.576202757272311*^9, 
   3.576202895856304*^9, {3.576202942259287*^9, 3.576202970601042*^9}, 
   3.5762030664380445`*^9, {3.576203896921875*^9, 3.57620394965625*^9}, {
   3.576204008109375*^9, 3.5762040713125*^9}, {3.576204105421875*^9, 
   3.576204131328125*^9}, 3.576204174515625*^9, 3.576204232765625*^9, 
   3.576207973265625*^9, 3.5762080275625*^9, 3.5762080965625*^9, {
   3.57620914284375*^9, 3.576209180828125*^9}, 3.576210561578125*^9, 
   3.576210863171875*^9, {3.576210990265625*^9, 3.57621100246875*^9}, {
   3.576211204390625*^9, 3.5762112074375*^9}, 3.5762113436875*^9, {
   3.5762115074375*^9, 3.57621151559375*^9}, 3.576211695234375*^9, 
   3.576211738640625*^9, 3.5762121834375*^9, 3.57621222703125*^9, 
   3.576212353640625*^9, 3.5762124086875*^9, {3.576212480734375*^9, 
   3.57621248846875*^9}, {3.576212531046875*^9, 3.576212578046875*^9}, {
   3.5762126996875*^9, 3.576212734453125*^9}, 3.5762131033125*^9, 
   3.576213304328125*^9, 3.576213518234375*^9, 3.576213553171875*^9, {
   3.5762136181875*^9, 3.57621363115625*^9}, {3.576213673609375*^9, 
   3.576213703640625*^9}, 3.57621380725*^9, 3.57621384915625*^9, 
   3.576213894390625*^9, 3.57621395371875*^9, {3.5762140093125*^9, 
   3.57621403503125*^9}, 3.57621410196875*^9, 3.57621413259375*^9, 
   3.5762209215*^9, 3.576221004875*^9, 3.57622103753125*^9, 
   3.576221117984375*^9, {3.5762211549375*^9, 3.57622116078125*^9}, {
   3.5762212139375*^9, 3.57622124615625*^9}, 3.576221307203125*^9, {
   3.5762213545625*^9, 3.576221376359375*^9}, 3.576221414109375*^9, 
   3.57622160475*^9, 3.5762250725625*^9, 3.576225116640625*^9, 
   3.57622515634375*^9, 3.576225252390625*^9, 3.576225396484375*^9, 
   3.576225495734375*^9, 3.5762255465*^9, 3.57622558584375*^9, 
   3.576225654328125*^9, 3.576225706171875*^9, 3.5762257375*^9, 
   3.57622588225*^9, 3.576226457046875*^9, {3.57626287428125*^9, 
   3.5762629439375*^9}, 3.576262974578125*^9, 3.57626300878125*^9, 
   3.5762777567231526`*^9, 3.576278143552817*^9, {3.5762781892836795`*^9, 
   3.5762782058605328`*^9}, 3.576278272090245*^9, 3.5762783328984632`*^9, 
   3.5762784598114033`*^9, 3.5762945201724663`*^9, 3.5762947543903513`*^9, 
   3.5762948962397394`*^9, {3.5762949412209473`*^9, 3.576295190437776*^9}, {
   3.5762952242947674`*^9, 3.576295267463603*^9}, {3.576295362503787*^9, 
   3.576295384455366*^9}, 3.576295417843641*^9, {3.5762954581689267`*^9, 
   3.576295524226776*^9}, 3.576310690686577*^9, {3.5763114478098817`*^9, 
   3.576311471402231*^9}, 3.576311612399296*^9, 3.5763117076977463`*^9, 
   3.5763118657477865`*^9, 3.576311921286963*^9, 3.5763119779702053`*^9, 
   3.576312047232167*^9, 3.576312123996557*^9, 3.5763500048125*^9, 
   3.576351491421875*^9, 3.576351591*^9, 3.576351760203125*^9, 
   3.576355443390625*^9, 3.576355744828125*^9, {3.57635729315625*^9, 
   3.576357317953125*^9}, 3.576357359828125*^9, 3.576357485296875*^9, 
   3.57635756796875*^9, 3.5763577068125*^9, 3.576364863952327*^9, 
   3.576364925385502*^9, 3.5763650153947897`*^9, {3.5763705644377832`*^9, 
   3.5763705931083736`*^9}, 3.5763708047551413`*^9, 3.576375270425031*^9, 
   3.5763754033650355`*^9, 3.576380149613265*^9, 3.5763802095015903`*^9, 
   3.5763802859517794`*^9, 3.576380334996771*^9, 3.5763803873228865`*^9, 
   3.5763804694603577`*^9, {3.576380529583049*^9, 3.576380556941373*^9}, {
   3.5764597399223747`*^9, 3.5764597604379997`*^9}, 3.5764601453286247`*^9, 
   3.5764604476411247`*^9, 3.5764605374067497`*^9, 3.5764605958754997`*^9, 
   3.5764607750161247`*^9, 3.5764608344379997`*^9, 3.5764609283442497`*^9, 
   3.5764610816723747`*^9, {3.5764611303754997`*^9, 3.5764611569692497`*^9}, 
   3.576706410546875*^9, 3.576706656953125*^9, {3.576706803421875*^9, 
   3.576706827578125*^9}, 3.57678566290625*^9, 3.576786203015625*^9, 
   3.57678716371875*^9, 3.576788349*^9, {3.576789282921875*^9, 
   3.57678931228125*^9}, 3.576789492859375*^9, 3.576789568625*^9, 
   3.57678963109375*^9, 3.57679069440625*^9, 3.576790938859375*^9, 
   3.576791108546875*^9, 3.57679169128125*^9, 3.5768959114375*^9, 
   3.576895952625*^9, 3.576896091265625*^9, 3.576896137078125*^9, 
   3.576896377921875*^9, 3.576896736609375*^9, 3.5768970165625*^9, 
   3.576897052359375*^9, 3.576897192046875*^9, 3.576897241515625*^9, 
   3.576899897453125*^9, 3.576960967125*^9, 3.57696107253125*^9, 
   3.57696114071875*^9}]
}, Open  ]],

Cell["Show and plot the CDF F_R (r)", "Text",
 CellChangeTimes->{{3.576350183796875*^9, 3.576350189484375*^9}, {
  3.576350758203125*^9, 3.57635075959375*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"FRr", "=", 
  RowBox[{
   FractionBox["1", "area"], 
   RowBox[{"Piecewise", "[", 
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{"{", 
        RowBox[{"#1", ",", 
         RowBox[{
          RowBox[{"#2", "[", 
           RowBox[{"[", "1", "]"}], "]"}], "\[LessEqual]", "r", 
          "\[LessEqual]", 
          RowBox[{"#2", "[", 
           RowBox[{"[", "2", "]"}], "]"}]}]}], "}"}], "&"}], "@@@", 
      RowBox[{"Transpose", "@", 
       RowBox[{"{", 
        RowBox[{"answernewCDF", ",", 
         RowBox[{"Partition", "[", 
          RowBox[{"Uniquedistancesnew", ",", "2", ",", "1"}], "]"}]}], 
        "}"}]}]}], ",", "area"}], "]"}]}]}]], "Input",
 CellChangeTimes->{{3.5763067582852697`*^9, 3.576306770671691*^9}, {
  3.57631266690561*^9, 3.576312675591107*^9}}],

Cell[BoxData[
 RowBox[{
  FractionBox["1", "2"], " ", 
  RowBox[{"(", 
   TagBox[GridBox[{
      {"\[Piecewise]", GridBox[{
         {
          FractionBox[
           RowBox[{"\[Pi]", " ", 
            SuperscriptBox["r", "2"]}], "2"], 
          RowBox[{"0", "\[LessEqual]", "r", "\[LessEqual]", 
           FractionBox["1", 
            SqrtBox["2"]]}]},
         {
          RowBox[{
           RowBox[{
            FractionBox["1", "2"], " ", 
            SqrtBox[
             RowBox[{
              RowBox[{"-", "1"}], "+", 
              RowBox[{"2", " ", 
               SuperscriptBox["r", "2"]}]}]]}], "+", 
           RowBox[{
            SuperscriptBox["r", "2"], " ", 
            RowBox[{"ArcCsc", "[", 
             RowBox[{
              SqrtBox["2"], " ", "r"}], "]"}]}]}], 
          RowBox[{
           FractionBox["1", 
            SqrtBox["2"]], "\[LessEqual]", "r", "\[LessEqual]", 
           SqrtBox["2"]}]},
         {
          RowBox[{
           RowBox[{
            SqrtBox["2"], " ", 
            SqrtBox[
             RowBox[{
              RowBox[{"-", "2"}], "+", 
              SuperscriptBox["r", "2"]}]]}], "+", 
           RowBox[{
            FractionBox["1", "2"], " ", 
            SqrtBox[
             RowBox[{
              RowBox[{"-", "1"}], "+", 
              RowBox[{"2", " ", 
               SuperscriptBox["r", "2"]}]}]]}], "+", 
           RowBox[{
            SuperscriptBox["r", "2"], " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"ArcCsc", "[", 
               RowBox[{
                SqrtBox["2"], " ", "r"}], "]"}], "-", 
              RowBox[{"ArcSec", "[", 
               FractionBox["r", 
                SqrtBox["2"]], "]"}]}], ")"}]}]}], 
          RowBox[{
           SqrtBox["2"], "\[LessEqual]", "r", "\[LessEqual]", 
           SqrtBox[
            FractionBox["5", "2"]]}]},
         {"2", 
          TagBox["True",
           "PiecewiseDefault",
           AutoDelete->True]}
        },
        AllowedDimensions->{2, Automatic},
        Editable->True,
        GridBoxAlignment->{
         "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, 
          "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
        GridBoxItemSize->{
         "Columns" -> {{Automatic}}, "ColumnsIndexed" -> {}, "Rows" -> {{1.}},
           "RowsIndexed" -> {}},
        GridBoxSpacings->{"Columns" -> {
            Offset[0.27999999999999997`], {
             Offset[0.84]}, 
            Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
            Offset[0.2], {
             Offset[0.4]}, 
            Offset[0.2]}, "RowsIndexed" -> {}},
        Selectable->True]}
     },
     GridBoxAlignment->{
      "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
       "RowsIndexed" -> {}},
     GridBoxItemSize->{
      "Columns" -> {{Automatic}}, "ColumnsIndexed" -> {}, "Rows" -> {{1.}}, 
       "RowsIndexed" -> {}},
     GridBoxSpacings->{"Columns" -> {
         Offset[0.27999999999999997`], {
          Offset[0.35]}, 
         Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
         Offset[0.2], {
          Offset[0.4]}, 
         Offset[0.2]}, "RowsIndexed" -> {}}],
    "Piecewise",
    DeleteWithContents->True,
    Editable->False,
    SelectWithContents->True,
    Selectable->False], ")"}]}]], "Output",
 CellChangeTimes->{
  3.5763067726684947`*^9, 3.576310696792926*^9, {3.576311450010008*^9, 
   3.5763114715502396`*^9}, 3.576311612493301*^9, 3.576311707822754*^9, 
   3.576311865869793*^9, 3.5763119213689675`*^9, 3.576311978125214*^9, 
   3.5763120473511734`*^9, 3.576312124079562*^9, 3.5763126767021704`*^9, 
   3.576350005359375*^9, 3.576351491453125*^9, 3.57635159103125*^9, 
   3.57635176021875*^9, 3.576355443453125*^9, 3.57635574484375*^9, {
   3.5763572931875*^9, 3.57635731796875*^9}, 3.57635735984375*^9, 
   3.576357485328125*^9, 3.576357567984375*^9, 3.576357706828125*^9, {
   3.5763648375638227`*^9, 3.576364863983575*^9}, 3.576364925401126*^9, 
   3.5763650154104137`*^9, {3.5763705644534073`*^9, 3.5763705931239977`*^9}, 
   3.5763708047707653`*^9, 3.5763752704406567`*^9, 3.5763754033650355`*^9, 
   3.576380149628889*^9, 3.576380209517215*^9, 3.576380285967404*^9, 
   3.576380334996771*^9, 3.576380387338511*^9, 3.5763804694603577`*^9, {
   3.576380529583049*^9, 3.5763805569569974`*^9}, {3.5764597399692497`*^9, 
   3.5764597604536247`*^9}, 3.5764601453442497`*^9, 3.5764604476567497`*^9, 
   3.5764605374223747`*^9, 3.5764605959223747`*^9, 3.5764607750473747`*^9, 
   3.5764608344848747`*^9, 3.5764609283911247`*^9, 3.5764610816879997`*^9, {
   3.5764611303911247`*^9, 3.5764611570161247`*^9}, 3.576706410640625*^9, 
   3.576706656984375*^9, {3.5767068034375*^9, 3.57670682759375*^9}, 
   3.576785663*^9, 3.576786203046875*^9, 3.576787163765625*^9, 
   3.57678834909375*^9, {3.57678928296875*^9, 3.57678931234375*^9}, 
   3.576789492890625*^9, 3.5767895688125*^9, 3.5767896311875*^9, 
   3.5767906944375*^9, 3.57679093925*^9, 3.576791108640625*^9, 
   3.576791691328125*^9, 3.576895912375*^9, 3.576895952640625*^9, 
   3.5768960913125*^9, 3.576896137109375*^9, 3.5768963779375*^9, 
   3.57689673665625*^9, 3.57689701659375*^9, 3.576897052375*^9, 
   3.57689719209375*^9, 3.576897241546875*^9, 3.5768998975625*^9, 
   3.576960967203125*^9, 3.576961072953125*^9, 3.576961140828125*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Plot", "[", 
  RowBox[{"FRr", ",", 
   RowBox[{"{", 
    RowBox[{"r", ",", "0", ",", "maxrange"}], "}"}], ",", 
   RowBox[{"Filling", "\[Rule]", "Bottom"}], ",", 
   RowBox[{"Frame", "\[Rule]", "True"}], ",", 
   RowBox[{"FrameLabel", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"Distance", " ", "r"}], ",", "CDF"}], "}"}]}]}], "]"}]], "Input",
 CellChangeTimes->{{3.57630680422735*^9, 3.5763068118401637`*^9}, {
  3.576350777578125*^9, 3.576350778484375*^9}}],

Cell[BoxData[
 GraphicsBox[GraphicsComplexBox[CompressedData["
1:eJxlWHs4Vd323m5dlfRFRIRUFEo3Fd5SyiWXpPhCJLeIcgtfpELJrYRCci2S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   "], {{{}, 
     {Hue[0.67, 0.6, 0.6], Opacity[0.2], EdgeForm[None], 
      GraphicsGroupBox[{
        PolygonBox[{{240, 270, 271, 50, 64, 49, 48, 47, 46, 45, 63, 44, 86, 
         62, 153, 112, 251, 195}}], 
        PolygonBox[{{20, 266, 267, 258, 114, 144, 182, 227, 81, 103, 133, 171,
          216, 57, 71, 93, 123, 161, 206, 38, 37, 36, 35, 34, 33, 32, 31, 30, 
         29, 28, 27, 26, 25, 24, 23, 22, 21}}], PolygonBox[CompressedData["
1:eJwNx8srwwEAwPEfZ/4IJ6//wLa74TRcPeYy1Hbg6HXyKFNEakevk0ehpklS
4mg4YYWaJkktIrXDPodPfb8N8VQsWRsEQQ1DNFJn6lnSfxzzShcVrvhmjX9O
eSfOBV/M8MsO97RyzQ8ZzvlknEvKrHDCG72sc8YHoyxwQIEIKdIc8UInq+Qo
Mcg029zRwhjLZCnSwwjz7PNEmCSLHPJMBwNMscUtzXQzzBx7PBIiSj+TbJKn
iRgJZtnlgTba6WOCDW6oAn6sPFs=
         "]], PolygonBox[CompressedData["
1:eJwt0CdLxAEYBvC/23Pe6SfwMzir42x6YnEmV3JgcDb1khcMByI4myNpMAgi
IgjO5kgaDIKICIIgFv0dXPg9z1ve8lT0jbWPZgZBkMFwuvNFiD93OWVECFNK
CcUUUUgBodQfedTRTC+zbHFLLrVE6WGGTW7IoY0h4uzxSA1NdDPNBtdkE2OQ
BXZ5oJpGuphinSuyaGWAeXa4p4oREhzwTAOdTLLGJamNxlnikBdaWOaYN/qZ
Y5s7KlnhhPf0vmd8ssg+T9RzzhdJfjjilQ5+OeWDCb5Z5YJ/nL41Nw==
         "]]}]}, {}, {}}, {{}, {}, 
     {Hue[0.67, 0.6, 0.6], 
      LineBox[{1, 200, 155, 245, 117, 237, 192, 250, 87, 230, 185, 248, 147, 
       242, 197, 65, 221, 176, 138, 239, 194, 108, 235, 190, 152, 51, 212, 
       167, 129, 99, 233, 188, 150, 77, 226, 181, 143, 113, 2, 201, 156, 118, 
       88, 66, 222, 177, 139, 109, 52, 213, 168, 130, 100, 78, 3, 202, 157, 
       119, 89, 67, 53, 214, 169, 131, 101, 79, 4, 203, 158, 120, 90, 68, 54, 
       215, 170, 132, 102, 80, 5, 204, 159, 121, 91, 69, 55, 6, 205, 160, 122,
        92, 70, 56, 7, 8, 9, 10, 11, 12, 13, 14, 15, 16, 17, 18, 19, 255}], 
      LineBox[{20, 21, 22, 23, 24, 25, 26, 27, 28, 29, 30, 31, 32, 33, 34, 35,
        36, 37, 38, 206, 161, 123, 93, 71, 57, 216, 171, 133, 103, 81, 227, 
       182, 144, 114, 258}], 
      LineBox[{39, 207, 162, 124, 94, 72, 58, 217, 172, 134, 104, 82, 40, 208,
        163, 125, 95, 73, 59, 218, 173, 135, 105, 83, 41, 209, 164, 126, 96, 
       74, 223, 178, 140, 110, 60, 219, 174, 136, 106, 84, 228, 183, 145, 115,
        42, 210, 165, 127, 97, 231, 186, 148, 75, 224, 179, 141, 111, 61, 220,
        175, 137, 107, 234, 189, 151, 85, 229, 184, 146, 241, 196, 116, 236, 
       191, 154, 244, 199, 43, 211, 166, 246, 128, 238, 193, 98, 232, 187, 
       249, 149, 243, 198, 252, 76, 225, 180, 247, 142}], 
      LineBox[{240, 195, 251, 112, 153, 62, 86, 44, 63, 45, 46, 47, 48, 49, 
       64, 50}]}, 
     {Hue[0.67, 0.6, 0.6], Opacity[0.2], LineBox[{254, 262, 253}], 
      LineBox[{257, 259, 256}], LineBox[{261, 263, 260}]}}, {{}, {}, {}}}],
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->True,
  AxesOrigin->{0, 0},
  Frame->True,
  FrameLabel->{
    FormBox[
     RowBox[{"Distance", " ", "r"}], TraditionalForm], 
    FormBox["CDF", TraditionalForm]},
  Method->{"AxesInFront" -> True},
  PlotRange->{{0, 1.8311388300841898`}, {0., 1.}},
  PlotRangeClipping->True,
  PlotRangePadding->{
    Scaled[0.02], 
    Scaled[0.02]}]], "Output",
 CellChangeTimes->{
  3.5763068151005692`*^9, 3.576310700445135*^9, {3.5763114520431237`*^9, 
   3.576311471784253*^9}, 3.576311612805319*^9, 3.576311708261779*^9, 
   3.576311866116808*^9, 3.576311921601981*^9, 3.5763119784342318`*^9, 
   3.576312047479181*^9, 3.5763121243445773`*^9, 3.576312692447071*^9, 
   3.57635000553125*^9, 3.57635149153125*^9, 3.57635159109375*^9, 
   3.576351760546875*^9, 3.576355443578125*^9, 3.5763557449375*^9, {
   3.576357293234375*^9, 3.57635731803125*^9}, 3.57635735996875*^9, 
   3.576357485390625*^9, 3.57635756803125*^9, 3.57635770690625*^9, {
   3.5763648443287086`*^9, 3.576364864030446*^9}, 3.576364925432373*^9, 
   3.576365015488533*^9, {3.5763705645002804`*^9, 3.576370593139622*^9}, 
   3.57637080489576*^9, 3.5763752704875326`*^9, 3.576375403427534*^9, 
   3.576380149660138*^9, 3.5763802095484633`*^9, 3.5763802859986525`*^9, 
   3.57638033502802*^9, 3.5763803873697596`*^9, 3.576380469491606*^9, {
   3.5763805296142974`*^9, 3.5763805570038705`*^9}, {3.5764597400161247`*^9, 
   3.5764597605004997`*^9}, 3.5764601453911247`*^9, 3.5764604477036247`*^9, 
   3.5764605375161247`*^9, 3.5764605963442497`*^9, 3.5764607751098747`*^9, 
   3.5764608345317497`*^9, 3.5764609289067497`*^9, 3.5764610817973747`*^9, {
   3.5764611304536247`*^9, 3.5764611571098747`*^9}, 3.576706410890625*^9, 
   3.576706657078125*^9, {3.5767068035625*^9, 3.57670682765625*^9}, 
   3.57678566325*^9, 3.576786203171875*^9, 3.576787164*^9, 
   3.576788349984375*^9, {3.57678928325*^9, 3.576789312984375*^9}, 
   3.5767894930625*^9, 3.576789569453125*^9, 3.576789631375*^9, 
   3.57679069496875*^9, 3.5767909395625*^9, 3.576791108734375*^9, 
   3.576791691484375*^9, 3.57689591284375*^9, 3.57689595271875*^9, 
   3.576896092390625*^9, 3.5768961371875*^9, 3.576896378015625*^9, 
   3.57689673696875*^9, 3.576897017015625*^9, 3.5768970524375*^9, 
   3.576897192171875*^9, 3.576897241625*^9, 3.57689989771875*^9, 
   3.576960968875*^9, 3.57696107340625*^9, 3.576961140890625*^9}]
}, Open  ]],

Cell["\<\
Export the PDF and CDF values to a text file for importing and plotting in \
Matlab\
\>", "Text",
 CellChangeTimes->{{3.5762109315*^9, 3.576210948359375*^9}, 
   3.576221563546875*^9, {3.57635020225*^9, 3.576350234765625*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"ansOUT", "=", 
   RowBox[{"{", "}"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"stepsize", "=", 
   FractionBox["1", "1000"]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"For", "[", 
   RowBox[{
    RowBox[{"rr", "=", "0.001"}], ",", 
    RowBox[{"rr", "\[LessEqual]", 
     RowBox[{"Max", "[", 
      RowBox[{"Uniquedistances", "+", "0.25"}], "]"}]}], ",", 
    RowBox[{"rr", "+=", "stepsize"}], ",", 
    RowBox[{"AppendTo", "[", 
     RowBox[{"ansOUT", ",", 
      RowBox[{"{", 
       RowBox[{"r", ",", "fRr", ",", "FRr"}], "}"}]}], "]"}]}], "]"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{"Export", "[", 
  RowBox[{"\"\<result.txt\>\"", ",", "ansOUT", ",", "\"\<table\>\""}], 
  "]"}]}], "Input",
 CellChangeTimes->CompressedData["
1:eJxTTMoPSmViYGAQBWIQzdAQKySy9JUjA8NjJQidogGmG4y0IPQ7SwjtYQeh
10dB6L2xEPUayRA6IB0ivrUAwr8BoRsYyiF85ToIfXUCRFxmIoTvMRNCG8+C
0LeWQOSdV0P4gRsg9AkI3cC5FULXbofQZw5B6NQzEJr/KtQ/1yD8ztsQfuwd
CP3nBUTc9jWE1voAoZd8g9Bzl0uCafOVIHrK9MJDtkC6V/QRmA7x3mXkBqSL
qv+DaaB9myLA9BYwDQCnO43O
  "]],

Cell[BoxData["\<\"result.txt\"\>"], "Output",
 CellChangeTimes->{
  3.576350006546875*^9, 3.576351492625*^9, 3.576351609125*^9, 
   3.576351794828125*^9, 3.576355478390625*^9, 3.57635578046875*^9, {
   3.57635729453125*^9, 3.576357319109375*^9}, 3.576357394921875*^9, 
   3.576357486875*^9, 3.576357587046875*^9, 3.57635770959375*^9, 
   3.576364865311606*^9, 3.5763649262291923`*^9, 3.576365049392396*^9, 
   3.576370565640854*^9, 3.5763706037328978`*^9, 3.576370826394797*^9, 
   3.5763752715813107`*^9, 3.576375404427515*^9, 3.5763801508632174`*^9, 
   3.5763802105015516`*^9, 3.57638028698299*^9, 3.576380335934235*^9, 
   3.5763803881353555`*^9, 3.576380469960338*^9, {3.5763805300205317`*^9, 
   3.5763805580975785`*^9}, 3.5764597412504997`*^9, 3.5764597787036247`*^9, 
   3.5764601629536247`*^9, 3.5764604660786247`*^9, 3.5764605397348747`*^9, 
   3.5764606028129997`*^9, 3.5764607755629997`*^9, 3.5764608349379997`*^9, 
   3.5764609689379997`*^9, {3.5764611245942497`*^9, 3.5764611763286247`*^9}, 
   3.576706431078125*^9, 3.57670667315625*^9, 3.576706806625*^9, 
   3.57670684575*^9, 3.576785707046875*^9, 3.57678620525*^9, 
   3.576787170890625*^9, 3.576788356953125*^9, 3.576789290453125*^9, 
   3.57678935559375*^9, 3.576789535921875*^9, 3.576789611453125*^9, 
   3.576789674765625*^9, 3.576790701734375*^9, 3.576790982046875*^9, 
   3.576791110828125*^9, 3.5767917098125*^9, {3.576895944375*^9, 
   3.576895954234375*^9}, {3.5768961253125*^9, 3.57689613865625*^9}, 
   3.57689637946875*^9, 3.576896741296875*^9, 3.57689702075*^9, 
   3.57689705453125*^9, 3.576897194203125*^9, 3.5768972431875*^9, 
   3.5768998990625*^9, 3.57696097453125*^9, 3.576961109078125*^9, 
   3.576961161890625*^9}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
7. Application: n-th neighbour PDF results\
\>", "Section",
 CellChangeTimes->{{3.576027529953125*^9, 3.57602754075*^9}, {
  3.57621320475*^9, 3.5762132138125*^9}, {3.57622157159375*^9, 
  3.576221575390625*^9}, {3.576351473078125*^9, 3.576351473484375*^9}}],

Cell["Define the number of nodes ", "Text",
 CellChangeTimes->{{3.57622107484375*^9, 3.576221091171875*^9}, {
  3.57635006315625*^9, 3.576350069109375*^9}, {3.57635453234375*^9, 
  3.57635453578125*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"\[CapitalNu]", "=", "5"}], ";"}]], "Input",
 CellChangeTimes->{{3.5762628685625*^9, 3.57626286953125*^9}}],

Cell["\<\
Define the nth neighbour PDF: Equation (12) in [1] (see reference 1 in [1])\
\>", "Text",
 CellChangeTimes->{{3.576213156796875*^9, 3.5762131663125*^9}, {
  3.57635454771875*^9, 3.5763545894375*^9}, {3.576355377546875*^9, 
  3.5763553805625*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"fr", "[", 
    RowBox[{"\[CapitalNu]_", ",", "n_", ",", "r_"}], "]"}], ":=", 
   RowBox[{
    FractionBox[
     RowBox[{
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{"1", "-", "FRr"}], ")"}], 
       RowBox[{"\[CapitalNu]", "-", "n"}]], " ", 
      SuperscriptBox[
       RowBox[{"(", "FRr", ")"}], 
       RowBox[{"n", "-", "1"}]]}], 
     RowBox[{"Beta", "[", 
      RowBox[{
       RowBox[{"\[CapitalNu]", "-", "n", "+", "1"}], ",", "n"}], "]"}]], " ", 
    "fRr"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.576212852515625*^9, 3.576212914453125*^9}, 
   3.57621299459375*^9, 3.576213145765625*^9, {3.57622090509375*^9, 
   3.576220907703125*^9}, {3.57629487072591*^9, 3.576294881475154*^9}, {
   3.576306959447623*^9, 3.5763069654692335`*^9}, {3.5763115951763105`*^9, 
   3.576311597632451*^9}, {3.5763122186089687`*^9, 3.5763122201990595`*^9}, {
   3.576350051875*^9, 3.576350054515625*^9}}],

Cell["Plotting", "Text",
 CellChangeTimes->{{3.57635460521875*^9, 3.5763546064375*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Plot", "[", 
  RowBox[{
   RowBox[{"Table", "[", 
    RowBox[{
     RowBox[{"fr", "[", 
      RowBox[{"\[CapitalNu]", ",", "n", ",", "r"}], "]"}], ",", 
     RowBox[{"{", 
      RowBox[{"n", " ", ",", 
       RowBox[{"Range", "[", 
        RowBox[{"1", ",", "\[CapitalNu]"}], "]"}]}], "}"}]}], "]"}], ",", 
   RowBox[{"{", 
    RowBox[{"r", ",", "0", ",", "maxrange"}], "}"}], ",", 
   RowBox[{"PlotRange", "\[Rule]", "Full"}], ",", 
   RowBox[{"Frame", "\[Rule]", "True"}], ",", 
   RowBox[{"FrameLabel", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"Distance", " ", "r"}], ",", "PDF"}], "}"}]}]}], "]"}]], "Input",
 CellChangeTimes->{{3.576212984515625*^9, 3.576212990953125*^9}, {
   3.57621303340625*^9, 3.57621303575*^9}, {3.576213075265625*^9, 
   3.576213096765625*^9}, {3.576213418578125*^9, 3.57621343265625*^9}, 
   3.576213596328125*^9, {3.576221104640625*^9, 3.57622110590625*^9}, {
   3.576221175546875*^9, 3.57622119215625*^9}, {3.576294874678757*^9, 
   3.5762948854123764`*^9}, {3.5763122217731495`*^9, 3.576312223120227*^9}, 
   3.5764604910473747`*^9, 3.5764606767348747`*^9, {3.576960849375*^9, 
   3.57696085171875*^9}, {3.576961024640625*^9, 3.576961025078125*^9}}],

Cell[BoxData[
 GraphicsBox[{{}, {}, 
   {Hue[0.67, 0.6, 0.6], LineBox[CompressedData["
1:eJwVl3c8le8bx80UQnbSUEiyaeE8H5XSF1EqRUrJzCgy2mWVhEpIUpQkeyaK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     "]], LineBox[CompressedData["
1:eJwVl3c8Vf8fx400RSmzkuxEoknueUmKMpNKJIUoySirSEZGsneSIiOryPiS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     "]], LineBox[CompressedData["
1:eJwVV3c4118bjmjSUGQUklFWiErxuSMNFJIfIilZDYlQaVvZeyUzOyMyMrIp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     "]], LineBox[CompressedData["
1:eJwVl3c41f8bxpVZCZWdFFklQlTifG6lksrIaBBtVN/IpklUUiKblJlNdsgM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     "]], LineBox[CompressedData["
1:eJwVV3c01o8XtqmEClkhOzNCkvdzXyR7JKOssqOy96hkZGRkJxlZmdkzvPbe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     "]]}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->True,
  AxesOrigin->{0, 0},
  Frame->True,
  FrameLabel->{
    FormBox[
     RowBox[{"Distance", " ", "r"}], TraditionalForm], 
    FormBox["PDF", TraditionalForm]},
  PlotRange->{{0, 1.8311388300841898`}, {4.247918107853654*^-67, 
    3.0967846755505004`}},
  PlotRangeClipping->True,
  PlotRangePadding->{
    Scaled[0.02], 
    Scaled[0.02]}]], "Output",
 CellChangeTimes->{{3.5769611115625*^9, 3.576961113546875*^9}, 
   3.576961163484375*^9}]
}, Open  ]],

Cell["Display total execuation time for the notebook in seconds", "Text",
 CellChangeTimes->{{3.576355408140625*^9, 3.576355421359375*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"endtime", "=", 
   RowBox[{"SessionTime", "[", "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{"Executiontime", "=", 
  RowBox[{"(", 
   RowBox[{"endtime", "-", "starttime"}], ")"}]}]}], "Input",
 CellChangeTimes->{{3.557793913203125*^9, 3.557793921515625*^9}, {
  3.557793966203125*^9, 3.557793979703125*^9}, {3.57635543078125*^9, 
  3.57635543328125*^9}},
 FontSize->20],

Cell[BoxData["25.609375`8.558913977418603"], "Output",
 CellChangeTimes->{
  3.5577939471875*^9, {3.5577939835625*^9, 3.5577940106875*^9}, 
   3.557794119*^9, 3.557794439546875*^9, 3.557794537203125*^9, {
   3.557794636171875*^9, 3.5577946475625*^9}, 3.557794846109375*^9, {
   3.557794928609375*^9, 3.55779494521875*^9}, 3.557794984046875*^9, {
   3.557795038484375*^9, 3.55779506459375*^9}, 3.55779557971875*^9, 
   3.558735666546875*^9, {3.558735708109375*^9, 3.558735717515625*^9}, {
   3.558735766515625*^9, 3.558735787421875*^9}, {3.558735912265625*^9, 
   3.558735928703125*^9}, 3.558735963953125*^9, {3.558736026984375*^9, 
   3.558736041328125*^9}, 3.558736257859375*^9, 3.558736288140625*^9, {
   3.55873635603125*^9, 3.5587363915625*^9}, 3.55873775184375*^9, 
   3.558737783609375*^9, 3.558737814734375*^9, 3.5587380640625*^9, 
   3.558738579328125*^9, {3.558738990015625*^9, 3.5587390069375*^9}, 
   3.55873908378125*^9, 3.55874067103125*^9, 3.558740918453125*^9, 
   3.558742041921875*^9, 3.558742086453125*^9, 3.55874219853125*^9, {
   3.558742231734375*^9, 3.558742252375*^9}, {3.558742348703125*^9, 
   3.558742384203125*^9}, 3.5587424145*^9, 3.558742467359375*^9, 
   3.558742525671875*^9, {3.558742569234375*^9, 3.5587425808125*^9}, 
   3.55874267628125*^9, {3.558742823859375*^9, 3.55874283471875*^9}, 
   3.558742879671875*^9, {3.55874297471875*^9, 3.558742997734375*^9}, 
   3.55874305509375*^9, 3.55874312*^9, 3.558744147234375*^9, 
   3.5587514788125*^9, 3.55875152625*^9, 3.558751559921875*^9, 
   3.5587532723125*^9, {3.55875330734375*^9, 3.558753329609375*^9}, 
   3.57583468540625*^9, 3.5758415609560003`*^9, 3.5758424500653753`*^9, {
   3.5758424846122503`*^9, 3.5758425138935003`*^9}, 3.5758425672060003`*^9, 
   3.5758426455497503`*^9, 3.5758426988466253`*^9, 3.5758433161278753`*^9, 
   3.5758433554091253`*^9, 3.5758437473778753`*^9, {3.5758438836903753`*^9, 
   3.5758439278778753`*^9}, 3.5758440885028753`*^9, 3.5758443262841253`*^9, 
   3.5758443956591253`*^9, 3.5758444350028753`*^9, 3.5758457770810003`*^9, 
   3.5758460382841253`*^9, 3.5758460949091253`*^9, {3.5758468975185003`*^9, 
   3.5758469398153753`*^9}, 3.5758470313935003`*^9, 3.5758470656747503`*^9, {
   3.5758471581903753`*^9, 3.5758471777685003`*^9}, 3.5758472618310003`*^9, 
   3.5758473003153753`*^9, 3.5758473920497503`*^9, 3.5758476718778753`*^9, 
   3.5758477487841253`*^9, 3.5758486032841253`*^9, 3.5758486554560003`*^9, 
   3.5758488588153753`*^9, 3.5758490067372503`*^9, 3.5758569506903753`*^9, {
   3.5758570420497503`*^9, 3.5758570582372503`*^9}, 3.5758572761435003`*^9, {
   3.5758573628935003`*^9, 3.5758573891747503`*^9}, 3.5758574710653753`*^9, 
   3.5758576145653753`*^9, 3.5758578030497503`*^9, 3.5758578655966253`*^9, 
   3.5758579228153753`*^9, {3.5758579645185003`*^9, 3.5758579904716253`*^9}, {
   3.5758583042060003`*^9, 3.5758583356747503`*^9}, {3.5758586286591253`*^9, 
   3.5758586736122503`*^9}, 3.5758594013153753`*^9, 3.5758594472060003`*^9, 
   3.5758595048622503`*^9, {3.5758597360653753`*^9, 3.5758597652841253`*^9}, {
   3.5758597992216253`*^9, 3.5758598222216253`*^9}, 3.5758598614247503`*^9, 
   3.5758600096278753`*^9, {3.5758600634872503`*^9, 3.5758600840185003`*^9}, 
   3.5758601469872503`*^9, {3.5758602039247503`*^9, 3.5758602567060003`*^9}, 
   3.5758608194091253`*^9, 3.5758608576278753`*^9, 3.5758610894716253`*^9, 
   3.5758611584716253`*^9, 3.5758612285185003`*^9, 3.5758612599716253`*^9, 
   3.575934534046875*^9, 3.575934580765625*^9, 3.575941398421875*^9, 
   3.575941463109375*^9, 3.575941835578125*^9, 3.575941888203125*^9, 
   3.5759454098125*^9, 3.575946445078125*^9, 3.575946498515625*^9, 
   3.575948340390625*^9, 3.575948496765625*^9, 3.575948729078125*^9, {
   3.575948980578125*^9, 3.5759489921875*^9}, 3.57594903340625*^9, 
   3.575949115859375*^9, 3.5759491558125*^9, 3.5759492511875*^9, 
   3.57594935084375*^9, {3.5759493885*^9, 3.5759494175*^9}, 3.575949516875*^9,
    3.57594971090625*^9, {3.575949776703125*^9, 3.575949794484375*^9}, 
   3.575951801828125*^9, 3.5759520115*^9, 3.575952258625*^9, 
   3.5759523118125*^9, 3.57595389846875*^9, {3.57595399340625*^9, 
   3.575954013359375*^9}, 3.575954077875*^9, 3.575954155359375*^9, 
   3.575955029734375*^9, 3.57595568575*^9, 3.57595574609375*^9, 
   3.57595597715625*^9, 3.575956028515625*^9, 3.575956353203125*^9, 
   3.5759565220625*^9, 3.575956795296875*^9, 3.5759568995*^9, 
   3.575956967046875*^9, {3.575957073421875*^9, 3.575957094*^9}, 
   3.575957139828125*^9, {3.575957319671875*^9, 3.57595733315625*^9}, 
   3.575957364046875*^9, {3.575960741*^9, 3.575960754703125*^9}, 
   3.575960904703125*^9, 3.575961214625*^9, 3.575961294046875*^9, {
   3.575961432703125*^9, 3.575961440234375*^9}, 3.575961528890625*^9, {
   3.575961610390625*^9, 3.5759616371875*^9}, 3.575961920046875*^9, 
   3.575961952453125*^9, {3.575963163296875*^9, 3.575963183609375*^9}, 
   3.5759633596875*^9, 3.575963440765625*^9, {3.575963645296875*^9, 
   3.575963674703125*^9}, 3.575963829625*^9, 3.575963872125*^9, 
   3.575963954515625*^9, 3.5759639866875*^9, 3.575964466390625*^9, {
   3.575964586546875*^9, 3.575964605765625*^9}, 3.57596501553125*^9, 
   3.57596521415625*^9, 3.5759658945*^9, 3.57596596721875*^9, 
   3.57596611328125*^9, 3.57596618534375*^9, 3.575966401375*^9, 
   3.575966443203125*^9, 3.57596694865625*^9, 3.575967034125*^9, 
   3.57596755175*^9, 3.575967817109375*^9, 3.5759678539375*^9, 
   3.575968507296875*^9, 3.575968591453125*^9, 3.575968624109375*^9, {
   3.575969249203125*^9, 3.575969261140625*^9}, 3.575969308734375*^9, 
   3.57596935103125*^9, 3.575969626625*^9, 3.5759697635*^9, {
   3.57596997990625*^9, 3.575970020421875*^9}, {3.5759702024375*^9, 
   3.57597020696875*^9}, 3.57597039375*^9, 3.575970432890625*^9, 
   3.575970506828125*^9, 3.576002374171875*^9, 3.576002980515625*^9, 
   3.576003111375*^9, 3.576003984765625*^9, 3.57600528390625*^9, 
   3.576007187875*^9, 3.57600813115625*^9, 3.5760082440625*^9, 
   3.576008300953125*^9, 3.576008350234375*^9, 3.576008691265625*^9, 
   3.57600881403125*^9, {3.57600929371875*^9, 3.57600930075*^9}, 
   3.57601286065625*^9, 3.576013185828125*^9, 3.57601322978125*^9, 
   3.576013276609375*^9, 3.576013561875*^9, 3.576013615234375*^9, 
   3.576013790203125*^9, {3.57601433265625*^9, 3.576014342125*^9}, 
   3.576014374203125*^9, 3.576014774953125*^9, 3.57601483328125*^9, {
   3.576014964828125*^9, 3.576014979515625*^9}, 3.57601570815625*^9, 
   3.576015942125*^9, 3.576016617953125*^9, 3.576016813984375*^9, 
   3.5760169211875*^9, 3.576016992015625*^9, {3.57601705196875*^9, 
   3.576017060390625*^9}, 3.57601907740625*^9, 3.57601919821875*^9, 
   3.576019358390625*^9, 3.576019479921875*^9, 3.57601956840625*^9, 
   3.5760199100625*^9, 3.576020396640625*^9, 3.576020533625*^9, 
   3.576020613484375*^9, 3.576020800734375*^9, {3.5760212185*^9, 
   3.576021255421875*^9}, 3.576021289265625*^9, 3.5760213626875*^9, 
   3.576021491125*^9, {3.576021555390625*^9, 3.576021570796875*^9}, 
   3.576021776734375*^9, {3.576021822125*^9, 3.576021840328125*^9}, 
   3.576021910109375*^9, 3.576022304265625*^9, 3.576022371*^9, {
   3.576025108828125*^9, 3.576025129296875*^9}, {3.576025618609375*^9, 
   3.576025659625*^9}, {3.576025960890625*^9, 3.576025975984375*^9}, {
   3.576026099390625*^9, 3.57602612265625*^9}, 3.576027493390625*^9, 
   3.576027653609375*^9, 3.576028673046875*^9, {3.576029685078125*^9, 
   3.5760296971875*^9}, 3.576029741859375*^9, 3.5760303198125*^9, 
   3.57603052434375*^9, 3.5760319514375*^9, {3.576032032015625*^9, 
   3.57603205846875*^9}, 3.5760321500625*^9, 3.57603220090625*^9, 
   3.5760322391875*^9, 3.576032282453125*^9, 3.576092706578125*^9, {
   3.576092769546875*^9, 3.576092795765625*^9}, 3.576135976703125*^9, 
   3.576136208890625*^9, 3.576136365953125*^9, 3.57613640528125*^9, 
   3.57613645178125*^9, 3.576136511546875*^9, 3.576136570328125*^9, 
   3.576136687796875*^9, 3.576136727609375*^9, 3.576136757703125*^9, 
   3.576136801359375*^9, {3.576136833046875*^9, 3.57613686053125*^9}, 
   3.5761369311875*^9, {3.576137009390625*^9, 3.576137039265625*^9}, 
   3.57613709578125*^9, {3.57613723115625*^9, 3.576137256609375*^9}, 
   3.57613749209375*^9, {3.57613778590625*^9, 3.57613785371875*^9}, 
   3.576137887390625*^9, 3.5761379349375*^9, 3.576137985734375*^9, 
   3.5761383735*^9, 3.576138886296875*^9, {3.576139018421875*^9, 
   3.576139019015625*^9}, 3.576139077640625*^9, 3.5761391104375*^9, 
   3.576139338953125*^9, {3.576139385953125*^9, 3.576139394*^9}, {
   3.576139427578125*^9, 3.576139440984375*^9}, {3.57613952028125*^9, 
   3.576139571171875*^9}, 3.57613960240625*^9, 3.576139746265625*^9, {
   3.57617730396875*^9, 3.576177327453125*^9}, 3.576177425625*^9, 
   3.57617746278125*^9, {3.57617756790625*^9, 3.576177596859375*^9}, {
   3.5761776370625*^9, 3.57617766915625*^9}, 3.576186313390625*^9, 
   3.576186418875*^9, 3.576186574796875*^9, 3.576186607078125*^9, 
   3.57618669315625*^9, 3.576187142390625*^9, {3.576187417015625*^9, 
   3.57618742915625*^9}, 3.576187789296875*^9, 3.5761878818125*^9, 
   3.576188229078125*^9, 3.57618923390625*^9, {3.57618933134375*^9, 
   3.57618935384375*^9}, 3.57619000684375*^9, 3.5761901535*^9, {
   3.5761907790625*^9, 3.57619080853125*^9}, 3.576190839171875*^9, {
   3.576190947609375*^9, 3.576190964359375*^9}, 3.576202721009239*^9, 
   3.5762027631312737`*^9, 3.576202900777833*^9, {3.576202942274911*^9, 
   3.576202970616666*^9}, 3.5762030664536686`*^9, {3.576203896921875*^9, 
   3.576203949671875*^9}, {3.576204008125*^9, 3.576204071328125*^9}, {
   3.576204105453125*^9, 3.576204131328125*^9}, 3.57620417453125*^9, 
   3.57620423278125*^9, 3.57620797328125*^9, 3.576210863359375*^9, {
   3.57621099034375*^9, 3.57621100253125*^9}, {3.576211204703125*^9, 
   3.5762112075*^9}, 3.576211344328125*^9, {3.576211507625*^9, 
   3.5762115159375*^9}, 3.576211695515625*^9, 3.576211738890625*^9, 
   3.5762121838125*^9, 3.5762122271875*^9, 3.57621235421875*^9, 
   3.5762124089375*^9, {3.576212481015625*^9, 3.5762124886875*^9}, {
   3.57621253146875*^9, 3.5762125783125*^9}, {3.57621269996875*^9, 
   3.57621273471875*^9}, 3.576213106203125*^9, 3.576213317953125*^9, 
   3.576213528328125*^9, 3.57621356296875*^9, {3.57621361834375*^9, 
   3.576213631265625*^9}, {3.57621367371875*^9, 3.57621370396875*^9}, 
   3.576213807359375*^9, 3.576213894484375*^9, 3.57621395384375*^9, 
   3.576214015703125*^9, 3.576214107828125*^9, 3.5762141401875*^9, 
   3.57622093521875*^9, 3.576221018359375*^9, 3.576221059984375*^9, 
   3.576221131734375*^9, 3.576221436890625*^9, 3.576221627140625*^9, 
   3.576225086140625*^9, 3.576225135515625*^9, 3.576225168328125*^9, 
   3.576225261171875*^9, 3.57622540896875*^9, 3.576225516734375*^9, 
   3.57622556590625*^9, 3.576225613640625*^9, 3.576225684734375*^9, {
   3.576225721765625*^9, 3.5762257464375*^9}, 3.576226011625*^9, 
   3.576226465421875*^9, {3.576262884125*^9, 3.576262955828125*^9}, {
   3.57626299109375*^9, 3.576263019390625*^9}, 3.5762777830648794`*^9, 
   3.5762781508491316`*^9, {3.576278193205253*^9, 3.5762782174065948`*^9}, 
   3.576278463358029*^9, {3.5762949412365713`*^9, 3.5762951904533997`*^9}, {
   3.5762952243260155`*^9, 3.576295267479227*^9}, {3.576295362535035*^9, 
   3.576295384486614*^9}, 3.5762954178592644`*^9, {3.5762954581845503`*^9, 
   3.5762955242423997`*^9}, 3.5763115083843465`*^9, 3.5763116290492477`*^9, 
   3.5763117287349496`*^9, 3.576311872922197*^9, 3.5763119289193993`*^9, 
   3.5763119808393693`*^9, 3.5763120533705177`*^9, 3.5763121761845427`*^9, 
   3.5763500239375*^9, 3.576351494578125*^9, 3.576351610109375*^9, 
   3.576351796625*^9, 3.57635543646875*^9, 3.576355480375*^9, 
   3.5763557825*^9, {3.576357300796875*^9, 3.576357320015625*^9}, 
   3.57635739684375*^9, 3.576357487875*^9, 3.576357588296875*^9, 
   3.57635771096875*^9, 3.576364865936562*^9, 3.5763649268072767`*^9, 
   3.5763705662814503`*^9, 3.5763706044516153`*^9, 3.576370827332255*^9, 
   3.5763752720969486`*^9, 3.5763754049431305`*^9, 3.576380151628813*^9, 
   3.5763802111109037`*^9, 3.5763802875610924`*^9, 3.576380336481089*^9, 
   3.576380388650961*^9, 3.576380470507192*^9, {3.5763805305048885`*^9, 
   3.576380558628808*^9}, 3.5764597436254997`*^9, 3.5764597797817497`*^9, 
   3.5764601640942497`*^9, 3.5764604672973747`*^9, 3.5764605400317497`*^9, 
   3.5764606050317497`*^9, 3.5764607770317497`*^9, 3.5764608357973747`*^9, 
   3.5764609708754997`*^9, {3.5764611268129997`*^9, 3.5764611777036247`*^9}, 
   3.576706432515625*^9, 3.576706808390625*^9, 3.5767068474375*^9, 
   3.57678571015625*^9, 3.576786207359375*^9, 3.5767871739375*^9, 
   3.576788359984375*^9, 3.57678929840625*^9, 3.57678935871875*^9, 
   3.57678953940625*^9, 3.57678967771875*^9, 3.576790704703125*^9, 
   3.57679098503125*^9, 3.576791113125*^9, 3.576791711046875*^9, {
   3.57689595175*^9, 3.576895956015625*^9}, {3.5768961276875*^9, 
   3.576896141125*^9}, 3.576896380515625*^9, 3.576896743875*^9, 
   3.5768970235*^9, 3.576897055953125*^9, 3.576897195796875*^9, 
   3.576897245640625*^9, 3.576899900046875*^9, 3.57696097765625*^9, 
   3.576961111625*^9, 3.576961163546875*^9}]
}, Open  ]]
}, Open  ]]
}, Open  ]]
},
WindowToolbars->"EditBar",
WindowSize->{1406, 758},
WindowMargins->{{0, Automatic}, {Automatic, 0}},
PrintingCopies->1,
PrintingPageRange->{32000, 32000},
PrintingOptions->{"Magnification"->1.,
"PaperOrientation"->"Landscape",
"PaperSize"->{822., 574.92},
"PrintingMargins"->28.346456999999997`},
FrontEndVersion->"8.0 for Microsoft Windows (32-bit) (February 23, 2011)",
StyleDefinitions->FrontEnd`FileName[{"Creative"}, "NaturalColor.nb", 
  CharacterEncoding -> "WindowsANSI"]
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{}
*)
(*CellTagsIndex
CellTagsIndex->{}
*)
(*NotebookFileOutline
Notebook[{
Cell[CellGroupData[{
Cell[579, 22, 256, 5, 65, "Title"],
Cell[838, 29, 4205, 76, 636, "Text"],
Cell[5046, 107, 695, 15, 107, "Input"],
Cell[CellGroupData[{
Cell[5766, 126, 272, 4, 75, "Section"],
Cell[6041, 132, 576, 11, 37, "Text"],
Cell[6620, 145, 7345, 106, 74, "Input"],
Cell[13968, 253, 667, 12, 37, "Text"],
Cell[14638, 267, 4146, 66, 101, "Input"],
Cell[18787, 335, 869, 15, 37, "Text"],
Cell[19659, 352, 261, 7, 46, "Input"]
}, Open  ]],
Cell[CellGroupData[{
Cell[19957, 364, 347, 4, 75, "Section"],
Cell[20307, 370, 351, 6, 35, "Text"],
Cell[CellGroupData[{
Cell[20683, 380, 1531, 36, 277, "Input"],
Cell[22217, 418, 6834, 98, 45, "Output"]
}, Open  ]],
Cell[29066, 519, 287, 6, 35, "Text"],
Cell[CellGroupData[{
Cell[29378, 529, 1429, 31, 101, "Input"],
Cell[30810, 562, 12737, 189, 45, "Output"]
}, Open  ]],
Cell[43562, 754, 430, 6, 35, "Text"],
Cell[CellGroupData[{
Cell[44017, 764, 1841, 42, 155, "Input"],
Cell[45861, 808, 12964, 187, 376, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[58874, 1001, 368, 7, 75, "Section"],
Cell[59245, 1010, 277, 5, 35, "Text"],
Cell[59525, 1017, 2585, 50, 74, "Input"],
Cell[62113, 1069, 238, 5, 35, "Text"],
Cell[62354, 1076, 698, 24, 88, "Input"],
Cell[63055, 1102, 201, 4, 35, "Text"],
Cell[63259, 1108, 1061, 36, 158, "Input"],
Cell[64323, 1146, 197, 4, 35, "Text"],
Cell[64523, 1152, 4124, 122, 239, "Input"],
Cell[68650, 1276, 539, 7, 35, "Text"],
Cell[69192, 1285, 3822, 72, 101, "Input"],
Cell[73017, 1359, 417, 9, 35, "Text"],
Cell[CellGroupData[{
Cell[73459, 1372, 512, 12, 101, "Input"],
Cell[73974, 1386, 756, 17, 82, "Output"],
Cell[74733, 1405, 892, 24, 82, "Output"]
}, Open  ]],
Cell[75640, 1432, 1182, 19, 83, "Text"],
Cell[76825, 1453, 617, 16, 101, "Input"],
Cell[77445, 1471, 1111, 17, 35, "Text"],
Cell[CellGroupData[{
Cell[78581, 1492, 3687, 103, 344, "Input"],
Cell[82271, 1597, 133, 3, 45, "Output"],
Cell[82407, 1602, 133, 3, 45, "Output"]
}, Open  ]],
Cell[82555, 1608, 204, 3, 35, "Text"],
Cell[CellGroupData[{
Cell[82784, 1615, 203, 2, 101, "Input"],
Cell[82990, 1619, 1340, 27, 82, "Output"],
Cell[84333, 1648, 1281, 24, 71, "Output"],
Cell[85617, 1674, 1281, 24, 71, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[86947, 1704, 256, 5, 75, "Section"],
Cell[87206, 1711, 463, 8, 35, "Text"],
Cell[87672, 1721, 481, 14, 46, "Input"],
Cell[88156, 1737, 712, 12, 35, "Text"],
Cell[88871, 1751, 2500, 69, 235, "Input"],
Cell[91374, 1822, 317, 6, 35, "Text"],
Cell[91694, 1830, 13357, 373, 1478, "Input"]
}, Open  ]],
Cell[CellGroupData[{
Cell[105088, 2208, 495, 8, 75, "Section"],
Cell[105586, 2218, 745, 12, 35, "Text"],
Cell[CellGroupData[{
Cell[106356, 2234, 3036, 50, 101, "Input"],
Cell[109395, 2286, 13310, 201, 82, "Output"],
Cell[122708, 2489, 13086, 190, 45, "Output"]
}, Open  ]],
Cell[135809, 2682, 281, 6, 35, "Text"],
Cell[CellGroupData[{
Cell[136115, 2692, 1091, 23, 74, "Input"],
Cell[137209, 2717, 6713, 98, 45, "Output"]
}, Open  ]],
Cell[143937, 2818, 510, 9, 35, "Text"],
Cell[144450, 2829, 5584, 89, 101, "Input"],
Cell[150037, 2920, 243, 5, 35, "Text"],
Cell[150283, 2927, 842, 22, 103, "Input"],
Cell[151128, 2951, 251, 5, 35, "Text"],
Cell[151382, 2958, 547, 14, 46, "Input"],
Cell[151932, 2974, 158, 3, 35, "Text"],
Cell[CellGroupData[{
Cell[152115, 2981, 1266, 33, 103, "Input"],
Cell[153384, 3016, 598, 14, 82, "Output"],
Cell[153985, 3032, 894, 23, 68, "Output"],
Cell[154882, 3057, 1524, 49, 74, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[156455, 3112, 312, 6, 75, "Section"],
Cell[156770, 3120, 157, 2, 35, "Text"],
Cell[CellGroupData[{
Cell[156952, 3126, 1066, 26, 70, "Input"],
Cell[158021, 3154, 6332, 127, 156, "Output"]
}, Open  ]],
Cell[164368, 3284, 100, 1, 35, "Text"],
Cell[CellGroupData[{
Cell[164493, 3289, 1380, 28, 74, "Input"],
Cell[165876, 3319, 15634, 255, 260, "Output"]
}, Open  ]],
Cell[181525, 3577, 159, 2, 35, "Text"],
Cell[CellGroupData[{
Cell[181709, 3583, 807, 23, 101, "Input"],
Cell[182519, 3608, 5350, 128, 160, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[187906, 3741, 498, 12, 46, "Input"],
Cell[188407, 3755, 10418, 174, 262, "Output"]
}, Open  ]],
Cell[198840, 3932, 236, 5, 35, "Text"],
Cell[CellGroupData[{
Cell[199101, 3941, 1072, 29, 155, "Input"],
Cell[200176, 3972, 1703, 25, 45, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[201928, 4003, 268, 5, 75, "Section"],
Cell[202199, 4010, 203, 3, 35, "Text"],
Cell[202405, 4015, 141, 3, 46, "Input"],
Cell[202549, 4020, 256, 5, 35, "Text"],
Cell[202808, 4027, 957, 24, 76, "Input"],
Cell[203768, 4053, 87, 1, 35, "Text"],
Cell[CellGroupData[{
Cell[203880, 4058, 1223, 26, 74, "Input"],
Cell[205106, 4086, 75065, 1243, 260, "Output"]
}, Open  ]],
Cell[280186, 5332, 139, 1, 35, "Text"],
Cell[CellGroupData[{
Cell[280350, 5337, 409, 10, 78, "Input"],
Cell[280762, 5349, 13090, 187, 45, "Output"]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}
]
*)

(* End of internal cache information *)
